@@ -4,8 +4,8 @@
 #include "./jsdefs.h"
 #include "./jsincludes.h"
 
-#include "../connector/syncthingconfig.h"
-#include "../connector/utils.h"
+#include <syncthingconnector/syncthingconfig.h>
+#include <syncthingconnector/utils.h>
 
 // use header-only functions waitForSignals() and signalInfo() from test utilities; disable assertions via macro
 #define SYNCTHINGTESTHELPER_FOR_CLI
@@ -47,7 +47,7 @@ static int statusCode = 0;
 
 void exitApplication(int statusCode)
 {
-    statusCode = ::Cli::statusCode;
+    ::Cli::statusCode = statusCode;
     terminated = true;
 }
 
@@ -208,7 +208,7 @@ int Application::loadConfig()
     if (apiKeyArgValue) {
         m_settings.apiKey.append(apiKeyArgValue);
     } else {
-        m_settings.apiKey.append(config.guiApiKey);
+        m_settings.apiKey.append(config.guiApiKey.toUtf8());
     }
     if (const char *certArgValue = m_args.certificate.firstValue()) {
         m_settings.httpsCertPath = argToQString(certArgValue);
@@ -579,20 +579,25 @@ void Application::printStatus(const ArgumentOccurrence &)
         const auto &overallStats(m_connection.computeOverallDirStatistics());
         const auto *statusString = "idle";
         const auto *statusColor = "32";
-        switch (m_connection.status()) {
-        case SyncthingStatus::Synchronizing:
-            statusString = "synchronizing";
-            statusColor = "34";
-            break;
-        case SyncthingStatus::Scanning:
-            statusString = "scanning";
-            statusColor = "34";
-            break;
-        case SyncthingStatus::OutOfSync:
+        if (m_connection.hasOutOfSyncDirs()) {
             statusString = "out-of-sync";
             statusColor = "31";
-            break;
-        default:;
+        } else {
+            switch (m_connection.status()) {
+            case SyncthingStatus::Synchronizing:
+                statusString = "synchronizing";
+                statusColor = "34";
+                break;
+            case SyncthingStatus::RemoteNotInSync:
+                statusString = "remote synchronizing";
+                statusColor = "34";
+                break;
+            case SyncthingStatus::Scanning:
+                statusString = "scanning";
+                statusColor = "34";
+                break;
+            default:;
+            }
         }
         if (!EscapeCodes::enabled) {
             printProperty("Status", statusString);
@@ -618,17 +623,19 @@ void Application::printStatus(const ArgumentOccurrence &)
     // display dirs
     if (!m_relevantDirs.empty()) {
         cout << TextAttribute::Bold << "Directories\n" << TextAttribute::Reset;
-        sort(m_relevantDirs.begin(), m_relevantDirs.end(),
-            [](const RelevantDir &dir1, const RelevantDir &dir2) { return dir1.dirObj->displayName() < dir2.dirObj->displayName(); });
-        for_each(m_relevantDirs.cbegin(), m_relevantDirs.cend(), bind(&Application::printDir, this, placeholders::_1));
+        std::sort(m_relevantDirs.begin(), m_relevantDirs.end(),
+            [](const RelevantDir &lhs, const RelevantDir &rhs) { return lhs.dirObj->displayName() < rhs.dirObj->displayName(); });
+        std::for_each(m_relevantDirs.cbegin(), m_relevantDirs.cend(), bind(&Application::printDir, this, std::placeholders::_1));
     }
 
     // display devs
     if (!m_relevantDevs.empty()) {
         cout << TextAttribute::Bold << "Devices\n" << TextAttribute::Reset;
-        sort(m_relevantDevs.begin(), m_relevantDevs.end(),
-            [](const SyncthingDev *dev1, const SyncthingDev *dev2) { return dev1->displayName() < dev2->displayName(); });
-        for_each(m_relevantDevs.cbegin(), m_relevantDevs.cend(), bind(&Application::printDev, this, placeholders::_1));
+        std::sort(m_relevantDevs.begin(), m_relevantDevs.end(), [](const SyncthingDev *lhs, const SyncthingDev *rhs) {
+            const auto lhsIsOwn = lhs->status == SyncthingDevStatus::OwnDevice, rhsIsOwn = rhs->status == SyncthingDevStatus::OwnDevice;
+            return lhsIsOwn != rhsIsOwn ? lhsIsOwn : lhs->displayName() < rhs->displayName();
+        });
+        std::for_each(m_relevantDevs.cbegin(), m_relevantDevs.cend(), bind(&Application::printDev, this, std::placeholders::_1));
     }
 
     cout.flush();
@@ -640,8 +647,13 @@ void Application::printLog(const std::vector<SyncthingLogEntry> &logEntries)
     cerr << Phrases::Override;
 
     for (const SyncthingLogEntry &entry : logEntries) {
-        cout << DateTime::fromIsoStringLocal(entry.when.toLocal8Bit().data()).toString(DateTimeOutputFormat::DateAndTime, true).data() << ':' << ' '
-             << entry.message.toLocal8Bit().data() << '\n';
+        const auto when = entry.when.toUtf8();
+        try {
+            cout << DateTime::fromIsoStringLocal(when.data()).toString(DateTimeOutputFormat::DateAndTime, true);
+        } catch (const ConversionException &e) {
+            cout << when.data();
+        }
+        cout << ':' << ' ' << entry.message.toLocal8Bit().data() << '\n';
     }
     cout.flush();
     QCoreApplication::exit();
@@ -818,13 +830,13 @@ QByteArray Application::editConfigViaScript() const
         }
     } else if (m_args.jsLines.isPresent()) {
         // construct script from CLI arguments
-        int requiredSize = 0;
-        for (const auto *line : m_args.jsLines.values()) {
-            requiredSize += strlen(line);
+        auto requiredSize = QString::size_type(0);
+        for (const auto *const line : m_args.jsLines.values()) {
+            requiredSize += static_cast<QString::size_type>(std::strlen(line));
             requiredSize += 1;
         }
         script.reserve(requiredSize);
-        for (const auto *line : m_args.jsLines.values()) {
+        for (const auto *const line : m_args.jsLines.values()) {
             script += line;
             script += '\n';
         }
@@ -1098,7 +1110,7 @@ RelevantDir Application::findDirectory(const QString &dirIdentifier)
 
     // check whether the specified identifier is a known Syncthing directory or a relative path to an item in a
     // known Syncthing directory
-    int firstSlash = dirIdentifier.indexOf(QChar('/'));
+    auto firstSlash = dirIdentifier.indexOf(QChar('/'));
     relevantDir.dirObj = m_connection.findDirInfo(firstSlash >= 0 ? dirIdentifier.mid(0, firstSlash) : dirIdentifier, dummy);
     if (relevantDir) {
         if (firstSlash >= 0) {
