@@ -7,12 +7,10 @@
 #include "./syncthingconnectionmockhelpers.h"
 #endif
 
-#include <c++utilities/conversion/stringconversion.h>
+#include "resources/config.h"
 
-#if defined(LIB_SYNCTHING_CONNECTOR_LOG_SYNCTHING_EVENTS) || defined(LIB_SYNCTHING_CONNECTOR_LOG_API_CALLS)
+#include <c++utilities/conversion/stringconversion.h>
 #include <c++utilities/io/ansiescapecodes.h>
-#include <iostream>
-#endif
 
 #include <QAuthenticator>
 #include <QHostAddress>
@@ -25,13 +23,12 @@
 #include <QStringBuilder>
 #include <QTimer>
 
+#include <iostream>
 #include <utility>
 
 using namespace std;
 using namespace CppUtilities;
-#if defined(LIB_SYNCTHING_CONNECTOR_LOG_SYNCTHING_EVENTS) || defined(LIB_SYNCTHING_CONNECTOR_LOG_API_CALLS)
 using namespace CppUtilities::EscapeCodes;
-#endif
 
 namespace Data {
 
@@ -50,11 +47,11 @@ QNetworkAccessManager &networkAccessManager()
  * \remarks All requests are performed asynchronously.
  *
  * The first thing to do when working with that class is setting the URL to connect to and the API key
- * via the constructor or setSyncthingUrl() and setApiKey(). Credentials for the HTTP authentification
+ * via the constructor or setSyncthingUrl() and setApiKey(). Credentials for the HTTP authentication
  * can be set via setCredentials() if not included in the URL.
  *
  * Requests can then be done via the request...() methods, eg. requestConfig(). This would emit the
- * newConfig() signal on success and the error() signal when an error occured. The other request...()
+ * newConfig() signal on success and the error() signal when an error occurred. The other request...()
  * methods work in a similar way.
  *
  * However, usually it is best to simply call the connect() method. It will do all required requests
@@ -67,15 +64,20 @@ QNetworkAccessManager &networkAccessManager()
 /*!
  * \brief Constructs a new instance ready to connect. To establish the connection, call connect().
  */
-SyncthingConnection::SyncthingConnection(const QString &syncthingUrl, const QByteArray &apiKey, QObject *parent)
+SyncthingConnection::SyncthingConnection(
+    const QString &syncthingUrl, const QByteArray &apiKey, SyncthingConnectionLoggingFlags loggingFlags, QObject *parent)
     : QObject(parent)
     , m_syncthingUrl(syncthingUrl)
     , m_apiKey(apiKey)
     , m_status(SyncthingStatus::Disconnected)
+    , m_statusComputionFlags(SyncthingStatusComputionFlags::Default)
+    , m_loggingFlags(SyncthingConnectionLoggingFlags::None)
+    , m_loggingFlagsHandler(SyncthingConnectionLoggingFlags::None)
     , m_keepPolling(false)
     , m_abortingAllRequests(false)
+    , m_connectionAborted(false)
     , m_abortingToReconnect(false)
-    , m_requestCompletion(false)
+    , m_requestCompletion(true)
     , m_lastEventId(0)
     , m_lastDiskEventId(0)
     , m_autoReconnectTries(0)
@@ -100,6 +102,7 @@ SyncthingConnection::SyncthingConnection(const QString &syncthingUrl, const QByt
     , m_hasDiskEvents(false)
     , m_lastFileDeleted(false)
     , m_dirStatsAltered(false)
+    , m_recordFileChanges(false)
 {
     m_trafficPollTimer.setInterval(SyncthingConnectionSettings::defaultTrafficPollInterval);
     m_trafficPollTimer.setTimerType(Qt::VeryCoarseTimer);
@@ -121,16 +124,7 @@ SyncthingConnection::SyncthingConnection(const QString &syncthingUrl, const QByt
     setupTestData();
 #endif
 
-#ifdef LIB_SYNCTHING_CONNECTOR_LOG_SYNCTHING_EVENTS
-    QObject::connect(this, &SyncthingConnection::newDirs, [](const auto &dirs) {
-        std::cerr << Phrases::Info << "Directory list renewed:" << Phrases::End;
-        std::cerr << displayNames(dirs).join(QStringLiteral(", ")).toStdString() << endl;
-    });
-    QObject::connect(this, &SyncthingConnection::newDevices, [](const auto &devs) {
-        std::cerr << Phrases::Info << "Device list renewed:" << Phrases::End;
-        std::cerr << displayNames(devs).join(QStringLiteral(", ")).toStdString() << endl;
-    });
-#endif
+    setLoggingFlags(loggingFlags);
 }
 
 /*!
@@ -168,13 +162,56 @@ QString SyncthingConnection::statusText(SyncthingStatus status)
         return tr("connected, paused");
     case SyncthingStatus::Synchronizing:
         return tr("connected, synchronizing");
-    case SyncthingStatus::OutOfSync:
-        return tr("connected, out of sync");
+    case SyncthingStatus::RemoteNotInSync:
+        return tr("connected, remote not in sync");
     default:
         return tr("unknown");
     }
 }
 
+/*!
+ * \brief Sets the specified logging \a flags.
+ */
+void SyncthingConnection::setLoggingFlags(SyncthingConnectionLoggingFlags flags)
+{
+    m_loggingFlags = flags;
+    if (flags & SyncthingConnectionLoggingFlags::FromEnvironment) {
+        if (!(flags & SyncthingConnectionLoggingFlags::All) && qEnvironmentVariableIntValue(PROJECT_VARNAME_UPPER "_LOG_ALL")) {
+            m_loggingFlags |= SyncthingConnectionLoggingFlags::All;
+        } else {
+            if (!(flags & SyncthingConnectionLoggingFlags::ApiCalls) && qEnvironmentVariableIntValue(PROJECT_VARNAME_UPPER "_LOG_API_CALLS")) {
+                m_loggingFlags |= SyncthingConnectionLoggingFlags::ApiCalls;
+            }
+            if (!(flags & SyncthingConnectionLoggingFlags::ApiCalls) && qEnvironmentVariableIntValue(PROJECT_VARNAME_UPPER "_LOG_API_REPLIES")) {
+                m_loggingFlags |= SyncthingConnectionLoggingFlags::ApiCalls;
+            }
+            if (!(flags & SyncthingConnectionLoggingFlags::Events) && qEnvironmentVariableIntValue(PROJECT_VARNAME_UPPER "_LOG_EVENTS")) {
+                m_loggingFlags |= SyncthingConnectionLoggingFlags::Events;
+            }
+            if (!(flags & SyncthingConnectionLoggingFlags::DirsOrDevsResetted)
+                && qEnvironmentVariableIntValue(PROJECT_VARNAME_UPPER "_LOG_DIRS_OR_DEVS_RESETTED")) {
+                m_loggingFlags |= SyncthingConnectionLoggingFlags::Events;
+            }
+        }
+    }
+    if ((m_loggingFlags & SyncthingConnectionLoggingFlags::DirsOrDevsResetted)
+        && !(m_loggingFlagsHandler & SyncthingConnectionLoggingFlags::DirsOrDevsResetted)) {
+        QObject::connect(this, &SyncthingConnection::newDirs, [this](const auto &dirs) {
+            if (m_loggingFlags & SyncthingConnectionLoggingFlags::DirsOrDevsResetted) {
+                std::cerr << Phrases::Info << "Directory list renewed:" << Phrases::End;
+                std::cerr << displayNames(dirs).join(QStringLiteral(", ")).toStdString() << endl;
+            }
+        });
+        QObject::connect(this, &SyncthingConnection::newDevices, [this](const auto &devs) {
+            if (m_loggingFlags & SyncthingConnectionLoggingFlags::DirsOrDevsResetted) {
+                std::cerr << Phrases::Info << "Device list renewed:" << Phrases::End;
+                std::cerr << displayNames(devs).join(QStringLiteral(", ")).toStdString() << endl;
+            }
+        });
+        m_loggingFlagsHandler |= SyncthingConnectionLoggingFlags::DirsOrDevsResetted;
+    }
+}
+
 /*!
  * \brief Returns whether there is at least one directory out-of-sync.
  */
@@ -221,7 +258,7 @@ void SyncthingConnection::connect()
     }
 
     // reset status
-    m_abortingToReconnect = m_hasConfig = m_hasStatus = m_hasEvents = m_hasDiskEvents = false;
+    m_connectionAborted = m_abortingToReconnect = m_hasConfig = m_hasStatus = m_hasEvents = m_hasDiskEvents = false;
 
     // check configuration
     if (m_apiKey.isEmpty() || m_syncthingUrl.isEmpty()) {
@@ -262,23 +299,27 @@ void SyncthingConnection::connectLater(int milliSeconds)
 }
 
 /*!
- * \brief Disconnects. Does nothing if not connected.
+ * \brief Disconnects. That means all (long) polling is stopped and ongoing requests are aborted via abortAllRequests().
  */
 void SyncthingConnection::disconnect()
 {
     m_abortingToReconnect = m_keepPolling = false;
+    m_trafficPollTimer.stop();
+    m_devStatsPollTimer.stop();
+    m_errorsPollTimer.stop();
+    m_autoReconnectTimer.stop();
     m_autoReconnectTries = 0;
     abortAllRequests();
 }
 
 /*!
  * \brief Aborts status-relevant, pending requests.
- * \remarks Status-relevant means that requests for tiggering actions like rescan() or restart() are excluded. requestQrCode() does not
+ * \remarks Status-relevant means that requests for triggering actions like rescan() or restart() are excluded. requestQrCode() does not
  *          contribute to the status as well and is excluded as well.
  */
 void SyncthingConnection::abortAllRequests()
 {
-    m_abortingAllRequests = true;
+    m_connectionAborted = m_abortingAllRequests = true;
     if (m_configReply) {
         m_configReply->abort();
     }
@@ -309,7 +350,7 @@ void SyncthingConnection::abortAllRequests()
     if (m_logReply) {
         m_logReply->abort();
     }
-    for (auto *const reply : m_otherReplies) {
+    for (auto *const reply : std::as_const(m_otherReplies)) {
         reply->abort();
     }
 
@@ -329,6 +370,11 @@ void SyncthingConnection::reconnect()
     m_autoReconnectTimer.stop();
     m_autoReconnectTries = 0;
 
+    // stop other timers
+    m_trafficPollTimer.stop();
+    m_devStatsPollTimer.stop();
+    m_errorsPollTimer.stop();
+
     // reset variables to track connection progress
     // note: especially resetting events is important as it influences the subsequent hasPendingRequests() call
     m_hasConfig = m_hasStatus = m_hasEvents = m_hasDiskEvents = false;
@@ -375,11 +421,14 @@ void SyncthingConnection::continueReconnecting()
 
     // cleanup information from previous connection
     m_keepPolling = true;
+    m_connectionAborted = false;
     m_abortingToReconnect = false;
     m_lastEventId = 0;
     m_lastDiskEventId = 0;
     m_configDir.clear();
     m_myId.clear();
+    m_tilde.clear();
+    m_pathSeparator.clear();
     m_totalIncomingTraffic = unknownTraffic;
     m_totalOutgoingTraffic = unknownTraffic;
     m_totalIncomingRate = 0.0;
@@ -643,6 +692,23 @@ SyncthingDev *SyncthingConnection::addDevInfo(std::vector<SyncthingDev> &devs, c
     return &devs.back();
 }
 
+/*!
+ * \brief Internally called to parse a time stamp.
+ */
+DateTime SyncthingConnection::parseTimeStamp(const QJsonValue &jsonValue, const QString &context, DateTime defaultValue, bool greaterThanEpoch)
+{
+    const auto utf16 = jsonValue.toString();
+    const auto utf8 = utf16.toUtf8();
+    try {
+        const auto [localTime, utcOffset] = DateTime::fromIsoString(utf8.data());
+        return !greaterThanEpoch || (localTime - utcOffset) > DateTime::unixEpochStart() ? localTime : defaultValue;
+    } catch (const ConversionException &e) {
+        emit error(tr("Unable to parse timestamp \"%1\" (%2): %3").arg(utf16, context, QString::fromUtf8(e.what())), SyncthingErrorCategory::Parsing,
+            QNetworkReply::NoError);
+    }
+    return defaultValue;
+}
+
 /*!
  * \brief Continues connecting if both - config and status - have been parsed yet and continuous polling is enabled.
  */
@@ -662,7 +728,7 @@ void SyncthingConnection::continueConnecting()
     requestVersion();
     for (const SyncthingDir &dir : m_dirs) {
         requestDirStatus(dir.id);
-        if (!m_requestCompletion) {
+        if (!m_requestCompletion || dir.paused) {
             continue;
         }
         for (const QString &devId : dir.deviceIds) {
@@ -765,15 +831,29 @@ bool SyncthingConnection::applySettings(SyncthingConnectionSettings &connectionS
     setDevStatsPollInterval(connectionSettings.devStatsPollInterval);
     setErrorsPollInterval(connectionSettings.errorsPollInterval);
     setAutoReconnectInterval(connectionSettings.reconnectInterval);
+    setStatusComputionFlags(connectionSettings.statusComputionFlags);
 
     return reconnectRequired;
 }
 
 /*!
- * \brief Sets the connection status. Ensures statusChanged() is emitted.
+ * \brief Sets the connection status. Ensures statusChanged() is emitted if the status has actually changed.
  * \param status Specifies the status; should be either SyncthingStatus::Disconnected, SyncthingStatus::Reconnecting, or
  *        SyncthingStatus::Idle. There is no use in specifying other values such as SyncthingStatus::Synchronizing as
- *        these are determined automatically within the method.
+ *        these are determined automatically within the method according to SyncthingConnection::statusComputionFlags().
+ *
+ * The precedence of the "connected" states from highest to lowest is:
+ * 1. SyncthingStatus::Synchronizing
+ * 2. SyncthingStatus::RemoteSynchronizing
+ * 3. SyncthingStatus::Scanning
+ * 4. SyncthingStatus::Paused
+ * 5. SyncthingStatus::Idle
+ *
+ * \remarks
+ * - The "out-of-sync" status is (currently) *not* handled by this function. One needs to query this via
+ *   the SyncthingConnection::hasOutOfSyncDirs() function.
+ * - Whether notifications are available is *not* handled by this function. One needs to query this via
+ *   SyncthingConnection::hasUnreadNotifications().
  */
 void SyncthingConnection::setStatus(SyncthingStatus status)
 {
@@ -784,6 +864,7 @@ void SyncthingConnection::setStatus(SyncthingStatus status)
     case SyncthingStatus::Disconnected:
         // disable (long) polling
         m_keepPolling = false;
+        m_connectionAborted = true;
         [[fallthrough]];
     case SyncthingStatus::Reconnecting:
         m_devStatsPollTimer.stop();
@@ -794,64 +875,69 @@ void SyncthingConnection::setStatus(SyncthingStatus status)
         // reset reconnect tries
         m_autoReconnectTries = 0;
 
+        // skip if no further status information should be gathered
+        status = SyncthingStatus::Idle;
+        if (m_statusComputionFlags == SyncthingStatusComputionFlags::None) {
+            break;
+        }
+
         // check whether at least one directory is scanning, preparing to synchronize or synchronizing
         // note: We don't distinguish between "preparing to sync" and "synchronizing" for computing the overall
         //       status at the moment.
-        bool scanning = false;
-        bool synchronizing = false;
-        for (const SyncthingDir &dir : m_dirs) {
-            switch (dir.status) {
-            case SyncthingDirStatus::PreparingToSync:
-            case SyncthingDirStatus::Synchronizing:
-                synchronizing = true;
-                break;
-            case SyncthingDirStatus::WaitingToScan:
-            case SyncthingDirStatus::Scanning:
-                scanning = true;
-                break;
-            default:;
+        auto scanning = false, synchronizing = false, remoteSynchronizing = false;
+        if (m_statusComputionFlags & SyncthingStatusComputionFlags::Synchronizing
+            || m_statusComputionFlags & SyncthingStatusComputionFlags::Scanning) {
+            for (const SyncthingDir &dir : m_dirs) {
+                switch (dir.status) {
+                case SyncthingDirStatus::WaitingToSync:
+                case SyncthingDirStatus::PreparingToSync:
+                case SyncthingDirStatus::Synchronizing:
+                    synchronizing = m_statusComputionFlags & SyncthingStatusComputionFlags::Synchronizing;
+                    break;
+                case SyncthingDirStatus::WaitingToScan:
+                case SyncthingDirStatus::Scanning:
+                    scanning = m_statusComputionFlags & SyncthingStatusComputionFlags::Scanning;
+                    break;
+                default:;
+                }
+                if (synchronizing) {
+                    break; // skip remaining dirs, "synchronizing" overrides "scanning" anyways
+                }
             }
-            if (synchronizing) {
-                break; // skip remaining dirs, "synchronizing" overrides "scanning" anyways
+        }
+
+        // set the status to "remote synchronizing" if at least one remote device is still in progress
+        if (!synchronizing && (m_statusComputionFlags & SyncthingStatusComputionFlags::RemoteSynchronizing)) {
+            for (const SyncthingDev &dev : m_devs) {
+                if (dev.status == SyncthingDevStatus::Synchronizing) {
+                    remoteSynchronizing = true;
+                    break;
+                }
             }
         }
 
         if (synchronizing) {
             status = SyncthingStatus::Synchronizing;
+        } else if (remoteSynchronizing) {
+            status = SyncthingStatus::RemoteNotInSync;
         } else if (scanning) {
             status = SyncthingStatus::Scanning;
-        } else {
+        } else if (m_statusComputionFlags & SyncthingStatusComputionFlags::DevicePaused) {
             // check whether at least one device is paused
-            bool paused = false;
             for (const SyncthingDev &dev : m_devs) {
                 if (dev.paused) {
-                    paused = true;
+                    status = SyncthingStatus::Paused;
                     break;
                 }
             }
-            if (paused) {
-                status = SyncthingStatus::Paused;
-            } else {
-                status = SyncthingStatus::Idle;
-            }
         }
     }
-    if (m_status != status) {
+    if (m_status != status || status == SyncthingStatus::Disconnected) {
+        // emit event if status changed and always for disconnects so isConnecting() is re-evaluated
         emit statusChanged(m_status = status);
     }
 }
 
-/*!
- * \brief Interanlly called to emit the notification with the specified \a message.
- * \remarks Ensures the status is updated and the unread notifications flag is set.
- */
-void SyncthingConnection::emitNotification(DateTime when, const QString &message)
-{
-    m_unreadNotifications = true;
-    emit newNotification(when, message);
-    recalculateStatus();
-}
-
 /*!
  * \brief Internally called to emit a JSON parsing error.
  * \remarks Since in this case the reply has already been read, its response must be passed as extra argument.
@@ -885,6 +971,7 @@ void SyncthingConnection::emitMyIdChanged(const QString &newId)
         if (dev.id == newId) {
             if (dev.status != SyncthingDevStatus::OwnDevice) {
                 dev.status = SyncthingDevStatus::OwnDevice;
+                dev.paused = false;
                 emit devStatusChanged(dev, row);
             }
         } else if (dev.status == SyncthingDevStatus::OwnDevice) {
@@ -897,6 +984,19 @@ void SyncthingConnection::emitMyIdChanged(const QString &newId)
     emit myIdChanged(m_myId = newId);
 }
 
+/*!
+ * \brief Internally called to emit tildeChanged() signal.
+ */
+void SyncthingConnection::emitTildeChanged(const QString &newTilde, const QString &newPathSeparator)
+{
+    if ((newTilde.isEmpty() || m_tilde == newTilde) && (newPathSeparator.isEmpty() && m_pathSeparator == newPathSeparator)) {
+        return;
+    }
+    m_tilde = newTilde;
+    m_pathSeparator = newPathSeparator;
+    emit tildeChanged(m_tilde);
+}
+
 /*!
  * \brief Internally called to emit dirStatisticsChanged() event.
  */
@@ -921,7 +1021,7 @@ void SyncthingConnection::handleFatalConnectionError()
 }
 
 /*!
- * \brief Handles cancelation of additional requests done via continueConnecting() method.
+ * \brief Handles cancellation of additional requests done via continueConnecting() method.
  */
 void SyncthingConnection::handleAdditionalRequestCanceled()
 {
@@ -939,13 +1039,12 @@ void SyncthingConnection::handleAdditionalRequestCanceled()
 }
 
 /*!
- * \brief Internally called to recalculate the overall connection status, eg. after the status of a directory
+ * \brief Internally called to recalculate the overall connection status, e.g. after the status of a directory
  *        changed.
  * \remarks
  * - This is achieved by simply setting the status to idle. setStatus() will calculate the specific status.
  * - If not connected, this method does nothing. This is important, because when this method is called when
- *   establishing a connection (and the status is hence still disconnected) timers for polling would be
- *   killed.
+ *   establishing a connection (and the status is hence still disconnected) timers for polling would be killed.
  */
 void SyncthingConnection::recalculateStatus()
 {
@@ -1019,7 +1118,7 @@ void SyncthingConnection::recalculateStatus()
 
 /*!
  * \fn SyncthingConnection::statusChanged()
- * \brief Indicates the status of the connection changed.
+ * \brief Indicates the status of the connection changed (status(), hasOutOfSyncDirs()).
  */
 
 /*!
@@ -1032,6 +1131,11 @@ void SyncthingConnection::recalculateStatus()
  * \brief Indicates ID of the own Syncthing device changed.
  */
 
+/*!
+ * \fn SyncthingConnection::tildeChanged()
+ * \brief Indicates the tilde or path separator of the connected Syncthing instance changed.
+ */
+
 /*!
  * \fn SyncthingConnection::trafficChanged()
  * \brief Indicates totalIncomingTraffic() or totalOutgoingTraffic() has changed.
@@ -1039,25 +1143,25 @@ void SyncthingConnection::recalculateStatus()
 
 /*!
  * \fn SyncthingConnection::newConfigTriggered()
- * \brief Indicates a new configuration has posted sucessfully via postConfig().
+ * \brief Indicates a new configuration has posted successfully via postConfig().
  * \remarks In contrast to newConfig(), this signal is only emitted for configuration changes internally posted via postConfig().
  */
 
 /*!
  * \fn SyncthingConnection::rescanTriggered()
- * \brief Indicates a rescan has been triggered sucessfully.
+ * \brief Indicates a rescan has been triggered successfully.
  * \remarks Only emitted for rescans triggered internally via rescan() or rescanAll().
  */
 
 /*!
  * \fn SyncthingConnection::pauseTriggered()
- * \brief Indicates a device has been paused sucessfully.
+ * \brief Indicates a device has been paused successfully.
  * \remarks Only emitted for pausing triggered internally via pause() or pauseAll().
  */
 
 /*!
  * \fn SyncthingConnection::resumeTriggered()
- * \brief Indicates a device has been resumed sucessfully.
+ * \brief Indicates a device has been resumed successfully.
  * \remarks Only emitted for resuming triggered internally via resume() or resumeAll().
  */
 
