@@ -1,9 +1,13 @@
 #ifndef SYNCTHINGCONNECTION_H
 #define SYNCTHINGCONNECTION_H
 
+#include "./syncthingconnectionstatus.h"
 #include "./syncthingdev.h"
 #include "./syncthingdir.h"
 
+#include <c++utilities/misc/flagenumclass.h>
+
+#include <QByteArray>
 #include <QJsonObject>
 #include <QList>
 #include <QNetworkRequest>
@@ -11,6 +15,7 @@
 #include <QSslError>
 #include <QTimer>
 
+#include <cstdint>
 #include <functional>
 #include <limits>
 #include <vector>
@@ -25,26 +30,17 @@ QT_FORWARD_DECLARE_CLASS(QJsonParseError)
 class ConnectionTests;
 class MiscTests;
 
+#define SYNCTHING_CONNECTOR_ENUM_CLASS enum class
+namespace Data {
+SYNCTHING_CONNECTOR_ENUM_CLASS SyncthingStatusComputionFlags : quint64;
+}
+#undef SYNCTHING_CONNECTOR_ENUM_CLASS
+
 namespace Data {
-#undef Q_NAMESPACE
-#define Q_NAMESPACE
-Q_NAMESPACE
-extern LIB_SYNCTHING_CONNECTOR_EXPORT const QMetaObject staticMetaObject;
-QT_ANNOTATE_CLASS(qt_qnamespace, "") /*end*/
 
 struct SyncthingConnectionSettings;
 
-QNetworkAccessManager LIB_SYNCTHING_CONNECTOR_EXPORT &networkAccessManager();
-
-enum class SyncthingStatus { Disconnected, Reconnecting, Idle, Scanning, Paused, Synchronizing, OutOfSync, BeingDestroyed };
-#if (QT_VERSION >= QT_VERSION_CHECK(5, 8, 0))
-Q_ENUM_NS(SyncthingStatus)
-#endif
-
-enum class SyncthingErrorCategory { OverallConnection, SpecificRequest, Parsing };
-#if (QT_VERSION >= QT_VERSION_CHECK(5, 8, 0))
-Q_ENUM_NS(SyncthingErrorCategory)
-#endif
+LIB_SYNCTHING_CONNECTOR_EXPORT QNetworkAccessManager &networkAccessManager();
 
 struct LIB_SYNCTHING_CONNECTOR_EXPORT SyncthingLogEntry {
     SyncthingLogEntry(const QString &when = QString(), const QString &message = QString())
@@ -56,6 +52,22 @@ struct LIB_SYNCTHING_CONNECTOR_EXPORT SyncthingLogEntry {
     QString message;
 };
 
+enum class SyncthingConnectionLoggingFlags : quint64 {
+    None, /**< loggingn is disabled */
+    FromEnvironment = (1 << 0), /**< environment variables are checked to pull in any of the other flags dynamically */
+    ApiCalls = (1 << 1), /**< log calls to Syncthing's REST-API and responses */
+    ApiReplies = (1 << 2), /**< log replies fromm Syncthing's REST-API */
+    Events = (1 << 3), /**< log events received via Syncthing's event API */
+    DirsOrDevsResetted = (1 << 4), /**< log list of directories/devices when list is reset */
+    All = ApiCalls | ApiReplies | Events | DirsOrDevsResetted, /** log as much as possible */
+};
+
+} // namespace Data
+
+CPP_UTILITIES_MARK_FLAG_ENUM_CLASS(Data, Data::SyncthingConnectionLoggingFlags)
+
+namespace Data {
+
 class LIB_SYNCTHING_CONNECTOR_EXPORT SyncthingConnection : public QObject {
     friend ConnectionTests;
     friend MiscTests;
@@ -67,8 +79,12 @@ class LIB_SYNCTHING_CONNECTOR_EXPORT SyncthingConnection : public QObject {
     Q_PROPERTY(QString user READ user)
     Q_PROPERTY(QString password READ password)
     Q_PROPERTY(Data::SyncthingStatus status READ status NOTIFY statusChanged)
+    Q_PROPERTY(Data::SyncthingStatusComputionFlags statusComputionFlags READ statusComputionFlags WRITE setStatusComputionFlags)
+    Q_PROPERTY(Data::SyncthingConnectionLoggingFlags loggingFlags READ loggingFlags WRITE setLoggingFlags)
     Q_PROPERTY(QString statusText READ statusText NOTIFY statusChanged)
     Q_PROPERTY(bool connected READ isConnected NOTIFY statusChanged)
+    Q_PROPERTY(bool connecting READ isConnecting NOTIFY statusChanged)
+    Q_PROPERTY(bool aborted READ isAborted NOTIFY statusChanged)
     Q_PROPERTY(bool hasUnreadNotifications READ hasUnreadNotifications)
     Q_PROPERTY(bool hasOutOfSyncDirs READ hasOutOfSyncDirs)
     Q_PROPERTY(bool requestingCompletionEnabled READ isRequestingCompletionEnabled WRITE setRequestingCompletionEnabled)
@@ -76,10 +92,13 @@ class LIB_SYNCTHING_CONNECTOR_EXPORT SyncthingConnection : public QObject {
     Q_PROPERTY(unsigned int autoReconnectTries READ autoReconnectTries)
     Q_PROPERTY(int trafficPollInterval READ trafficPollInterval WRITE setTrafficPollInterval)
     Q_PROPERTY(int devStatsPollInterval READ devStatsPollInterval WRITE setDevStatsPollInterval)
+    Q_PROPERTY(bool recordFileChanges READ recordFileChanges WRITE setRecordFileChanges)
     Q_PROPERTY(QString myId READ myId NOTIFY myIdChanged)
+    Q_PROPERTY(QString tilde READ tilde NOTIFY tildeChanged)
+    Q_PROPERTY(QString pathSeparator READ pathSeparator NOTIFY tildeChanged)
     Q_PROPERTY(QString configDir READ configDir NOTIFY configDirChanged)
-    Q_PROPERTY(int totalIncomingTraffic READ totalIncomingTraffic NOTIFY trafficChanged)
-    Q_PROPERTY(int totalOutgoingTraffic READ totalOutgoingTraffic NOTIFY trafficChanged)
+    Q_PROPERTY(quint64 totalIncomingTraffic READ totalIncomingTraffic NOTIFY trafficChanged)
+    Q_PROPERTY(quint64 totalOutgoingTraffic READ totalOutgoingTraffic NOTIFY trafficChanged)
     Q_PROPERTY(double totalIncomingRate READ totalIncomingRate NOTIFY trafficChanged)
     Q_PROPERTY(double totalOutgoingRate READ totalOutgoingRate NOTIFY trafficChanged)
     Q_PROPERTY(QString lastSyncedFile READ lastSyncedFile)
@@ -92,8 +111,8 @@ class LIB_SYNCTHING_CONNECTOR_EXPORT SyncthingConnection : public QObject {
     Q_PROPERTY(QJsonObject rawConfig READ rawConfig NOTIFY newConfig)
 
 public:
-    explicit SyncthingConnection(
-        const QString &syncthingUrl = QStringLiteral("http://localhost:8080"), const QByteArray &apiKey = QByteArray(), QObject *parent = nullptr);
+    explicit SyncthingConnection(const QString &syncthingUrl = QStringLiteral("http://localhost:8080"), const QByteArray &apiKey = QByteArray(),
+        SyncthingConnectionLoggingFlags loggingFlags = SyncthingConnectionLoggingFlags::FromEnvironment, QObject *parent = nullptr);
     ~SyncthingConnection() override;
 
     // getter/setter for
@@ -110,7 +129,13 @@ public:
     SyncthingStatus status() const;
     QString statusText() const;
     static QString statusText(SyncthingStatus status);
+    SyncthingStatusComputionFlags statusComputionFlags() const;
+    void setStatusComputionFlags(SyncthingStatusComputionFlags flags);
+    SyncthingConnectionLoggingFlags loggingFlags() const;
+    void setLoggingFlags(SyncthingConnectionLoggingFlags flags);
     bool isConnected() const;
+    bool isAborted() const;
+    bool isConnecting() const;
     bool hasPendingRequests() const;
     bool hasPendingRequestsIncludingEvents() const;
     bool hasUnreadNotifications() const;
@@ -129,10 +154,14 @@ public:
     unsigned int autoReconnectTries() const;
     void setAutoReconnectInterval(int interval);
     void disablePolling();
+    bool recordFileChanges() const;
+    void setRecordFileChanges(bool recordFileChanges);
 
     // getter for information retrieved from Syncthing
     const QString &configDir() const;
     const QString &myId() const;
+    const QString &tilde() const;
+    const QString &pathSeparator() const;
     std::uint64_t totalIncomingTraffic() const;
     std::uint64_t totalOutgoingTraffic() const;
     double totalIncomingRate() const;
@@ -218,6 +247,7 @@ Q_SIGNALS:
     void newEvents(const QJsonArray &events);
     void dirStatusChanged(const SyncthingDir &dir, int index);
     void devStatusChanged(const SyncthingDev &dev, int index);
+    void fileChanged(const SyncthingDir &dir, int index, const SyncthingFileChange &fileChange);
     void downloadProgressChanged();
     void dirStatisticsChanged();
     void dirCompleted(CppUtilities::DateTime when, const SyncthingDir &dir, int index, const SyncthingDev *remoteDev = nullptr);
@@ -229,6 +259,7 @@ Q_SIGNALS:
     void statusChanged(SyncthingStatus newStatus);
     void configDirChanged(const QString &newConfigDir);
     void myIdChanged(const QString &myNewId);
+    void tildeChanged(const QString &tilde);
     void trafficChanged(std::uint64_t totalIncomingTraffic, std::uint64_t totalOutgoingTraffic);
     void newConfigTriggered();
     void rescanTriggered(const QString &dirId);
@@ -264,11 +295,15 @@ private Q_SLOTS:
     void readItemStarted(CppUtilities::DateTime eventTime, const QJsonObject &eventData);
     void readItemFinished(CppUtilities::DateTime eventTime, const QJsonObject &eventData);
     void readFolderErrors(CppUtilities::DateTime eventTime, const QJsonObject &eventData, SyncthingDir &dirInfo, int index);
-    void readFolderCompletion(CppUtilities::DateTime eventTime, const QJsonObject &eventData, SyncthingDir &dirInfo, int index);
-    void readFolderCompletion(CppUtilities::DateTime eventTime, const QJsonObject &eventData, SyncthingDir &dirInfo, int index, const QString &devId);
+    void readFolderCompletion(
+        CppUtilities::DateTime eventTime, const QJsonObject &eventData, const QString &dirId, SyncthingDir *dirInfo, int dirIndex);
+    void readFolderCompletion(CppUtilities::DateTime eventTime, const QJsonObject &eventData, const QString &devId, SyncthingDev *devInfo,
+        int devIndex, const QString &dirId, SyncthingDir *dirInfo, int dirIndex);
     void readLocalFolderCompletion(CppUtilities::DateTime eventTime, const QJsonObject &eventData, SyncthingDir &dirInfo, int index);
-    void readRemoteFolderCompletion(
-        CppUtilities::DateTime eventTime, const QJsonObject &eventData, SyncthingDir &dirInfo, int index, const QString &devId);
+    void readRemoteFolderCompletion(CppUtilities::DateTime eventTime, const QJsonObject &eventData, const QString &devId, SyncthingDev *devInfo,
+        int devIndex, const QString &dirId, SyncthingDir *dirInfo, int dirIndex);
+    void readRemoteFolderCompletion(const SyncthingCompletion &completion, const QString &devId, SyncthingDev *devInfo, int devIndex,
+        const QString &dirId, SyncthingDir *dirInfo, int dirIndex);
     void readRemoteIndexUpdated(CppUtilities::DateTime eventTime, const QJsonObject &eventData);
     void readPostConfig();
     void readRescan();
@@ -297,31 +332,45 @@ private Q_SLOTS:
     void emitError(const QString &message, const QJsonParseError &jsonError, QNetworkReply *reply, const QByteArray &response = QByteArray());
     void emitError(const QString &message, SyncthingErrorCategory category, QNetworkReply *reply);
     void emitMyIdChanged(const QString &newId);
+    void emitTildeChanged(const QString &newTilde, const QString &newPathSeparator);
     void emitDirStatisticsChanged();
     void handleFatalConnectionError();
     void handleAdditionalRequestCanceled();
+    void handleSslErrors(const QList<QSslError> &errors);
     void recalculateStatus();
 
 private:
     // internal helper methods
+    struct Reply {
+        QNetworkReply *reply;
+        QByteArray response;
+    };
     QNetworkRequest prepareRequest(const QString &path, const QUrlQuery &query, bool rest = true);
     QNetworkReply *requestData(const QString &path, const QUrlQuery &query, bool rest = true);
     QNetworkReply *postData(const QString &path, const QUrlQuery &query, const QByteArray &data = QByteArray());
-    QNetworkReply *prepareReply();
-    QNetworkReply *prepareReply(QNetworkReply *&expectedReply);
-    QNetworkReply *prepareReply(QList<QNetworkReply *> &expectedReplies);
+    Reply prepareReply(bool readData = true, bool handleAborting = true);
+    Reply prepareReply(QNetworkReply *&expectedReply, bool readData = true, bool handleAborting = true);
+    Reply prepareReply(QList<QNetworkReply *> &expectedReplies, bool readData = true, bool handleAborting = true);
+    Reply handleReply(QNetworkReply *reply, bool readData, bool handleAborting);
     bool pauseResumeDevice(const QStringList &devIds, bool paused);
     bool pauseResumeDirectory(const QStringList &dirIds, bool paused);
     SyncthingDir *addDirInfo(std::vector<SyncthingDir> &dirs, const QString &dirId);
     SyncthingDev *addDevInfo(std::vector<SyncthingDev> &devs, const QString &devId);
+    CppUtilities::DateTime parseTimeStamp(const QJsonValue &jsonValue, const QString &context,
+        CppUtilities::DateTime defaultValue = CppUtilities::DateTime(), bool greaterThanEpoch = false);
 
     QString m_syncthingUrl;
     QByteArray m_apiKey;
     QString m_user;
     QString m_password;
     SyncthingStatus m_status;
+    SyncthingStatusComputionFlags m_statusComputionFlags;
+    SyncthingConnectionLoggingFlags m_loggingFlags;
+    SyncthingConnectionLoggingFlags m_loggingFlagsHandler;
+
     bool m_keepPolling;
     bool m_abortingAllRequests;
+    bool m_connectionAborted;
     bool m_abortingToReconnect;
     bool m_requestCompletion;
     int m_lastEventId;
@@ -333,6 +382,8 @@ private:
     unsigned int m_autoReconnectTries;
     QString m_configDir;
     QString m_myId;
+    QString m_tilde;
+    QString m_pathSeparator;
     std::uint64_t m_totalIncomingTraffic;
     std::uint64_t m_totalOutgoingTraffic;
     double m_totalIncomingRate;
@@ -363,8 +414,10 @@ private:
     QString m_syncthingVersion;
     bool m_lastFileDeleted;
     QList<QSslError> m_expectedSslErrors;
+    QSslCertificate m_certFromLastSslError;
     QJsonObject m_rawConfig;
     bool m_dirStatsAltered;
+    bool m_recordFileChanges;
 };
 
 /*!
@@ -433,7 +486,8 @@ inline QString SyncthingConnection::statusText() const
 }
 
 /*!
- * \brief Returns the connection status.
+ * \brief Returns the (pre-computed) connection status.
+ * \sa See SyncthingConnection::setStatus() and SyncthingStatus for details how it is computed.
  */
 inline SyncthingStatus SyncthingConnection::status() const
 {
@@ -443,22 +497,39 @@ inline SyncthingStatus SyncthingConnection::status() const
 /*!
  * \brief Returns whether the connection to Syncthing has been established.
  *
- * If ture, all information like dirInfo() and devInfo() has been populated and will be updated if it changes.
+ * If true, all information like dirInfo() and devInfo() has been populated and will be updated if it changes.
  */
 inline bool SyncthingConnection::isConnected() const
 {
     return m_status != SyncthingStatus::Disconnected && m_status != SyncthingStatus::Reconnecting;
 }
 
+/*!
+ * \brief Returns whether the connection has been aborted, either by invoking disconnect(), abortAllRequests() or
+ *        by an error.
+ */
+inline bool SyncthingConnection::isAborted() const
+{
+    return m_connectionAborted;
+}
+
+/*!
+ * \brief Returns whether the connection is currently being established (and has not been established yet).
+ */
+inline bool SyncthingConnection::isConnecting() const
+{
+    return !isConnected() && !isAborted() && hasPendingRequests();
+}
+
 /*!
  * \brief Returns whether the SyncthingConnector instance is waiting for Syncthing to respond to a request.
  * \remarks
  * - Requests for (disk) events are excluded because those are long polling requests and therefore always pending.
  *   Instead, we take only into account whether those requests have been at least concluded once (since the last
  *   reconnect).
- * - Only requests which contribute to the overall state and population of myId(), dirInfo(), devInfo(), traffic
- *   statistics, ... are considered. So requests for QR code, logs, clearing errors, rescan, ... are not taken
- *   into account.
+ * - Only requests which contribute to the overall state and population of myId(), tilde(), dirInfo(), devInfo(),
+ *   traffic statistics, ... are considered. So requests for QR code, logs, clearing errors, rescan, ... are not
+ *   taken into account.
  * - This function will also return true as long as the method abortAllRequests() is executed.
  */
 inline bool SyncthingConnection::hasPendingRequests() const
@@ -494,6 +565,16 @@ inline void SyncthingConnection::setRequestingCompletionEnabled(bool requestingC
     m_requestCompletion = requestingCompletionEnabled;
 }
 
+/*!
+ * \brief Internally called to emit the notification with the specified \a message.
+ * \remarks Ensures the unread notifications flag is set.
+ */
+inline void SyncthingConnection::emitNotification(CppUtilities::DateTime when, const QString &message)
+{
+    m_unreadNotifications = true;
+    emit newNotification(when, message);
+}
+
 /*!
  * \brief Considers all notifications as read; hence might trigger a status update.
  */
@@ -595,6 +676,51 @@ inline void SyncthingConnection::setAutoReconnectInterval(int interval)
     m_autoReconnectTimer.setInterval(interval);
 }
 
+/*!
+ * \brief Returns whether file changes are recorded for each directory so SyncthingDir::recentChanges is being populated.
+ * \remarks The fileChanged() signal is unaffected.
+ */
+inline bool SyncthingConnection::recordFileChanges() const
+{
+    return m_recordFileChanges;
+}
+
+/*!
+ * \brief Returns whether file changes are recorded for each directory so SyncthingDir::recentChanges is being populated.
+ * \remarks The fileChanged() signal is unaffected.
+ */
+inline void SyncthingConnection::setRecordFileChanges(bool recordFileChanges)
+{
+    m_recordFileChanges = recordFileChanges;
+}
+
+/*!
+ * \brief Returns what information is considered to compute the overall status returned by status().
+ */
+inline SyncthingStatusComputionFlags SyncthingConnection::statusComputionFlags() const
+{
+    return m_statusComputionFlags;
+}
+
+/*!
+ * \brief Sets what information should be used to compute the overall status returned by status().
+ */
+inline void SyncthingConnection::setStatusComputionFlags(SyncthingStatusComputionFlags flags)
+{
+    if (m_statusComputionFlags != flags) {
+        m_statusComputionFlags = flags;
+        recalculateStatus();
+    }
+}
+
+/*!
+ * \brief Returns the currently active logging flags.
+ */
+inline SyncthingConnectionLoggingFlags SyncthingConnection::loggingFlags() const
+{
+    return m_loggingFlags;
+}
+
 /*!
  * \brief Returns the Syncthing home/configuration directory.
  */
@@ -611,6 +737,22 @@ inline const QString &SyncthingConnection::myId() const
     return m_myId;
 }
 
+/*!
+ * \brief Returns the substitution for "~" of the Syncthing instance.
+ */
+inline const QString &SyncthingConnection::tilde() const
+{
+    return m_tilde;
+}
+
+/*!
+ * \brief Returns the path separator of the Syncthing instance.
+ */
+inline const QString &SyncthingConnection::pathSeparator() const
+{
+    return m_pathSeparator;
+}
+
 /*!
  * \brief Returns the total incoming traffic in byte.
  */
@@ -700,7 +842,7 @@ inline CppUtilities::DateTime SyncthingConnection::startTime() const
  */
 inline CppUtilities::TimeSpan SyncthingConnection::uptime() const
 {
-    return CppUtilities::DateTime::gmtNow() - m_startTime;
+    return m_startTime.isNull() ? CppUtilities::TimeSpan() : CppUtilities::DateTime::now() - m_startTime;
 }
 
 /*!
