@@ -78,9 +78,9 @@ public:
     void tearDown() override;
 
 private:
-    template <typename Action, typename... Signalinfo> void waitForConnection(Action action, int timeout, const Signalinfo &... signalInfo);
+    template <typename Action, typename... Signalinfo> void waitForConnection(Action action, int timeout, const Signalinfo &...signalInfo);
     template <typename Action, typename FailureSignalInfo, typename... Signalinfo>
-    void waitForConnectionOrFail(Action action, int timeout, const FailureSignalInfo &failureSignalInfo, const Signalinfo &... signalInfo);
+    void waitForConnectionOrFail(Action action, int timeout, const FailureSignalInfo &failureSignalInfo, const Signalinfo &...signalInfo);
     template <typename Signal, typename Handler = function<void(void)>>
     SignalInfo<Signal, Handler> connectionSignal(
         Signal signal, const Handler &handler = function<void(void)>(), bool *correctSignalEmitted = nullptr);
@@ -118,7 +118,7 @@ void ConnectionTests::setUp()
     SyncthingTestInstance::start();
 
     cerr << "\n - Preparing connection ..." << endl;
-    m_connection.setSyncthingUrl(QStringLiteral("http://localhost:") + syncthingPort());
+    m_connection.setSyncthingUrl(QStringLiteral("http://127.0.0.1:") + syncthingPort());
 
     // keep track of status changes
     QObject::connect(&m_connection, &SyncthingConnection::statusChanged,
@@ -154,7 +154,7 @@ void ConnectionTests::tearDown()
  * \brief Variant of waitForSignal() where the sender is the connection and the action is a method of the connection.
  */
 template <typename Action, typename... SignalInfo>
-void ConnectionTests::waitForConnection(Action action, int timeout, const SignalInfo &... signalInfo)
+void ConnectionTests::waitForConnection(Action action, int timeout, const SignalInfo &...signalInfo)
 {
     waitForSignals(bind(action, &m_connection), timeout, signalInfo...);
 }
@@ -163,8 +163,7 @@ void ConnectionTests::waitForConnection(Action action, int timeout, const Signal
  * \brief Variant of waitForSignalOrFail() where the sender is the connection and the action is a method of the connection.
  */
 template <typename Action, typename FailureSignalInfo, typename... SignalInfo>
-void ConnectionTests::waitForConnectionOrFail(
-    Action action, int timeout, const FailureSignalInfo &failureSignalInfo, const SignalInfo &... signalInfo)
+void ConnectionTests::waitForConnectionOrFail(Action action, int timeout, const FailureSignalInfo &failureSignalInfo, const SignalInfo &...signalInfo)
 {
     waitForSignalsOrFail(bind(action, &m_connection), timeout, failureSignalInfo, signalInfo...);
 }
@@ -320,7 +319,7 @@ void ConnectionTests::testConnection()
 
 void ConnectionTests::testErrorCases()
 {
-    cerr << "\n - Error handling in case of insufficient conficuration ..." << endl;
+    cerr << "\n - Error handling in case of insufficient configuration ..." << endl;
     waitForConnection(defaultConnect(), 1000, connectionSignal(&SyncthingConnection::error, [](const QString &errorMessage) {
         CPPUNIT_ASSERT_EQUAL(QStringLiteral("Connection configuration is insufficient."), errorMessage);
     }));
@@ -338,9 +337,9 @@ void ConnectionTests::testErrorCases()
         // check whether Syncthing is available
         if ((errorMessage == QStringLiteral("Unable to request Syncthing status: Connection refused"))
             || (errorMessage == QStringLiteral("Unable to request Syncthing config: Connection refused"))) {
-            // consider test failed if we receive "Connection refused" when another error has already occured
+            // consider test failed if we receive "Connection refused" when another error has already occurred
             if (syncthingAvailable) {
-                CPPUNIT_FAIL("Syncthing became unavailable after another error had already occured");
+                CPPUNIT_FAIL("Syncthing became unavailable after another error had already occurred");
             }
 
             // consider test failed if Syncthing takes too long to come up (or we fail to connect)
@@ -444,7 +443,7 @@ void ConnectionTests::checkDevices()
             CPPUNIT_ASSERT_EQUAL_MESSAGE("paused device", QStringLiteral("paused"), dev.statusString());
             CPPUNIT_ASSERT_EQUAL_MESSAGE("name", QStringLiteral("Test dev 2"), dev.name);
             CPPUNIT_ASSERT_MESSAGE("no introducer", !dev.introducer);
-            CPPUNIT_ASSERT_EQUAL(1, dev.addresses.size());
+            CPPUNIT_ASSERT_EQUAL(static_cast<decltype(dev.addresses.size())>(1), dev.addresses.size());
             CPPUNIT_ASSERT_EQUAL(QStringLiteral("tcp://192.168.2.2:22001"), dev.addresses.front());
             dev2 = &dev;
             dev2Index = index;
@@ -452,7 +451,7 @@ void ConnectionTests::checkDevices()
             CPPUNIT_ASSERT_EQUAL_MESSAGE("disconnected device", QStringLiteral("disconnected"), dev.statusString());
             CPPUNIT_ASSERT_EQUAL_MESSAGE("name", QStringLiteral("Test dev 1"), dev.name);
             CPPUNIT_ASSERT_MESSAGE("introducer", dev.introducer);
-            CPPUNIT_ASSERT_EQUAL(1, dev.addresses.size());
+            CPPUNIT_ASSERT_EQUAL(static_cast<decltype(dev.addresses.size())>(1), dev.addresses.size());
             CPPUNIT_ASSERT_EQUAL(QStringLiteral("dynamic"), dev.addresses.front());
             dev1 = &dev;
             dev1Index = index;
@@ -480,10 +479,17 @@ void ConnectionTests::checkDirectories() const
     CPPUNIT_ASSERT_EQUAL(QStringLiteral("idle"), dir1.statusString());
     CPPUNIT_ASSERT_EQUAL(SyncthingDirType::SendReceive, dir1.dirType);
     CPPUNIT_ASSERT(!dir1.paused);
+#if QT_VERSION < QT_VERSION_CHECK(5, 14, 0)
+    const auto devIds = dir1.deviceIds.toSet();
+    const auto devNames = dir1.deviceNames.toSet();
+#else
+    const auto devIds = QSet(dir1.deviceIds.begin(), dir1.deviceIds.end());
+    const auto devNames = QSet(dir1.deviceNames.begin(), dir1.deviceNames.end());
+#endif
     CPPUNIT_ASSERT_EQUAL(QSet<QString>({ QStringLiteral("MMGUI6U-WUEZQCP-XZZ6VYB-LCT4TVC-ER2HAVX-QYT6X7D-S6ZSG2B-323KLQ7"),
                              QStringLiteral("6EIS2PN-J2IHWGS-AXS3YUL-HC5FT3K-77ZXTLL-AKQLJ4C-7SWVPUS-AZW4RQ4") }),
-        dir1.deviceIds.toSet());
-    CPPUNIT_ASSERT_EQUAL(QSet<QString>({ QStringLiteral("Test dev 2"), QStringLiteral("Test dev 1") }), dir1.deviceNames.toSet());
+        devIds);
+    CPPUNIT_ASSERT_EQUAL(QSet<QString>({ QStringLiteral("Test dev 2"), QStringLiteral("Test dev 1") }), devNames);
     const SyncthingDir &dir2 = dirInfo.back();
     CPPUNIT_ASSERT_EQUAL(QStringLiteral("test2"), dir2.id);
     CPPUNIT_ASSERT_EQUAL(QStringLiteral("Test dir 2"), dir2.label);
@@ -493,9 +499,15 @@ void ConnectionTests::checkDirectories() const
     CPPUNIT_ASSERT_EQUAL(QStringLiteral("paused"), dir2.statusString());
     CPPUNIT_ASSERT_EQUAL(SyncthingDirType::SendReceive, dir2.dirType);
     CPPUNIT_ASSERT(dir2.paused);
-    CPPUNIT_ASSERT_EQUAL(
-        QSet<QString>({ QStringLiteral("MMGUI6U-WUEZQCP-XZZ6VYB-LCT4TVC-ER2HAVX-QYT6X7D-S6ZSG2B-323KLQ7") }), dir2.deviceIds.toSet());
-    CPPUNIT_ASSERT_EQUAL(QSet<QString>({ QStringLiteral("Test dev 2") }), dir2.deviceNames.toSet());
+#if QT_VERSION < QT_VERSION_CHECK(5, 14, 0)
+    const auto devIds2 = dir2.deviceIds.toSet();
+    const auto devNames2 = dir2.deviceNames.toSet();
+#else
+    const auto devIds2 = QSet(dir2.deviceIds.begin(), dir2.deviceIds.end());
+    const auto devNames2 = QSet(dir2.deviceNames.begin(), dir2.deviceNames.end());
+#endif
+    CPPUNIT_ASSERT_EQUAL(QSet<QString>({ QStringLiteral("MMGUI6U-WUEZQCP-XZZ6VYB-LCT4TVC-ER2HAVX-QYT6X7D-S6ZSG2B-323KLQ7") }), devIds2);
+    CPPUNIT_ASSERT_EQUAL(QSet<QString>({ QStringLiteral("Test dev 2") }), devNames2);
 }
 
 void ConnectionTests::testReconnecting()
@@ -613,9 +625,17 @@ void ConnectionTests::testRequestingQrCode()
 
 void ConnectionTests::testDisconnecting()
 {
-    cerr << "\n - Disconnecting ..." << endl;
+    cerr << "\n - Disconnecting while there are outstanding requests ..." << endl;
     waitForConnected();
-    waitForConnection(defaultDisconnect(), 1000, connectionSignal(&SyncthingConnection::statusChanged));
+    m_connection.requestVersion();
+    m_connection.requestDirStatistics();
+    waitForSignals(
+        [this] {
+            m_connection.requestDeviceStatistics();
+            m_connection.requestCompletion("MMGUI6U-WUEZQCP-XZZ6VYB-LCT4TVC-ER2HAVX-QYT6X7D-S6ZSG2B-323KLQ7", "test1");
+            QTimer::singleShot(0, &m_connection, defaultDisconnect());
+        },
+        5000, connectionSignal(&SyncthingConnection::statusChanged));
     CPPUNIT_ASSERT_EQUAL_MESSAGE("disconnected", QStringLiteral("disconnected"), m_connection.statusText());
 }
 
