@@ -1,17 +1,19 @@
 #include "./syncthingfileitemactionstaticdata.h"
 
-#include "../model/syncthingicons.h"
+#include <syncthingmodel/syncthingicons.h>
 
-#include "../connector/syncthingconfig.h"
-#include "../connector/syncthingconnection.h"
-#include "../connector/syncthingconnectionsettings.h"
+#include <syncthingconnector/syncthingconfig.h>
+#include <syncthingconnector/syncthingconnection.h>
+#include <syncthingconnector/syncthingconnectionsettings.h>
 
 #include <c++utilities/application/argumentparser.h>
 #include <c++utilities/io/ansiescapecodes.h>
 
 #include <qtutilities/aboutdialog/aboutdialog.h>
+#include <qtutilities/misc/desktoputils.h>
 #include <qtutilities/resources/resources.h>
 
+#include <QAction>
 #include <QFileDialog>
 #include <QInputDialog>
 #include <QMessageBox>
@@ -66,9 +68,6 @@ void SyncthingFileItemActionStaticData::initialize()
         connect(&m_connection, &SyncthingConnection::statusChanged, this, &SyncthingFileItemActionStaticData::logConnectionStatus);
     }
 
-    // use default icon settings
-    IconManager::instance().applySettings();
-
     m_initialized = true;
 }
 
@@ -91,17 +90,21 @@ void SyncthingFileItemActionStaticData::logConnectionError(const QString &errorM
 
 void SyncthingFileItemActionStaticData::rescanDir(const QString &dirId, const QString &relpath)
 {
-    m_connection.rescan(dirId, relpath);
+    int row;
+    const auto *const dirInfo = m_connection.findDirInfo(dirId, row);
+    if (dirInfo && !dirInfo->paused) {
+        m_connection.rescan(dirId, relpath);
+    }
 }
 
 void SyncthingFileItemActionStaticData::showAboutDialog()
 {
     auto *const aboutDialog = new AboutDialog(nullptr, QStringLiteral(APP_NAME),
         QStringLiteral(APP_AUTHOR "<br>Syncthing icons from <a href=\"https://syncthing.net\">Syncthing project</a><br>Using "
-                                  "icons from <a href=\"https://fontawesome.com\">Font "
-                                  "Awesome</a> (see <a href=\"https://fontawesome.com/license\">their license</a>)"),
+                                  "icons from <a href=\"https://forkaweso.me\">Fork "
+                                  "Awesome</a> (see <a href=\"https://forkaweso.me/Fork-Awesome/license\">their license</a>)"),
         QStringLiteral(APP_VERSION), CppUtilities::applicationInfo.dependencyVersions, QStringLiteral(APP_URL), QStringLiteral(APP_DESCRIPTION),
-        renderSvgImage(makeSyncthingIcon()).toImage());
+        renderSvgImage(makeSyncthingIcon(), QSize(128, 128)).toImage());
     aboutDialog->setWindowTitle(tr("About") + QStringLiteral(" - " APP_NAME));
     aboutDialog->setWindowIcon(QIcon::fromTheme(QStringLiteral("syncthingtray")));
     aboutDialog->setAttribute(Qt::WA_DeleteOnClose);
@@ -116,6 +119,11 @@ void SyncthingFileItemActionStaticData::selectSyncthingConfig()
     }
 }
 
+void SyncthingFileItemActionStaticData::handlePaletteChanged(const QPalette &palette)
+{
+    applyBrightCustomColorsSetting(isPaletteDark(palette));
+}
+
 void SyncthingFileItemActionStaticData::appendNoteToError(QString &errorMessage, const QString &newSyncthingConfigFilePath) const
 {
     if (!m_configFilePath.isEmpty() && m_configFilePath != newSyncthingConfigFilePath) {
@@ -171,7 +179,7 @@ bool SyncthingFileItemActionStaticData::applySyncthingConfiguration(
     // make connection settings
     SyncthingConnectionSettings connectionSettings;
     connectionSettings.syncthingUrl = config.syncthingUrl();
-    connectionSettings.apiKey.append(config.guiApiKey);
+    connectionSettings.apiKey.append(config.guiApiKey.toUtf8());
 
     // establish connection
     bool ok;
@@ -192,6 +200,17 @@ bool SyncthingFileItemActionStaticData::applySyncthingConfiguration(
     return true;
 }
 
+void SyncthingFileItemActionStaticData::applyBrightCustomColorsSetting(bool useBrightCustomColors)
+{
+    if (useBrightCustomColors) {
+        static const auto settings = StatusIconSettings(StatusIconSettings::DarkTheme());
+        IconManager::instance().applySettings(&settings);
+    } else {
+        static const auto settings = StatusIconSettings(StatusIconSettings::BrightTheme());
+        IconManager::instance().applySettings(&settings);
+    }
+}
+
 void SyncthingFileItemActionStaticData::setCurrentError(const QString &currentError)
 {
     if (m_currentError == currentError) {
