@@ -1,11 +1,22 @@
 #include "./syncthingicons.h"
 
-#include <QCoreApplication>
+#include "resources/qtconfig.h"
+
+#include <qtutilities/misc/compat.h>
+
+#include <qtforkawesome/icon.h>
+
 #include <QFile>
+#include <QGuiApplication>
 #include <QPainter>
+#include <QPalette>
 #include <QStringBuilder>
 #include <QSvgRenderer>
 
+#ifndef LIB_SYNCTHING_MODEL_STATIC
+ENABLE_QT_RESOURCES_OF_STATIC_DEPENDENCIES
+#endif
+
 namespace Data {
 
 /*!
@@ -16,16 +27,17 @@ QByteArray makeSyncthingIcon(const StatusIconColorSet &colors, StatusEmblem stat
     // serialize colors
     auto gradientStartColor = colors.backgroundStart.name(QColor::HexRgb);
     auto gradientEndColor = colors.backgroundEnd.name(QColor::HexRgb);
-    if (colors.backgroundStart.alphaF() < 1.0) {
-        gradientStartColor += QStringLiteral(";stop-opacity:") + QString::number(colors.backgroundStart.alphaF());
+    constexpr auto opaque = static_cast<decltype(colors.backgroundStart.alphaF())>(1.0);
+    if (colors.backgroundStart.alphaF() < opaque) {
+        gradientStartColor += QStringLiteral(";stop-opacity:") + QString::number(static_cast<double>(colors.backgroundStart.alphaF()));
     }
-    if (colors.backgroundEnd.alphaF() < 1.0) {
-        gradientEndColor += QStringLiteral(";stop-opacity:") + QString::number(colors.backgroundEnd.alphaF());
+    if (colors.backgroundEnd.alphaF() < opaque) {
+        gradientEndColor += QStringLiteral(";stop-opacity:") + QString::number(static_cast<double>(colors.backgroundEnd.alphaF()));
     }
     auto fillColor = colors.foreground.name(QColor::HexRgb);
     auto strokeColor = fillColor;
-    if (colors.foreground.alphaF() < 1.0) {
-        const auto alpha = QString::number(colors.foreground.alphaF());
+    if (colors.foreground.alphaF() < opaque) {
+        const auto alpha = QString::number(static_cast<double>(colors.foreground.alphaF()));
         fillColor += QStringLiteral(";fill-opacity:") + alpha;
         strokeColor += QStringLiteral(";stroke-opacity:") + alpha;
     }
@@ -113,12 +125,18 @@ QByteArray makeSyncthingIcon(const StatusIconColorSet &colors, StatusEmblem stat
 
 /// \cond
 namespace Detail {
-template <typename SourceType> QPixmap renderSvgImage(const SourceType &source, const QSize &size, int margin)
+template <typename SourceType> QPixmap renderSvgImage(const SourceType &source, const QSize &givenSize, int margin)
 {
-    QSvgRenderer renderer(source);
-    QSize renderSize(renderer.defaultSize());
-    renderSize.scale(size.width() - margin, size.height() - margin, Qt::KeepAspectRatio);
-    QRect renderBounds(QPoint(), size);
+    const auto scaleFactor =
+#if (QT_VERSION < QT_VERSION_CHECK(6, 0, 0))
+        !QCoreApplication::testAttribute(Qt::AA_UseHighDpiPixmaps) ? 1.0 :
+#endif
+                                                                   qGuiApp->devicePixelRatio();
+    const auto scaledSize = QSize(givenSize * scaleFactor);
+    auto renderer = QSvgRenderer(source);
+    auto renderSize = QSize(renderer.defaultSize());
+    renderSize.scale(scaledSize.width() - margin, scaledSize.height() - margin, Qt::KeepAspectRatio);
+    auto renderBounds = QRect(QPoint(), scaledSize);
     if (renderSize.width() < renderBounds.width()) {
         const auto diff = (renderBounds.width() - renderSize.width()) / 2;
         renderBounds.setX(diff);
@@ -129,10 +147,11 @@ template <typename SourceType> QPixmap renderSvgImage(const SourceType &source,
         renderBounds.setY(diff);
         renderBounds.setHeight(renderSize.height());
     }
-    QPixmap pm(size);
+    auto pm = QPixmap(scaledSize);
     pm.fill(QColor(Qt::transparent));
-    QPainter painter(&pm);
+    auto painter = QPainter(&pm);
     renderer.render(&painter, renderBounds);
+    pm.setDevicePixelRatio(scaleFactor);
     return pm;
 }
 } // namespace Detail
@@ -156,25 +175,6 @@ QPixmap renderSvgImage(const QByteArray &contents, const QSize &size, int margin
     return Detail::renderSvgImage(contents, size, margin);
 }
 
-/*!
- * \brief Returns the font awesome icon with the specified \a iconName and \a color.
- */
-QByteArray loadFontAwesomeIcon(const QString &iconName, const QColor &color, bool solid)
-{
-    QByteArray result;
-    QFile icon((solid ? QStringLiteral(":/icons/hicolor/scalable/fa/") : QStringLiteral(":/icons/hicolor/scalable/fa-non-solid/")) % iconName
-        % QStringLiteral(".svg"));
-    if (!icon.open(QFile::ReadOnly)) {
-        return result;
-    }
-    result = icon.readAll();
-    const auto pathBegin = result.indexOf("<path ");
-    if (pathBegin > 0) {
-        result.insert(pathBegin + 6, QStringLiteral("fill=\"") % color.name(QColor::HexRgb) % QStringLiteral("\" "));
-    }
-    return result;
-}
-
 StatusIconSettings::StatusIconSettings()
     : defaultColor({ QStringLiteral("#26B6DB"), QStringLiteral("#0882C8"), QStringLiteral("#FFFFFF") })
     , errorColor({ QStringLiteral("#DB3C26"), QStringLiteral("#C80828"), QStringLiteral("#FFFFFF") })
@@ -187,6 +187,30 @@ StatusIconSettings::StatusIconSettings()
 {
 }
 
+StatusIconSettings::StatusIconSettings(StatusIconSettings::DarkTheme)
+    : defaultColor({ QStringLiteral("#00000000"), QStringLiteral("#00000000"), QStringLiteral("#FFFFFFFF") })
+    , errorColor({ QStringLiteral("#00000000"), QStringLiteral("#00000000"), QStringLiteral("#FFFFAEA5") })
+    , warningColor({ QStringLiteral("#00FFFFFF"), QStringLiteral("#00FFFFFF"), QStringLiteral("#FFFFF6A5") })
+    , idleColor({ QStringLiteral("#00FFFFFF"), QStringLiteral("#00FFFFFF"), QStringLiteral("#FFFFFFFF") })
+    , scanningColor({ QStringLiteral("#00FFFFFF"), QStringLiteral("#00FFFFFF"), QStringLiteral("#FFA5EFFF") })
+    , synchronizingColor({ QStringLiteral("#00FFFFFF"), QStringLiteral("#00FFFFFF"), QStringLiteral("#FFA5EFFF") })
+    , pausedColor({ QStringLiteral("#00000000"), QStringLiteral("#00FFFFFF"), QStringLiteral("#FFA7A7A7") })
+    , disconnectedColor({ QStringLiteral("#00000000"), QStringLiteral("#00000000"), QStringLiteral("#FFA7A7A7") })
+{
+}
+
+StatusIconSettings::StatusIconSettings(StatusIconSettings::BrightTheme)
+    : defaultColor({ QStringLiteral("#00FFFFFF"), QStringLiteral("#00FFFFFF"), QStringLiteral("#FF000000") })
+    , errorColor({ QStringLiteral("#00FFFFFF"), QStringLiteral("#00FFFFFF"), QStringLiteral("#FFDB3C26") })
+    , warningColor({ QStringLiteral("#00000000"), QStringLiteral("#00000000"), QStringLiteral("#FFC9CE3B") })
+    , idleColor({ QStringLiteral("#00000000"), QStringLiteral("#00000000"), QStringLiteral("#FF000000") })
+    , scanningColor({ QStringLiteral("#00000000"), QStringLiteral("#00000000"), QStringLiteral("#FF26B6DB") })
+    , synchronizingColor({ QStringLiteral("#00000000"), QStringLiteral("#00000000"), QStringLiteral("#FF26B6DB") })
+    , pausedColor({ QStringLiteral("#00FFFFFF"), QStringLiteral("#00FFFFFF"), QStringLiteral("#FFA7A7A7") })
+    , disconnectedColor({ QStringLiteral("#00FFFFFF"), QStringLiteral("#00FFFFFF"), QStringLiteral("#FFA7A7A7") })
+{
+}
+
 std::vector<StatusIconSettings::ColorMapping> StatusIconSettings::colorMapping()
 {
     return std::vector<ColorMapping>({
@@ -204,7 +228,7 @@ std::vector<StatusIconSettings::ColorMapping> StatusIconSettings::colorMapping()
 StatusIconSettings::StatusIconSettings(const QString &str)
     : StatusIconSettings()
 {
-    const auto parts = str.splitRef(QChar(';'));
+    const auto parts = QtUtilities::splitRef(str, QChar(';'));
     int index = 0;
     for (auto *field :
         { &defaultColor, &errorColor, &warningColor, &idleColor, &scanningColor, &synchronizingColor, &pausedColor, &disconnectedColor }) {
@@ -239,54 +263,70 @@ QString StatusIconSettings::toString() const
 }
 
 StatusIcons::StatusIcons(const StatusIconSettings &settings)
-    : disconnected(QIcon(renderSvgImage(makeSyncthingIcon(settings.disconnectedColor, StatusEmblem::None))))
-    , idling(QIcon(renderSvgImage(makeSyncthingIcon(settings.idleColor, StatusEmblem::None))))
-    , scanninig(QIcon(renderSvgImage(makeSyncthingIcon(settings.scanningColor, StatusEmblem::Scanning))))
-    , notify(QIcon(renderSvgImage(makeSyncthingIcon(settings.warningColor, StatusEmblem::Alert))))
-    , pause(QIcon(renderSvgImage(makeSyncthingIcon(settings.pausedColor, StatusEmblem::Paused))))
-    , sync(QIcon(renderSvgImage(makeSyncthingIcon(settings.synchronizingColor, StatusEmblem::Synchronizing))))
-    , syncComplete(QIcon(renderSvgImage(makeSyncthingIcon(settings.defaultColor, StatusEmblem::Complete))))
-    , error(QIcon(renderSvgImage(makeSyncthingIcon(settings.errorColor, StatusEmblem::Alert))))
-    , errorSync(QIcon(renderSvgImage(makeSyncthingIcon(settings.errorColor, StatusEmblem::Synchronizing))))
-    , newItem(QIcon(renderSvgImage(makeSyncthingIcon(settings.defaultColor, StatusEmblem::Add))))
+    : disconnected(QIcon(renderSvgImage(makeSyncthingIcon(settings.disconnectedColor, StatusEmblem::None), settings.renderSize)))
+    , idling(QIcon(renderSvgImage(makeSyncthingIcon(settings.idleColor, StatusEmblem::None), settings.renderSize)))
+    , scanninig(QIcon(renderSvgImage(makeSyncthingIcon(settings.scanningColor, StatusEmblem::Scanning), settings.renderSize)))
+    , notify(QIcon(renderSvgImage(makeSyncthingIcon(settings.warningColor, StatusEmblem::Alert), settings.renderSize)))
+    , pause(QIcon(renderSvgImage(makeSyncthingIcon(settings.pausedColor, StatusEmblem::Paused), settings.renderSize)))
+    , sync(QIcon(renderSvgImage(makeSyncthingIcon(settings.synchronizingColor, StatusEmblem::Synchronizing), settings.renderSize)))
+    , syncComplete(QIcon(renderSvgImage(makeSyncthingIcon(settings.defaultColor, StatusEmblem::Complete), settings.renderSize)))
+    , error(QIcon(renderSvgImage(makeSyncthingIcon(settings.errorColor, StatusEmblem::Alert), settings.renderSize)))
+    , errorSync(QIcon(renderSvgImage(makeSyncthingIcon(settings.errorColor, StatusEmblem::Synchronizing), settings.renderSize)))
+    , newItem(QIcon(renderSvgImage(makeSyncthingIcon(settings.defaultColor, StatusEmblem::Add), settings.renderSize)))
     , isValid(true)
 {
 }
 
-FontAwesomeIcons::FontAwesomeIcons(const QColor &color, const QSize &size, int margin)
-    : hashtag(renderSvgImage(loadFontAwesomeIcon(QStringLiteral("hashtag"), color), size, margin))
-    , folderOpen(renderSvgImage(loadFontAwesomeIcon(QStringLiteral("folder-open"), color), size, margin))
-    , globe(renderSvgImage(loadFontAwesomeIcon(QStringLiteral("globe"), color), size, margin))
-    , home(renderSvgImage(loadFontAwesomeIcon(QStringLiteral("home"), color), size, margin))
-    , shareAlt(renderSvgImage(loadFontAwesomeIcon(QStringLiteral("share-alt"), color), size, margin))
-    , refresh(renderSvgImage(loadFontAwesomeIcon(QStringLiteral("redo"), color), size, margin))
-    , clock(renderSvgImage(loadFontAwesomeIcon(QStringLiteral("clock"), color), size, margin))
-    , exchangeAlt(renderSvgImage(loadFontAwesomeIcon(QStringLiteral("exchange-alt"), color), size, margin))
-    , exclamationTriangle(renderSvgImage(loadFontAwesomeIcon(QStringLiteral("exclamation-triangle"), color), size, margin))
-    , cogs(renderSvgImage(loadFontAwesomeIcon(QStringLiteral("cogs"), color), size, margin))
-    , link(renderSvgImage(loadFontAwesomeIcon(QStringLiteral("link"), color), size, margin))
-    , eye(renderSvgImage(loadFontAwesomeIcon(QStringLiteral("eye"), color), size, margin))
-    , fileArchive(renderSvgImage(loadFontAwesomeIcon(QStringLiteral("file-archive"), color), size, margin))
-    , folder(renderSvgImage(loadFontAwesomeIcon(QStringLiteral("folder"), color), size, margin))
-    , certificate(renderSvgImage(loadFontAwesomeIcon(QStringLiteral("certificate"), color), size, margin))
-    , networkWired(renderSvgImage(loadFontAwesomeIcon(QStringLiteral("network-wired"), color), size, margin))
-    , cloudDownloadAlt(renderSvgImage(loadFontAwesomeIcon(QStringLiteral("cloud-download-alt"), color), size, margin))
-    , cloudUploadAlt(renderSvgImage(loadFontAwesomeIcon(QStringLiteral("cloud-upload-alt"), color), size, margin))
-    , tag(renderSvgImage(loadFontAwesomeIcon(QStringLiteral("tag"), color), size, margin))
+ForkAwesomeIcons::ForkAwesomeIcons(QtForkAwesome::Renderer &renderer, const QColor &color, const QSize &size)
+    : hashtag(renderer.pixmap(QtForkAwesome::Icon::Hashtag, size, color))
+    , folderOpen(renderer.pixmap(QtForkAwesome::Icon::FolderOpen, size, color))
+    , globe(renderer.pixmap(QtForkAwesome::Icon::Globe, size, color))
+    , home(renderer.pixmap(QtForkAwesome::Icon::Home, size, color))
+    , shareAlt(renderer.pixmap(QtForkAwesome::Icon::ShareAlt, size, color))
+    , refresh(renderer.pixmap(QtForkAwesome::Icon::Refresh, size, color))
+    , clock(renderer.pixmap(QtForkAwesome::Icon::ClockO, size, color))
+    , exchangeAlt(renderer.pixmap(QtForkAwesome::Icon::Exchange, size, color))
+    , exclamationTriangle(renderer.pixmap(QtForkAwesome::Icon::ExclamationTriangle, size, color))
+    , cogs(renderer.pixmap(QtForkAwesome::Icon::Cogs, size, color))
+    , link(renderer.pixmap(QtForkAwesome::Icon::Link, size, color))
+    , eye(renderer.pixmap(QtForkAwesome::Icon::Eye, size, color))
+    , fileArchive(renderer.pixmap(QtForkAwesome::Icon::FileArchiveO, size, color))
+    , folder(renderer.pixmap(QtForkAwesome::Icon::Folder, size, color))
+    , certificate(renderer.pixmap(QtForkAwesome::Icon::Certificate, size, color))
+    , networkWired(renderer.pixmap(QtForkAwesome::Icon::Sitemap, size, color))
+    , cloudDownloadAlt(renderer.pixmap(QtForkAwesome::Icon::CloudDownload, size, color))
+    , cloudUploadAlt(renderer.pixmap(QtForkAwesome::Icon::CloudUpload, size, color))
+    , tag(renderer.pixmap(QtForkAwesome::Icon::Tag, size, color))
 {
 }
 
-IconManager::IconManager()
+IconManager::IconManager(const QPalette *palette)
     : m_statusIcons()
     , m_trayIcons(m_statusIcons)
-    , m_fontAwesomeIconsForLightTheme(QColor(10, 10, 10), QSize(64, 64), 8)
-    , m_fontAwesomeIconsForDarkTheme(Qt::white, QSize(64, 64), 8)
+    , m_commonForkAwesomeIcons(
+          m_forkAwesomeRenderer, (palette ? *palette : QGuiApplication::palette()).color(QPalette::Normal, QPalette::Text), QSize(64, 64))
 {
+#ifdef __GNUC__
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wdeprecated-declarations"
+#endif
+    if (!palette) {
+        QObject::connect(qGuiApp, &QGuiApplication::paletteChanged, this, &IconManager::setPalette);
+    }
+#ifdef __GNUC__
+#pragma GCC diagnostic pop
+#endif
 }
 
-IconManager &IconManager::instance()
+void IconManager::setPalette(const QPalette &palette)
 {
-    static IconManager iconManager;
+    emit forkAwesomeIconsChanged(
+        m_commonForkAwesomeIcons = ForkAwesomeIcons(m_forkAwesomeRenderer, palette.color(QPalette::Normal, QPalette::Text), QSize(64, 64)));
+}
+
+IconManager &IconManager::instance(const QPalette *palette)
+{
+    static auto iconManager = IconManager(palette);
     return iconManager;
 }
 
