@@ -1,24 +1,27 @@
 #include "./syncthingapplet.h"
 #include "./settingsdialog.h"
 
-#include "../../connector/syncthingservice.h"
-#include "../../connector/utils.h"
+#include <syncthingconnector/syncthingservice.h>
+#include <syncthingconnector/utils.h>
 
-#include "../../widgets/misc/direrrorsdialog.h"
-#include "../../widgets/misc/internalerrorsdialog.h"
-#include "../../widgets/misc/otherdialogs.h"
-#include "../../widgets/misc/textviewdialog.h"
-#include "../../widgets/settings/settings.h"
-#include "../../widgets/settings/settingsdialog.h"
-#include "../../widgets/webview/webviewdialog.h"
+#include <syncthingwidgets/misc/direrrorsdialog.h>
+#include <syncthingwidgets/misc/internalerrorsdialog.h>
+#include <syncthingwidgets/misc/otherdialogs.h>
+#include <syncthingwidgets/misc/textviewdialog.h>
+#include <syncthingwidgets/settings/settings.h>
+#include <syncthingwidgets/settings/settingsdialog.h>
+#include <syncthingwidgets/webview/webviewdialog.h>
 
-#include "../../model/syncthingicons.h"
+#include <syncthingmodel/syncthingicons.h>
 
-#include "../../connector/utils.h"
+#include <syncthingconnector/utils.h>
 
 #include "resources/config.h"
 #include "resources/qtconfig.h"
 
+#include <qtforkawesome/utils.h>
+#include <qtquickforkawesome/imageprovider.h>
+
 #include <qtutilities/misc/desktoputils.h>
 #include <qtutilities/misc/dialogutils.h>
 #include <qtutilities/resources/resources.h>
@@ -28,16 +31,19 @@
 
 #include <KConfigGroup>
 
+#include <Plasma/Theme>
+#include <plasma/plasma_export.h>
+#include <plasma_version.h>
+
 #include <QClipboard>
 #include <QDesktopServices>
 #include <QGuiApplication>
+#include <QMap>
 #include <QNetworkReply>
 #include <QPalette>
 #include <QQmlEngine>
 #include <QStringBuilder>
 
-#include <iostream>
-
 using namespace std;
 using namespace Data;
 using namespace Plasma;
@@ -47,24 +53,44 @@ using namespace QtGui;
 
 namespace Plasmoid {
 
+static inline QPalette paletteFromTheme(const Plasma::Theme &theme)
+{
+#if 0 && PLASMA_VERSION_MAJOR >= 5 && PLASMA_VERSION_MINOR >= 68
+    return theme.palette();
+#else
+    auto p = QPalette();
+    p.setColor(QPalette::Normal, QPalette::Text, theme.color(Plasma::Theme::TextColor));
+    return p;
+#endif
+}
+
 SyncthingApplet::SyncthingApplet(QObject *parent, const QVariantList &data)
     : Applet(parent, data)
+    , m_faUrl(QStringLiteral("image://fa/"))
+    , m_iconManager(IconManager::instance(&m_palette))
     , m_aboutDlg(nullptr)
     , m_connection()
     , m_notifier(m_connection)
     , m_dirModel(m_connection)
+    , m_sortFilterDirModel(&m_dirModel)
     , m_devModel(m_connection)
+    , m_sortFilterDevModel(&m_devModel)
     , m_downloadModel(m_connection)
+    , m_recentChangesModel(m_connection)
     , m_settingsDlg(nullptr)
+    , m_imageProvider(nullptr)
 #ifndef SYNCTHINGWIDGETS_NO_WEBVIEW
     , m_webViewDlg(nullptr)
 #endif
     , m_currentConnectionConfig(-1)
+    , m_hasInternalErrors(false)
     , m_initialized(false)
 {
 #ifdef LIB_SYNCTHING_CONNECTOR_SUPPORT_SYSTEMD
     m_notifier.setService(&m_service);
 #endif
+    m_sortFilterDirModel.sort(0, Qt::AscendingOrder);
+    m_sortFilterDevModel.sort(0, Qt::AscendingOrder);
     qmlRegisterUncreatableMetaObject(Data::staticMetaObject, "martchus.syncthingplasmoid", 0, 6, "Data", QStringLiteral("only enums"));
 }
 
@@ -82,6 +108,7 @@ SyncthingApplet::~SyncthingApplet()
 void SyncthingApplet::init()
 {
     LOAD_QT_TRANSLATIONS;
+    setupCommonQtApplicationAttributes();
 
     Applet::init();
 
@@ -103,7 +130,8 @@ void SyncthingApplet::init()
     connect(&m_dbusNotifier, &DBusStatusNotifier::showNotificationsRequested, this, &SyncthingApplet::showNotificationsDialog);
     connect(&m_dbusNotifier, &DBusStatusNotifier::errorDetailsRequested, this, &SyncthingApplet::showInternalErrorsDialog);
     connect(&m_dbusNotifier, &DBusStatusNotifier::webUiRequested, this, &SyncthingApplet::showWebUI);
-    connect(&IconManager::instance(), &IconManager::statusIconsChanged, this, &SyncthingApplet::connectionStatusChanged);
+    connect(&m_iconManager, &IconManager::statusIconsChanged, this, &SyncthingApplet::connectionStatusChanged);
+    connect(&m_theme, &Plasma::Theme::themeChanged, this, &SyncthingApplet::handleThemeChanged);
 
     // restore settings
     Settings::restore();
@@ -111,7 +139,7 @@ void SyncthingApplet::init()
     // initialize systemd service support
 #ifdef LIB_SYNCTHING_CONNECTOR_SUPPORT_SYSTEMD
     SyncthingService::setMainInstance(&m_service);
-    m_service.setUnitName(Settings::values().systemd.syncthingUnit);
+    Settings::values().systemd.setupService(m_service);
     connect(&m_service, &SyncthingService::systemdAvailableChanged, this, &SyncthingApplet::handleSystemdStatusChanged);
     connect(&m_service, &SyncthingService::stateChanged, this, &SyncthingApplet::handleSystemdStatusChanged);
     connect(&m_service, &SyncthingService::errorOccurred, this, &SyncthingApplet::handleSystemdServiceError);
@@ -121,11 +149,24 @@ void SyncthingApplet::init()
     m_currentConnectionConfig = config().readEntry<int>("selectedConfig", 0);
 
     // apply settings and connect according to settings
+    setBrightColors(isPaletteDark(paletteFromTheme(m_theme)));
     handleSettingsChanged();
 
     m_initialized = true;
 }
 
+void SyncthingApplet::initEngine(QObject *object)
+{
+    const auto engine = qmlEngine(object);
+    if (!engine) {
+        return;
+    }
+    const auto color = m_theme.color(Plasma::Theme::TextColor, Plasma::Theme::NormalColorGroup);
+    m_imageProvider = new QtForkAwesome::QuickImageProvider(m_iconManager.forkAwesomeRenderer(), color);
+    connect(engine, &QObject::destroyed, this, &SyncthingApplet::handleImageProviderDestroyed); // engine has ownership over image provider
+    engine->addImageProvider(QStringLiteral("fa"), m_imageProvider);
+}
+
 QIcon SyncthingApplet::statusIcon() const
 {
     return m_statusInfo.statusIcon();
@@ -212,11 +253,12 @@ void SyncthingApplet::setCurrentConnectionConfigIndex(int index)
 
     // apply systemd settings, reconnect if required and possible
 #ifdef LIB_SYNCTHING_CONNECTOR_SUPPORT_SYSTEMD
-    const auto systemdRelevantForReconnect = settings.systemd.apply(m_connection, currentConnectionConfig(), reconnectRequired).relevant;
+    const auto systemdConsideredForReconnect
+        = settings.systemd.apply(m_connection, currentConnectionConfig(), reconnectRequired).consideredForReconnect;
 #else
-    const auto systemdRelevantForReconnect = false;
+    const auto systemdConsideredForReconnect = false;
 #endif
-    if (!systemdRelevantForReconnect && (reconnectRequired || !m_connection.isConnected())) {
+    if (!systemdConsideredForReconnect && (reconnectRequired || !m_connection.isConnected())) {
         m_connection.reconnect();
     }
 }
@@ -230,6 +272,11 @@ bool SyncthingApplet::isStartStopEnabled() const
 #endif
 }
 
+bool SyncthingApplet::hasInternalErrors() const
+{
+    return m_hasInternalErrors;
+}
+
 bool SyncthingApplet::areNotificationsAvailable() const
 {
     return !m_notifications.empty();
@@ -249,9 +296,12 @@ void SyncthingApplet::updateStatusIconAndTooltip()
     emit connectionStatusChanged();
 }
 
-QIcon SyncthingApplet::loadFontAwesomeIcon(const QString &name, bool solid) const
+QIcon SyncthingApplet::loadForkAwesomeIcon(const QString &name, int size) const
 {
-    return Data::renderSvgImage(Data::loadFontAwesomeIcon(name, QGuiApplication::palette().color(QPalette::WindowText), solid), QSize(32, 32), 8);
+    const auto icon = QtForkAwesome::iconFromId(name);
+    return QtForkAwesome::isIconValid(icon)
+        ? QIcon(IconManager::instance().forkAwesomeRenderer().pixmap(icon, QSize(size, size), QGuiApplication::palette().color(QPalette::WindowText)))
+        : QIcon();
 }
 
 QString SyncthingApplet::formatFileSize(quint64 fileSizeInByte) const
@@ -259,6 +309,11 @@ QString SyncthingApplet::formatFileSize(quint64 fileSizeInByte) const
     return QString::fromStdString(dataSizeToString(fileSizeInByte));
 }
 
+QString SyncthingApplet::substituteTilde(const QString &path) const
+{
+    return Data::substituteTilde(path, m_connection.tilde(), m_connection.pathSeparator());
+}
+
 void SyncthingApplet::showSettingsDlg()
 {
     if (!m_settingsDlg) {
@@ -317,10 +372,10 @@ void SyncthingApplet::showAboutDialog()
     if (!m_aboutDlg) {
         m_aboutDlg = new AboutDialog(nullptr, QStringLiteral(APP_NAME),
             QStringLiteral("<p>Developed by " APP_AUTHOR "<br>Syncthing icons from <a href=\"https://syncthing.net\">Syncthing project</a><br>Using "
-                           "icons from <a href=\"https://fontawesome.com\">Font "
-                           "Awesome</a> (see <a href=\"https://fontawesome.com/license\">their license</a>)</p>"),
+                           "icons from <a href=\"https://forkaweso.me\">Fork "
+                           "Awesome</a> (see <a href=\"https://forkaweso.me/Fork-Awesome/license\">their license</a>)</p>"),
             QStringLiteral(APP_VERSION), CppUtilities::applicationInfo.dependencyVersions, QStringLiteral(APP_URL), QStringLiteral(APP_DESCRIPTION),
-            renderSvgImage(makeSyncthingIcon()).toImage());
+            renderSvgImage(makeSyncthingIcon(), QSize(128, 128)).toImage());
         m_aboutDlg->setWindowTitle(tr("About") + QStringLiteral(" - " APP_NAME));
         m_aboutDlg->setWindowIcon(QIcon::fromTheme(QStringLiteral("syncthingtray")));
         m_aboutDlg->setAttribute(Qt::WA_DeleteOnClose);
@@ -396,10 +451,6 @@ void SyncthingApplet::handleSettingsChanged()
 
     // apply appearance settings
     setSize(config.readEntry<QSize>("size", QSize(25, 25)));
-    const bool brightColors = config.readEntry<bool>("brightColors", false);
-    m_dirModel.setBrightColors(brightColors);
-    m_devModel.setBrightColors(brightColors);
-    m_downloadModel.setBrightColors(brightColors);
     IconManager::instance().applySettings(&settings.icons.status);
 
     // restore selected states
@@ -446,9 +497,14 @@ void SyncthingApplet::handleInternalError(
     if (!InternalError::isRelevant(m_connection, category, networkError)) {
         return;
     }
-    InternalError error(errorMsg, request.url(), response);
-    m_dbusNotifier.showInternalError(error);
-    InternalErrorsDialog::addError(move(error));
+    auto error = InternalError(errorMsg, request.url(), response);
+    if (Settings::values().notifyOn.internalErrors) {
+        m_dbusNotifier.showInternalError(error);
+    }
+    InternalErrorsDialog::addError(std::move(error));
+    if (!m_hasInternalErrors) {
+        emit hasInternalErrorsChanged(m_hasInternalErrors = true);
+    }
 }
 
 void SyncthingApplet::handleDirStatisticsChanged()
@@ -459,6 +515,7 @@ void SyncthingApplet::handleDirStatisticsChanged()
 
 void SyncthingApplet::handleErrorsCleared()
 {
+    emit hasInternalErrorsChanged(m_hasInternalErrors = false);
 }
 
 void SyncthingApplet::handleAboutDialogDeleted()
@@ -492,6 +549,36 @@ void SyncthingApplet::handleSystemdServiceError(const QString &context, const QS
         QNetworkReply::NoError, QNetworkRequest(), QByteArray());
 }
 
+void Plasmoid::SyncthingApplet::handleImageProviderDestroyed()
+{
+    m_imageProvider = nullptr;
+}
+
+void SyncthingApplet::handleThemeChanged()
+{
+    // unset the fa-URL to provoke Qt Quick to reload the images
+    emit faUrlChanged(m_faUrl = QString());
+
+    // return to the event loop before setting the new theme color; otherwise Qt Quick does not update the images
+    QTimer::singleShot(0, this, [this] {
+        const auto palette = paletteFromTheme(m_theme);
+        IconManager::instance().setPalette(palette);
+        setBrightColors(isPaletteDark(palette));
+        if (m_imageProvider) {
+            m_imageProvider->setDefaultColor(m_theme.color(Plasma::Theme::TextColor, Plasma::Theme::NormalColorGroup));
+        }
+        emit faUrlChanged(m_faUrl = QStringLiteral("image://fa/"));
+    });
+}
+
+void SyncthingApplet::setBrightColors(bool brightColors)
+{
+    m_dirModel.setBrightColors(brightColors);
+    m_devModel.setBrightColors(brightColors);
+    m_downloadModel.setBrightColors(brightColors);
+    m_recentChangesModel.setBrightColors(brightColors);
+}
+
 #ifdef LIB_SYNCTHING_CONNECTOR_SUPPORT_SYSTEMD
 void SyncthingApplet::handleSystemdStatusChanged()
 {
