@@ -12,144 +12,183 @@
 <context>
     <name>DevicesPage</name>
     <message>
-        <location filename="../package/contents/ui/DevicesPage.qml" line="60"/>
+        <location filename="../package/contents/ui/DevicesPage.qml" line="64"/>
         <source>Resume</source>
         <translation>Fortsetzen</translation>
     </message>
     <message>
-        <location filename="../package/contents/ui/DevicesPage.qml" line="60"/>
-        <location filename="../package/contents/ui/DevicesPage.qml" line="98"/>
+        <location filename="../package/contents/ui/DevicesPage.qml" line="64"/>
+        <location filename="../package/contents/ui/DevicesPage.qml" line="116"/>
         <source>Pause</source>
         <translation>Pausieren</translation>
     </message>
+    <message>
+        <location filename="../package/contents/ui/DevicesPage.qml" line="102"/>
+        <source>Copy name</source>
+        <translation>Namen kopieren</translation>
+    </message>
+    <message>
+        <location filename="../package/contents/ui/DevicesPage.qml" line="107"/>
+        <source>Copy ID</source>
+        <translation>ID kopieren</translation>
+    </message>
 </context>
 <context>
     <name>DirectoriesPage</name>
     <message>
-        <location filename="../package/contents/ui/DirectoriesPage.qml" line="75"/>
+        <location filename="../package/contents/ui/DirectoriesPage.qml" line="20"/>
+        <source>Filter directories</source>
+        <translation>Verzeichnisse filtern</translation>
+    </message>
+    <message>
+        <location filename="../package/contents/ui/DirectoriesPage.qml" line="81"/>
         <source>Show errors</source>
         <translation>Zeige Fehler</translation>
     </message>
     <message>
-        <location filename="../package/contents/ui/DirectoriesPage.qml" line="86"/>
-        <location filename="../package/contents/ui/DirectoriesPage.qml" line="142"/>
+        <location filename="../package/contents/ui/DirectoriesPage.qml" line="92"/>
+        <location filename="../package/contents/ui/DirectoriesPage.qml" line="161"/>
         <source>Rescan</source>
         <translation>Scannen</translation>
     </message>
     <message>
-        <location filename="../package/contents/ui/DirectoriesPage.qml" line="94"/>
+        <location filename="../package/contents/ui/DirectoriesPage.qml" line="100"/>
         <source>Resume</source>
         <translation>Fortsetzen</translation>
     </message>
     <message>
-        <location filename="../package/contents/ui/DirectoriesPage.qml" line="94"/>
-        <location filename="../package/contents/ui/DirectoriesPage.qml" line="149"/>
+        <location filename="../package/contents/ui/DirectoriesPage.qml" line="100"/>
+        <location filename="../package/contents/ui/DirectoriesPage.qml" line="168"/>
         <source>Pause</source>
         <translation>Pausieren</translation>
     </message>
     <message>
-        <location filename="../package/contents/ui/DirectoriesPage.qml" line="104"/>
-        <location filename="../package/contents/ui/DirectoriesPage.qml" line="156"/>
+        <location filename="../package/contents/ui/DirectoriesPage.qml" line="110"/>
+        <location filename="../package/contents/ui/DirectoriesPage.qml" line="175"/>
         <source>Open in file browser</source>
         <translation>Im Dateibrowser öffnen</translation>
     </message>
+    <message>
+        <location filename="../package/contents/ui/DirectoriesPage.qml" line="147"/>
+        <source>Copy label/ID</source>
+        <translation>Namen/ID kopieren</translation>
+    </message>
+    <message>
+        <location filename="../package/contents/ui/DirectoriesPage.qml" line="152"/>
+        <source>Copy path</source>
+        <translation>Pfad kopieren</translation>
+    </message>
 </context>
 <context>
     <name>DownloadsPage</name>
     <message>
-        <location filename="../package/contents/ui/DownloadsPage.qml" line="64"/>
-        <location filename="../package/contents/ui/DownloadsPage.qml" line="120"/>
-        <location filename="../package/contents/ui/DownloadsPage.qml" line="137"/>
+        <location filename="../package/contents/ui/DownloadsPage.qml" line="66"/>
+        <location filename="../package/contents/ui/DownloadsPage.qml" line="122"/>
+        <location filename="../package/contents/ui/DownloadsPage.qml" line="147"/>
         <source>Open in file browser</source>
         <translation>Im Dateibrowser öffnen</translation>
     </message>
+    <message>
+        <location filename="../package/contents/ui/DownloadsPage.qml" line="138"/>
+        <source>Copy label/ID</source>
+        <translation>Namen/ID kopieren</translation>
+    </message>
 </context>
 <context>
     <name>FullRepresentation</name>
     <message>
-        <location filename="../package/contents/ui/FullRepresentation.qml" line="195"/>
         <source>Connect</source>
-        <translation>Verbinden</translation>
+        <translation type="vanished">Verbinden</translation>
     </message>
     <message>
-        <location filename="../package/contents/ui/FullRepresentation.qml" line="203"/>
         <source>Resume</source>
-        <translation>Fortsetzen</translation>
+        <translation type="vanished">Fortsetzen</translation>
     </message>
     <message>
-        <location filename="../package/contents/ui/FullRepresentation.qml" line="211"/>
         <source>Pause</source>
-        <translation>Pausieren</translation>
+        <translation type="vanished">Pausieren</translation>
     </message>
     <message>
-        <location filename="../package/contents/ui/FullRepresentation.qml" line="256"/>
         <source>Stop</source>
-        <translation>Stoppen</translation>
+        <translation type="vanished">Stoppen</translation>
     </message>
     <message>
-        <location filename="../package/contents/ui/FullRepresentation.qml" line="267"/>
         <source>Start</source>
-        <translation>Starten</translation>
+        <translation type="vanished">Starten</translation>
     </message>
     <message>
-        <location filename="../package/contents/ui/FullRepresentation.qml" line="312"/>
         <source>Show new notifications</source>
-        <translation>Neue Benachrichtigungen anzeigen</translation>
+        <translation type="vanished">Neue Benachrichtigungen anzeigen</translation>
     </message>
     <message>
-        <location filename="../package/contents/ui/FullRepresentation.qml" line="338"/>
         <source>Show own device ID</source>
-        <translation>Eigene Geräte-ID anzeigen</translation>
+        <translation type="vanished">Eigene Geräte-ID anzeigen</translation>
     </message>
     <message>
-        <location filename="../package/contents/ui/FullRepresentation.qml" line="351"/>
         <source>Show Syncthing log</source>
-        <translation>Syncthing-Log anzeigen</translation>
+        <translation type="vanished">Syncthing-Log anzeigen</translation>
     </message>
     <message>
-        <location filename="../package/contents/ui/FullRepresentation.qml" line="364"/>
         <source>Rescan all directories</source>
-        <translation>Alle Verzeichnisse neu scannen</translation>
+        <translation type="vanished">Alle Verzeichnisse neu scannen</translation>
     </message>
     <message>
-        <location filename="../package/contents/ui/FullRepresentation.qml" line="374"/>
         <source>Settings</source>
-        <translation>Einstellungen</translation>
+        <translation type="vanished">Einstellungen</translation>
     </message>
     <message>
-        <location filename="../package/contents/ui/FullRepresentation.qml" line="387"/>
         <source>Open Syncthing</source>
-        <translation>Syncthing öffnen</translation>
+        <translation type="vanished">Syncthing öffnen</translation>
     </message>
     <message>
-        <location filename="../package/contents/ui/FullRepresentation.qml" line="457"/>
+        <location filename="../package/contents/ui/FullRepresentation.qml" line="241"/>
         <source>Global</source>
         <translation>Globale</translation>
     </message>
     <message>
-        <location filename="../package/contents/ui/FullRepresentation.qml" line="466"/>
+        <location filename="../package/contents/ui/FullRepresentation.qml" line="248"/>
         <source>Global incoming traffic</source>
         <translation>Globaler eingehender Datenverkehr</translation>
     </message>
     <message>
-        <location filename="../package/contents/ui/FullRepresentation.qml" line="477"/>
+        <location filename="../package/contents/ui/FullRepresentation.qml" line="266"/>
         <source>Local</source>
         <translation>Lokale</translation>
     </message>
     <message>
-        <location filename="../package/contents/ui/FullRepresentation.qml" line="486"/>
+        <location filename="../package/contents/ui/FullRepresentation.qml" line="273"/>
         <source>Global outgoing traffic</source>
         <translation>Globaler ausgehender Datenverkehr</translation>
     </message>
     <message>
-        <location filename="../package/contents/ui/FullRepresentation.qml" line="538"/>
+        <location filename="../package/contents/ui/FullRepresentation.qml" line="29"/>
+        <source>Directories</source>
+        <translation>Verzeichnisse</translation>
+    </message>
+    <message>
+        <location filename="../package/contents/ui/FullRepresentation.qml" line="35"/>
+        <source>Devices</source>
+        <translation>Geräte</translation>
+    </message>
+    <message>
+        <location filename="../package/contents/ui/FullRepresentation.qml" line="41"/>
+        <source>Downloads</source>
+        <translation></translation>
+    </message>
+    <message>
+        <location filename="../package/contents/ui/FullRepresentation.qml" line="47"/>
+        <source>History</source>
+        <translatorcomment>&quot;Letzte Änderungen&quot; is too long</translatorcomment>
+        <translation>Änderungen</translation>
+    </message>
+    <message>
+        <location filename="../package/contents/ui/FullRepresentation.qml" line="99"/>
         <source>Toggle filter</source>
         <translation>Filter ein-/ausblenden</translation>
     </message>
     <message>
-        <location filename="../package/contents/ui/FullRepresentation.qml" line="329"/>
         <source>About Syncthing Tray</source>
-        <translation>Über Syncthing Tray</translation>
+        <translation type="vanished">Über Syncthing Tray</translation>
     </message>
 </context>
 <context>
@@ -160,40 +199,38 @@
         <translation>Erscheinungsbild</translation>
     </message>
     <message>
-        <location filename="../lib/appearanceoptionpage.ui" line="18"/>
-        <source>Size of full representation</source>
-        <translation>Minimale Größe</translation>
+        <location filename="../lib/appearanceoptionpage.ui" line="25"/>
+        <source>Size of directory/device/download list</source>
+        <translation>Größe der Verzeichnis-/Geräte-/Downloadliste</translation>
     </message>
     <message>
-        <location filename="../lib/appearanceoptionpage.ui" line="68"/>
+        <location filename="../lib/appearanceoptionpage.ui" line="64"/>
         <source> x </source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../lib/appearanceoptionpage.ui" line="94"/>
+        <location filename="../lib/appearanceoptionpage.ui" line="90"/>
         <source> grid units</source>
         <translation> Rastereinheiten</translation>
     </message>
     <message>
-        <location filename="../lib/appearanceoptionpage.ui" line="112"/>
-        <source>Note that the size is ignored when the Plasmoid is displayed on the desktop, in full screen mode or as entry of the system tray Plasmoid.</source>
-        <translation>Die eingestellte Größe wird ignoriert, wenn das Plasmoid am Desktop, im Vollbild oder innerhalb des Systemtray-Plasmoids dargestellt wird.</translation>
+        <location filename="../lib/appearanceoptionpage.ui" line="108"/>
+        <source>Note that the size is ignored when the Plasmoid is displayed on the desktop or in full screen mode. When displayed as entry of the system tray Plasmoid the size can not be changed (setting a high value just leads to the contents being clipped).</source>
+        <translation>Die Größe wird ignoriert when das Plasmoid auf dem Desktop oder im Vollbildmodus dargestellt wird. Wenn das Plasmoid innerhalb des Systemtray-Plasmoids dargestellt wird kann die Größe nicht geändert werden (einen größeren Wert einzustellen führt nur dazu, dass der Inhalt abgeschnitten wird).</translation>
     </message>
     <message>
-        <location filename="../lib/appearanceoptionpage.ui" line="124"/>
+        <location filename="../lib/appearanceoptionpage.ui" line="120"/>
         <source>States to enable passive mode</source>
         <translatorcomment>Plural: https://www.duden.de/rechtschreibung/Status</translatorcomment>
         <translation>Status für passiven Modus</translation>
     </message>
     <message>
-        <location filename="../lib/appearanceoptionpage.ui" line="25"/>
         <source>Colors</source>
-        <translation>Farben</translation>
+        <translation type="vanished">Farben</translation>
     </message>
     <message>
-        <location filename="../lib/appearanceoptionpage.ui" line="32"/>
         <source>Bright custom text colors (use for dark color scheme)</source>
-        <translation>Helle benutzerdefinierte Schriftfarben (für dunkles Farbschema gedacht)</translation>
+        <translation type="vanished">Helle benutzerdefinierte Schriftfarben (für dunkles Farbschema gedacht)</translation>
     </message>
 </context>
 <context>
@@ -207,17 +244,17 @@
 <context>
     <name>Plasmoid::SettingsDialog</name>
     <message>
-        <location filename="../lib/settingsdialog.cpp" line="126"/>
+        <location filename="../lib/settingsdialog.cpp" line="124"/>
         <source>Plasmoid</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../lib/settingsdialog.cpp" line="134"/>
+        <location filename="../lib/settingsdialog.cpp" line="132"/>
         <source>Web view</source>
         <translation>Weboberfläche</translation>
     </message>
     <message>
-        <location filename="../lib/settingsdialog.cpp" line="144"/>
+        <location filename="../lib/settingsdialog.cpp" line="138"/>
         <source>Extras</source>
         <translation></translation>
     </message>
@@ -238,73 +275,163 @@
 <context>
     <name>Plasmoid::SyncthingApplet</name>
     <message>
-        <location filename="../lib/syncthingapplet.cpp" line="324"/>
+        <location filename="../lib/syncthingapplet.cpp" line="379"/>
         <source>About</source>
         <translation>Über Syncthing Plasmoid</translation>
     </message>
     <message>
-        <location filename="../lib/syncthingapplet.cpp" line="336"/>
+        <location filename="../lib/syncthingapplet.cpp" line="391"/>
         <source>New notifications</source>
         <translation>Neue Benachrichtigungen</translation>
     </message>
     <message>
-        <location filename="../lib/syncthingapplet.cpp" line="491"/>
+        <location filename="../lib/syncthingapplet.cpp" line="548"/>
         <source>D-Bus error - unable to </source>
         <translation>D-Bus-Fehler bei Aktion </translation>
     </message>
 </context>
+<context>
+    <name>RecentChangesPage</name>
+    <message>
+        <location filename="../package/contents/ui/RecentChangesPage.qml" line="109"/>
+        <source>Copy path</source>
+        <translation>Pfad kopieren</translation>
+    </message>
+    <message>
+        <location filename="../package/contents/ui/RecentChangesPage.qml" line="114"/>
+        <source>Copy device ID</source>
+        <translation>Geräte-ID kopieren</translation>
+    </message>
+    <message>
+        <location filename="../package/contents/ui/RecentChangesPage.qml" line="119"/>
+        <source>Copy directory ID</source>
+        <translation>Verzeichnis-ID kopieren</translation>
+    </message>
+</context>
 <context>
     <name>StatisticsView</name>
     <message>
-        <location filename="../package/contents/ui/StatisticsView.qml" line="15"/>
+        <location filename="../package/contents/ui/StatisticsView.qml" line="12"/>
         <source> files</source>
         <translation> Dateien</translation>
     </message>
     <message>
-        <location filename="../package/contents/ui/StatisticsView.qml" line="21"/>
+        <location filename="../package/contents/ui/StatisticsView.qml" line="17"/>
         <source> directories</source>
         <translation> Verzeichnisse</translation>
     </message>
     <message>
-        <location filename="../package/contents/ui/StatisticsView.qml" line="27"/>
+        <location filename="../package/contents/ui/StatisticsView.qml" line="23"/>
         <source> size</source>
         <translation> Datengröße</translation>
     </message>
 </context>
 <context>
-    <name>main</name>
+    <name>ToolBar</name>
     <message>
-        <location filename="../package/contents/ui/main.qml" line="63"/>
-        <source>Web UI</source>
-        <translation>Weboberfläche</translation>
+        <location filename="../package/contents/ui/ToolBar.qml" line="25"/>
+        <source>Connect</source>
+        <translation>Verbinden</translation>
     </message>
     <message>
-        <location filename="../package/contents/ui/main.qml" line="64"/>
-        <source>Settings</source>
-        <translation>Einstellungen</translation>
+        <location filename="../package/contents/ui/ToolBar.qml" line="41"/>
+        <source>Resume</source>
+        <translation>Fortsetzen</translation>
     </message>
     <message>
-        <location filename="../package/contents/ui/main.qml" line="65"/>
-        <source>Log</source>
-        <translation>Log</translation>
+        <location filename="../package/contents/ui/ToolBar.qml" line="50"/>
+        <source>Pause</source>
+        <translation>Pausieren</translation>
     </message>
     <message>
-        <location filename="../package/contents/ui/main.qml" line="67"/>
-        <source>Internal errors</source>
-        <translation>Interne Fehler</translation>
+        <location filename="../package/contents/ui/ToolBar.qml" line="99"/>
+        <source>Stop</source>
+        <translation>Stoppen</translation>
     </message>
     <message>
-        <location filename="../package/contents/ui/main.qml" line="69"/>
+        <location filename="../package/contents/ui/ToolBar.qml" line="113"/>
+        <source>Start</source>
+        <translation>Starten</translation>
+    </message>
+    <message>
+        <location filename="../package/contents/ui/ToolBar.qml" line="169"/>
+        <source>Show new notifications</source>
+        <translation>Neue Benachrichtigungen anzeigen</translation>
+    </message>
+    <message>
+        <location filename="../package/contents/ui/ToolBar.qml" line="188"/>
+        <source>About Syncthing Tray</source>
+        <translation>Über Syncthing Tray</translation>
+    </message>
+    <message>
+        <location filename="../package/contents/ui/ToolBar.qml" line="200"/>
+        <source>Show own device ID</source>
+        <translation>Eigene Geräte-ID anzeigen</translation>
+    </message>
+    <message>
+        <location filename="../package/contents/ui/ToolBar.qml" line="216"/>
+        <source>Show Syncthing log</source>
+        <translation>Syncthing-Log anzeigen</translation>
+    </message>
+    <message>
+        <location filename="../package/contents/ui/ToolBar.qml" line="228"/>
         <source>Rescan all directories</source>
         <translation>Alle Verzeichnisse neu scannen</translation>
     </message>
     <message>
-        <location filename="../package/contents/ui/main.qml" line="71"/>
+        <location filename="../package/contents/ui/ToolBar.qml" line="244"/>
+        <source>Settings</source>
+        <translation>Einstellungen</translation>
+    </message>
+    <message>
+        <location filename="../package/contents/ui/ToolBar.qml" line="259"/>
+        <source>Open Syncthing</source>
+        <translation>Syncthing öffnen</translation>
+    </message>
+</context>
+<context>
+    <name>main</name>
+    <message>
+        <source>Web UI</source>
+        <translation type="vanished">Weboberfläche</translation>
+    </message>
+    <message>
+        <location filename="../package/contents/ui/main.qml" line="59"/>
+        <source>Open Syncthing</source>
+        <translation>Syncthing öffnen</translation>
+    </message>
+    <message>
+        <location filename="../package/contents/ui/main.qml" line="60"/>
+        <source>Settings</source>
+        <translation>Einstellungen</translation>
+    </message>
+    <message>
+        <location filename="../package/contents/ui/main.qml" line="63"/>
+        <source>Show own device ID</source>
+        <translation>Eigene Geräte-ID anzeigen</translation>
+    </message>
+    <message>
+        <location filename="../package/contents/ui/main.qml" line="67"/>
+        <source>Log</source>
+        <translation>Log</translation>
+    </message>
+    <message>
+        <location filename="../package/contents/ui/main.qml" line="68"/>
+        <source>Internal errors</source>
+        <translation>Interne Fehler</translation>
+    </message>
+    <message>
+        <location filename="../package/contents/ui/main.qml" line="61"/>
+        <source>Rescan all directories</source>
+        <translation>Alle Verzeichnisse neu scannen</translation>
+    </message>
+    <message>
+        <location filename="../package/contents/ui/main.qml" line="65"/>
         <source>Restart Syncthing</source>
         <translation>Syncthing neustarten</translation>
     </message>
     <message>
-        <location filename="../package/contents/ui/main.qml" line="73"/>
+        <location filename="../package/contents/ui/main.qml" line="70"/>
         <source>About</source>
         <translation>Über Syncthing Plasmoid</translation>
     </message>
