@@ -12,143 +12,133 @@
 <context>
     <name>DevicesPage</name>
     <message>
-        <location filename="../package/contents/ui/DevicesPage.qml" line="60"/>
+        <location filename="../package/contents/ui/DevicesPage.qml" line="64"/>
         <source>Resume</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../package/contents/ui/DevicesPage.qml" line="60"/>
-        <location filename="../package/contents/ui/DevicesPage.qml" line="98"/>
+        <location filename="../package/contents/ui/DevicesPage.qml" line="64"/>
+        <location filename="../package/contents/ui/DevicesPage.qml" line="116"/>
         <source>Pause</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <location filename="../package/contents/ui/DevicesPage.qml" line="102"/>
+        <source>Copy name</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../package/contents/ui/DevicesPage.qml" line="107"/>
+        <source>Copy ID</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>DirectoriesPage</name>
     <message>
-        <location filename="../package/contents/ui/DirectoriesPage.qml" line="75"/>
+        <location filename="../package/contents/ui/DirectoriesPage.qml" line="20"/>
+        <source>Filter directories</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../package/contents/ui/DirectoriesPage.qml" line="81"/>
         <source>Show errors</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../package/contents/ui/DirectoriesPage.qml" line="86"/>
-        <location filename="../package/contents/ui/DirectoriesPage.qml" line="142"/>
+        <location filename="../package/contents/ui/DirectoriesPage.qml" line="92"/>
+        <location filename="../package/contents/ui/DirectoriesPage.qml" line="161"/>
         <source>Rescan</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../package/contents/ui/DirectoriesPage.qml" line="94"/>
+        <location filename="../package/contents/ui/DirectoriesPage.qml" line="100"/>
         <source>Resume</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../package/contents/ui/DirectoriesPage.qml" line="94"/>
-        <location filename="../package/contents/ui/DirectoriesPage.qml" line="149"/>
+        <location filename="../package/contents/ui/DirectoriesPage.qml" line="100"/>
+        <location filename="../package/contents/ui/DirectoriesPage.qml" line="168"/>
         <source>Pause</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../package/contents/ui/DirectoriesPage.qml" line="104"/>
-        <location filename="../package/contents/ui/DirectoriesPage.qml" line="156"/>
+        <location filename="../package/contents/ui/DirectoriesPage.qml" line="110"/>
+        <location filename="../package/contents/ui/DirectoriesPage.qml" line="175"/>
         <source>Open in file browser</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <location filename="../package/contents/ui/DirectoriesPage.qml" line="147"/>
+        <source>Copy label/ID</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../package/contents/ui/DirectoriesPage.qml" line="152"/>
+        <source>Copy path</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>DownloadsPage</name>
     <message>
-        <location filename="../package/contents/ui/DownloadsPage.qml" line="64"/>
-        <location filename="../package/contents/ui/DownloadsPage.qml" line="120"/>
-        <location filename="../package/contents/ui/DownloadsPage.qml" line="137"/>
+        <location filename="../package/contents/ui/DownloadsPage.qml" line="66"/>
+        <location filename="../package/contents/ui/DownloadsPage.qml" line="122"/>
+        <location filename="../package/contents/ui/DownloadsPage.qml" line="147"/>
         <source>Open in file browser</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <location filename="../package/contents/ui/DownloadsPage.qml" line="138"/>
+        <source>Copy label/ID</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>FullRepresentation</name>
     <message>
-        <location filename="../package/contents/ui/FullRepresentation.qml" line="195"/>
-        <source>Connect</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../package/contents/ui/FullRepresentation.qml" line="203"/>
-        <source>Resume</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../package/contents/ui/FullRepresentation.qml" line="211"/>
-        <source>Pause</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../package/contents/ui/FullRepresentation.qml" line="256"/>
-        <source>Stop</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../package/contents/ui/FullRepresentation.qml" line="267"/>
-        <source>Start</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../package/contents/ui/FullRepresentation.qml" line="312"/>
-        <source>Show new notifications</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../package/contents/ui/FullRepresentation.qml" line="338"/>
-        <source>Show own device ID</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../package/contents/ui/FullRepresentation.qml" line="351"/>
-        <source>Show Syncthing log</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../package/contents/ui/FullRepresentation.qml" line="364"/>
-        <source>Rescan all directories</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../package/contents/ui/FullRepresentation.qml" line="374"/>
-        <source>Settings</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../package/contents/ui/FullRepresentation.qml" line="387"/>
-        <source>Open Syncthing</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../package/contents/ui/FullRepresentation.qml" line="457"/>
+        <location filename="../package/contents/ui/FullRepresentation.qml" line="241"/>
         <source>Global</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../package/contents/ui/FullRepresentation.qml" line="466"/>
+        <location filename="../package/contents/ui/FullRepresentation.qml" line="248"/>
         <source>Global incoming traffic</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../package/contents/ui/FullRepresentation.qml" line="477"/>
+        <location filename="../package/contents/ui/FullRepresentation.qml" line="266"/>
         <source>Local</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../package/contents/ui/FullRepresentation.qml" line="486"/>
+        <location filename="../package/contents/ui/FullRepresentation.qml" line="273"/>
         <source>Global outgoing traffic</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../package/contents/ui/FullRepresentation.qml" line="538"/>
-        <source>Toggle filter</source>
+        <location filename="../package/contents/ui/FullRepresentation.qml" line="29"/>
+        <source>Directories</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../package/contents/ui/FullRepresentation.qml" line="329"/>
-        <source>About Syncthing Tray</source>
+        <location filename="../package/contents/ui/FullRepresentation.qml" line="35"/>
+        <source>Devices</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../package/contents/ui/FullRepresentation.qml" line="41"/>
+        <source>Downloads</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../package/contents/ui/FullRepresentation.qml" line="47"/>
+        <source>History</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../package/contents/ui/FullRepresentation.qml" line="99"/>
+        <source>Toggle filter</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -160,40 +150,30 @@
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../lib/appearanceoptionpage.ui" line="18"/>
-        <source>Size of full representation</source>
+        <location filename="../lib/appearanceoptionpage.ui" line="25"/>
+        <source>Size of directory/device/download list</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../lib/appearanceoptionpage.ui" line="68"/>
+        <location filename="../lib/appearanceoptionpage.ui" line="64"/>
         <source> x </source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../lib/appearanceoptionpage.ui" line="94"/>
+        <location filename="../lib/appearanceoptionpage.ui" line="90"/>
         <source> grid units</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../lib/appearanceoptionpage.ui" line="112"/>
-        <source>Note that the size is ignored when the Plasmoid is displayed on the desktop, in full screen mode or as entry of the system tray Plasmoid.</source>
+        <location filename="../lib/appearanceoptionpage.ui" line="108"/>
+        <source>Note that the size is ignored when the Plasmoid is displayed on the desktop or in full screen mode. When displayed as entry of the system tray Plasmoid the size can not be changed (setting a high value just leads to the contents being clipped).</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../lib/appearanceoptionpage.ui" line="124"/>
+        <location filename="../lib/appearanceoptionpage.ui" line="120"/>
         <source>States to enable passive mode</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <location filename="../lib/appearanceoptionpage.ui" line="25"/>
-        <source>Colors</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../lib/appearanceoptionpage.ui" line="32"/>
-        <source>Bright custom text colors (use for dark color scheme)</source>
-        <translation type="unfinished"></translation>
-    </message>
 </context>
 <context>
     <name>Plasmoid::Settings</name>
@@ -206,17 +186,17 @@
 <context>
     <name>Plasmoid::SettingsDialog</name>
     <message>
-        <location filename="../lib/settingsdialog.cpp" line="126"/>
+        <location filename="../lib/settingsdialog.cpp" line="124"/>
         <source>Plasmoid</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../lib/settingsdialog.cpp" line="134"/>
+        <location filename="../lib/settingsdialog.cpp" line="132"/>
         <source>Web view</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../lib/settingsdialog.cpp" line="144"/>
+        <location filename="../lib/settingsdialog.cpp" line="138"/>
         <source>Extras</source>
         <translation type="unfinished"></translation>
     </message>
@@ -237,73 +217,159 @@
 <context>
     <name>Plasmoid::SyncthingApplet</name>
     <message>
-        <location filename="../lib/syncthingapplet.cpp" line="324"/>
+        <location filename="../lib/syncthingapplet.cpp" line="379"/>
         <source>About</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../lib/syncthingapplet.cpp" line="336"/>
+        <location filename="../lib/syncthingapplet.cpp" line="391"/>
         <source>New notifications</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../lib/syncthingapplet.cpp" line="491"/>
+        <location filename="../lib/syncthingapplet.cpp" line="548"/>
         <source>D-Bus error - unable to </source>
         <translation type="unfinished"></translation>
     </message>
 </context>
+<context>
+    <name>RecentChangesPage</name>
+    <message>
+        <location filename="../package/contents/ui/RecentChangesPage.qml" line="109"/>
+        <source>Copy path</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../package/contents/ui/RecentChangesPage.qml" line="114"/>
+        <source>Copy device ID</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../package/contents/ui/RecentChangesPage.qml" line="119"/>
+        <source>Copy directory ID</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>StatisticsView</name>
     <message>
-        <location filename="../package/contents/ui/StatisticsView.qml" line="15"/>
+        <location filename="../package/contents/ui/StatisticsView.qml" line="12"/>
         <source> files</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../package/contents/ui/StatisticsView.qml" line="21"/>
+        <location filename="../package/contents/ui/StatisticsView.qml" line="17"/>
         <source> directories</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../package/contents/ui/StatisticsView.qml" line="27"/>
+        <location filename="../package/contents/ui/StatisticsView.qml" line="23"/>
         <source> size</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
+<context>
+    <name>ToolBar</name>
+    <message>
+        <location filename="../package/contents/ui/ToolBar.qml" line="25"/>
+        <source>Connect</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../package/contents/ui/ToolBar.qml" line="41"/>
+        <source>Resume</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../package/contents/ui/ToolBar.qml" line="50"/>
+        <source>Pause</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../package/contents/ui/ToolBar.qml" line="99"/>
+        <source>Stop</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../package/contents/ui/ToolBar.qml" line="113"/>
+        <source>Start</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../package/contents/ui/ToolBar.qml" line="169"/>
+        <source>Show new notifications</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../package/contents/ui/ToolBar.qml" line="188"/>
+        <source>About Syncthing Tray</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../package/contents/ui/ToolBar.qml" line="200"/>
+        <source>Show own device ID</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../package/contents/ui/ToolBar.qml" line="216"/>
+        <source>Show Syncthing log</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../package/contents/ui/ToolBar.qml" line="228"/>
+        <source>Rescan all directories</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../package/contents/ui/ToolBar.qml" line="244"/>
+        <source>Settings</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../package/contents/ui/ToolBar.qml" line="259"/>
+        <source>Open Syncthing</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>main</name>
     <message>
-        <location filename="../package/contents/ui/main.qml" line="63"/>
-        <source>Web UI</source>
+        <location filename="../package/contents/ui/main.qml" line="59"/>
+        <source>Open Syncthing</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../package/contents/ui/main.qml" line="64"/>
+        <location filename="../package/contents/ui/main.qml" line="60"/>
         <source>Settings</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../package/contents/ui/main.qml" line="65"/>
-        <source>Log</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../package/contents/ui/main.qml" line="67"/>
-        <source>Internal errors</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../package/contents/ui/main.qml" line="69"/>
+        <location filename="../package/contents/ui/main.qml" line="61"/>
         <source>Rescan all directories</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../package/contents/ui/main.qml" line="71"/>
+        <location filename="../package/contents/ui/main.qml" line="63"/>
+        <source>Show own device ID</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../package/contents/ui/main.qml" line="65"/>
         <source>Restart Syncthing</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../package/contents/ui/main.qml" line="73"/>
+        <location filename="../package/contents/ui/main.qml" line="67"/>
+        <source>Log</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../package/contents/ui/main.qml" line="68"/>
+        <source>Internal errors</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../package/contents/ui/main.qml" line="70"/>
         <source>About</source>
         <translation type="unfinished"></translation>
     </message>
