@@ -1,29 +1,29 @@
 #include "./traywidget.h"
+#include "./helper.h"
 #include "./trayicon.h"
 #include "./traymenu.h"
 
-#include "../../widgets/misc/otherdialogs.h"
-#include "../../widgets/misc/syncthinglauncher.h"
-#include "../../widgets/misc/textviewdialog.h"
-#include "../../widgets/settings/settingsdialog.h"
-#include "../../widgets/webview/webviewdialog.h"
+#include <syncthingwidgets/misc/internalerrorsdialog.h>
+#include <syncthingwidgets/misc/otherdialogs.h>
+#include <syncthingwidgets/misc/syncthinglauncher.h>
+#include <syncthingwidgets/misc/textviewdialog.h>
+#include <syncthingwidgets/settings/settingsdialog.h>
+#include <syncthingwidgets/webview/webviewdialog.h>
 
-#ifdef SYNCTHINGTRAY_UNIFY_TRAY_MENUS
-#include "../../widgets/misc/internalerrorsdialog.h"
-#endif
-
-#include "../../model/syncthingicons.h"
+#include <syncthingmodel/syncthingicons.h>
 
 #ifdef LIB_SYNCTHING_CONNECTOR_SUPPORT_SYSTEMD
-#include "../../connector/syncthingservice.h"
+#include <syncthingconnector/syncthingservice.h>
 #endif
-#include "../../connector/utils.h"
+#include <syncthingconnector/utils.h>
 
 // use meta-data of syncthingtray application here
 #include "resources/../../tray/resources/config.h"
 
 #include "ui_traywidget.h"
 
+#include <qtforkawesome/icon.h>
+
 #include <qtutilities/aboutdialog/aboutdialog.h>
 #include <qtutilities/misc/desktoputils.h>
 #include <qtutilities/misc/dialogutils.h>
@@ -34,6 +34,7 @@
 #include <c++utilities/application/argumentparser.h>
 #include <c++utilities/conversion/stringconversion.h>
 
+#include <QActionGroup>
 #include <QClipboard>
 #include <QCoreApplication>
 #include <QDesktopServices>
@@ -55,6 +56,7 @@ using namespace std;
 
 namespace QtGui {
 
+QWidget *TrayWidget::s_dialogParent = nullptr;
 SettingsDialog *TrayWidget::s_settingsDlg = nullptr;
 QtUtilities::AboutDialog *TrayWidget::s_aboutDlg = nullptr;
 vector<TrayWidget *> TrayWidget::s_instances;
@@ -72,21 +74,41 @@ TrayWidget::TrayWidget(TrayMenu *parent)
 #ifndef SYNCTHINGWIDGETS_NO_WEBVIEW
     , m_webViewDlg(nullptr)
 #endif
+    , m_internalErrorsButton(nullptr)
     , m_notifier(m_connection)
     , m_dirModel(m_connection)
+    , m_sortFilterDirModel(&m_dirModel)
     , m_devModel(m_connection)
+    , m_sortFilterDevModel(&m_devModel)
     , m_dlModel(m_connection)
+    , m_recentChangesModel(m_connection)
     , m_selectedConnection(nullptr)
     , m_startStopButtonTarget(StartStopButtonTarget::None)
 {
+    // don't show connection status within connection settings if there are multiple tray widgets/icons (would be ambiguous)
+    if (!s_instances.empty() && s_settingsDlg) {
+        s_settingsDlg->hideConnectionStatus();
+    }
+
+    // take record of the newly created instance
     s_instances.push_back(this);
 
+    // show the connection configuration in the previous icon's tooltip as soon as there's a 2nd icon
+    if (s_instances.size() == 2) {
+        s_instances.front()->updateIconAndTooltip();
+    }
+
     m_ui->setupUi(this);
 
-    // setup model and view
-    m_ui->dirsTreeView->setModel(&m_dirModel);
-    m_ui->devsTreeView->setModel(&m_devModel);
+    // setup models and views
+    m_ui->dirsTreeView->header()->setSortIndicator(0, Qt::AscendingOrder);
+    m_ui->dirsTreeView->setModel(&m_sortFilterDirModel);
+    m_ui->devsTreeView->header()->setSortIndicator(0, Qt::AscendingOrder);
+    m_ui->devsTreeView->setModel(&m_sortFilterDevModel);
     m_ui->downloadsTreeView->setModel(&m_dlModel);
+    m_ui->recentChangesTreeView->setModel(&m_recentChangesModel);
+    m_ui->recentChangesTreeView->setContextMenuPolicy(Qt::CustomContextMenu);
+    setBrightColorsOfModelsAccordingToPalette();
 
     // setup sync-all button
     m_cornerFrame = new QFrame(this);
@@ -96,26 +118,22 @@ TrayWidget::TrayWidget(TrayMenu *parent)
     m_cornerFrame->setLayout(cornerFrameLayout);
     auto *viewIdButton = new QPushButton(m_cornerFrame);
     viewIdButton->setToolTip(tr("View own device ID"));
-    viewIdButton->setIcon(
-        QIcon::fromTheme(QStringLiteral("view-barcode"), QIcon(QStringLiteral(":/icons/hicolor/scalable/actions/view-barcode.svg"))));
+    viewIdButton->setIcon(QIcon(QStringLiteral("qrcode.fa")));
     viewIdButton->setFlat(true);
     cornerFrameLayout->addWidget(viewIdButton);
     auto *restartButton = new QPushButton(m_cornerFrame);
     restartButton->setToolTip(tr("Restart Syncthing"));
-    restartButton->setIcon(
-        QIcon::fromTheme(QStringLiteral("system-reboot"), QIcon(QStringLiteral(":/icons/hicolor/scalable/actions/view-refresh.svg"))));
+    restartButton->setIcon(QIcon(QStringLiteral("power-off.fa")));
     restartButton->setFlat(true);
     cornerFrameLayout->addWidget(restartButton);
     auto *showLogButton = new QPushButton(m_cornerFrame);
     showLogButton->setToolTip(tr("Show Syncthing log"));
-    showLogButton->setIcon(
-        QIcon::fromTheme(QStringLiteral("text-x-generic"), QIcon(QStringLiteral(":/icons/hicolor/scalable/mimetypes/text-x-generic.svg"))));
+    showLogButton->setIcon(QIcon(QStringLiteral("file-text.fa")));
     showLogButton->setFlat(true);
     cornerFrameLayout->addWidget(showLogButton);
     auto *scanAllButton = new QPushButton(m_cornerFrame);
     scanAllButton->setToolTip(tr("Rescan all directories"));
-    scanAllButton->setIcon(
-        QIcon::fromTheme(QStringLiteral("folder-sync"), QIcon(QStringLiteral(":/icons/hicolor/scalable/actions/folder-sync.svg"))));
+    scanAllButton->setIcon(QIcon(QStringLiteral("refresh.fa")));
     scanAllButton->setFlat(true);
     cornerFrameLayout->addWidget(scanAllButton);
     m_ui->tabWidget->setCornerWidget(m_cornerFrame, Qt::BottomRightCorner);
@@ -134,22 +152,29 @@ TrayWidget::TrayWidget(TrayMenu *parent)
 
     // setup other widgets
     m_ui->notificationsPushButton->setHidden(true);
-    m_ui->globalTextLabel->setPixmap(
-        QIcon::fromTheme(QStringLiteral("globe"), QIcon(QStringLiteral(":/icons/hicolor/scalable/actions/globe.svg"))).pixmap(16));
-    m_ui->localTextLabel->setPixmap(
-        QIcon::fromTheme(QStringLiteral("user-home"), QIcon(QStringLiteral(":/icons/hicolor/scalable/places/user-home.svg"))).pixmap(16));
+    m_ui->globalTextLabel->setPixmap(QIcon(QStringLiteral("globe.fa")).pixmap(16));
+    m_ui->localTextLabel->setPixmap(QIcon(QStringLiteral("home.fa")).pixmap(16));
     updateTraffic();
 
-#ifdef SYNCTHINGTRAY_UNIFY_TRAY_MENUS
     // add actions from right-click menu if it is not available
-    m_internalErrorsButton = new QPushButton(m_cornerFrame);
-    m_internalErrorsButton->setToolTip(tr("Show internal errors"));
-    m_internalErrorsButton->setIcon(
-        QIcon::fromTheme(QStringLiteral("emblem-error"), QIcon(QStringLiteral(":/icons/hicolor/scalable/emblems/8/emblem-error.svg"))));
-    m_internalErrorsButton->setFlat(true);
-    m_internalErrorsButton->setVisible(false);
-    connect(m_internalErrorsButton, &QPushButton::clicked, this, &TrayWidget::showInternalErrorsDialog);
-    cornerFrameLayout->addWidget(m_internalErrorsButton);
+#ifndef SYNCTHINGTRAY_UNIFY_TRAY_MENUS
+    if (!m_menu) {
+#endif
+        m_internalErrorsButton = new QPushButton(m_cornerFrame);
+        m_internalErrorsButton->setToolTip(tr("Show internal errors"));
+        m_internalErrorsButton->setIcon(
+            QIcon::fromTheme(QStringLiteral("emblem-error"), QIcon(QStringLiteral(":/icons/hicolor/scalable/emblems/8/emblem-error.svg"))));
+        m_internalErrorsButton->setFlat(true);
+        m_internalErrorsButton->setVisible(false);
+        connect(m_internalErrorsButton, &QPushButton::clicked, this, &TrayWidget::showInternalErrorsDialog);
+        cornerFrameLayout->addWidget(m_internalErrorsButton);
+        if (!m_menu) {
+            connect(&m_connection, &SyncthingConnection::error, this, &TrayWidget::showInternalError);
+        }
+#ifndef SYNCTHINGTRAY_UNIFY_TRAY_MENUS
+    }
+#endif
+#ifdef SYNCTHINGTRAY_UNIFY_TRAY_MENUS
     auto *quitButton = new QPushButton(m_cornerFrame);
     quitButton->setToolTip(tr("Quit Syncthing Tray"));
     quitButton->setIcon(QIcon::fromTheme(QStringLiteral("window-close"), QIcon(QStringLiteral(":/icons/hicolor/scalable/actions/window-close.svg"))));
@@ -173,6 +198,7 @@ TrayWidget::TrayWidget(TrayMenu *parent)
     connect(m_ui->devsTreeView, &DevView::pauseResumeDev, this, &TrayWidget::pauseResumeDev);
     connect(m_ui->downloadsTreeView, &DownloadView::openDir, this, &TrayWidget::openDir);
     connect(m_ui->downloadsTreeView, &DownloadView::openItemDir, this, &TrayWidget::openItemDir);
+    connect(m_ui->recentChangesTreeView, &QTreeView::customContextMenuRequested, this, &TrayWidget::showRecentChangesContextMenu);
     connect(scanAllButton, &QPushButton::clicked, &m_connection, &SyncthingConnection::rescanAllDirs);
     connect(viewIdButton, &QPushButton::clicked, this, &TrayWidget::showOwnDeviceId);
     connect(showLogButton, &QPushButton::clicked, this, &TrayWidget::showLog);
@@ -200,17 +226,20 @@ TrayWidget::~TrayWidget()
         s_instances.erase(i);
     }
     if (s_instances.empty()) {
+        delete s_dialogParent;
         QCoreApplication::quit();
+    } else if (s_instances.size() == 1) {
+        s_instances.front()->updateIconAndTooltip();
     }
 }
 
 void TrayWidget::showSettingsDialog()
 {
-    if (!m_dialogParent) {
-        m_dialogParent = make_unique<QWidget>();
+    if (!s_dialogParent) {
+        s_dialogParent = new QWidget();
     }
     if (!s_settingsDlg) {
-        s_settingsDlg = new SettingsDialog(&m_connection, m_dialogParent.get());
+        s_settingsDlg = new SettingsDialog(s_instances.size() < 2 ? &m_connection : nullptr, s_dialogParent);
         connect(s_settingsDlg, &SettingsDialog::applied, &TrayWidget::applySettingsOnAllInstances);
 
         // save settings to disk when applied
@@ -219,23 +248,24 @@ void TrayWidget::showSettingsDialog()
         //       by simply saving the settings immediately.
         connect(s_settingsDlg, &SettingsDialog::applied, &Settings::save);
     }
-    centerWidget(s_settingsDlg);
-    showDialog(s_settingsDlg);
+
+    // show settings dialog centered or maximized if the relatively big windows would overflow
+    showDialog(s_settingsDlg, centerWidgetAvoidingOverflow(s_settingsDlg));
 }
 
 void TrayWidget::showAboutDialog()
 {
-    if (!m_dialogParent) {
-        m_dialogParent = make_unique<QWidget>();
+    if (!s_dialogParent) {
+        s_dialogParent = new QWidget();
     }
     if (!s_aboutDlg) {
-        s_aboutDlg = new AboutDialog(m_dialogParent.get(), QString(),
+        s_aboutDlg = new AboutDialog(s_dialogParent, QString(),
             QStringLiteral(
                 "<p>Developed by " APP_AUTHOR
                 "<br>Fallback icons from KDE/Breeze project<br>Syncthing icons from <a href=\"https://syncthing.net\">Syncthing project</a><br>Using "
-                "icons from <a href=\"https://fontawesome.com\">Font "
-                "Awesome</a> (see <a href=\"https://fontawesome.com/license\">their license</a>)</p>"),
-            QString(), {}, QStringLiteral(APP_URL), QString(), QImage(QStringLiteral(":/icons/hicolor/scalable/app/syncthingtray.svg")));
+                "icons from <a href=\"https://forkaweso.me\">Fork "
+                "Awesome</a> (see <a href=\"https://forkaweso.me/Fork-Awesome/license\">their license</a>)</p>"),
+            QString(), {}, QStringLiteral(APP_URL), QString(), renderSvgImage(makeSyncthingIcon(), QSize(128, 128)).toImage());
         s_aboutDlg->setWindowTitle(tr("About") + QStringLiteral(" - " APP_NAME));
         s_aboutDlg->setWindowIcon(QIcon(QStringLiteral(":/icons/hicolor/scalable/app/syncthingtray.svg")));
     }
@@ -267,24 +297,21 @@ void TrayWidget::showOwnDeviceId()
 {
     auto *const dlg = ownDeviceIdDialog(m_connection);
     dlg->setAttribute(Qt::WA_DeleteOnClose, true);
-    centerWidget(dlg);
-    showDialog(dlg);
+    showDialog(dlg, centerWidgetAvoidingOverflow(dlg));
 }
 
 void TrayWidget::showLog()
 {
     auto *const dlg = TextViewDialog::forLogEntries(m_connection);
     dlg->setAttribute(Qt::WA_DeleteOnClose, true);
-    centerWidget(dlg);
-    showDialog(dlg);
+    showDialog(dlg, centerWidgetAvoidingOverflow(dlg));
 }
 
 void TrayWidget::showNotifications()
 {
     auto *const dlg = TextViewDialog::forLogEntries(m_notifications, tr("New notifications"));
     dlg->setAttribute(Qt::WA_DeleteOnClose, true);
-    centerWidget(dlg);
-    showDialog(dlg);
+    showDialog(dlg, centerWidgetAvoidingOverflow(dlg));
     m_notifications.clear();
     dismissNotifications();
 }
@@ -299,20 +326,31 @@ void TrayWidget::showUsingPositioningSettings()
     }
 }
 
-#ifdef SYNCTHINGTRAY_UNIFY_TRAY_MENUS
+void TrayWidget::showInternalError(
+    const QString &errorMessage, SyncthingErrorCategory category, int networkError, const QNetworkRequest &request, const QByteArray &response)
+{
+    if (!InternalError::isRelevant(connection(), category, networkError)) {
+        return;
+    }
+    InternalErrorsDialog::addError(errorMessage, request.url(), response);
+    showInternalErrorsButton();
+}
+
 void TrayWidget::showInternalErrorsButton()
 {
-    m_internalErrorsButton->setVisible(true);
+    if (m_internalErrorsButton) {
+        m_internalErrorsButton->setVisible(true);
+    }
 }
 
 void TrayWidget::showInternalErrorsDialog()
 {
     auto *const errorViewDlg = InternalErrorsDialog::instance();
-    connect(errorViewDlg, &InternalErrorsDialog::errorsCleared, this, &TrayWidget::handleErrorsCleared);
-    centerWidget(errorViewDlg);
-    errorViewDlg->show();
+    if (m_internalErrorsButton) {
+        connect(errorViewDlg, &InternalErrorsDialog::errorsCleared, m_internalErrorsButton, &QWidget::hide);
+    }
+    showDialog(errorViewDlg, centerWidgetAvoidingOverflow(errorViewDlg));
 }
-#endif
 
 void TrayWidget::dismissNotifications()
 {
@@ -353,8 +391,7 @@ void TrayWidget::handleStatusChanged(SyncthingStatus status)
     case SyncthingStatus::Disconnected:
         m_ui->statusPushButton->setText(tr("Connect"));
         m_ui->statusPushButton->setToolTip(tr("Not connected to Syncthing, click to connect"));
-        m_ui->statusPushButton->setIcon(
-            QIcon::fromTheme(QStringLiteral("view-refresh"), QIcon(QStringLiteral(":/icons/hicolor/scalable/actions/view-refresh.svg"))));
+        m_ui->statusPushButton->setIcon(QIcon(QStringLiteral("refresh.fa")));
         m_ui->statusPushButton->setHidden(false);
         updateTraffic(); // ensure previous traffic statistics are no longer shown
         break;
@@ -364,30 +401,22 @@ void TrayWidget::handleStatusChanged(SyncthingStatus status)
     case SyncthingStatus::Idle:
     case SyncthingStatus::Scanning:
     case SyncthingStatus::Synchronizing:
+    case SyncthingStatus::RemoteNotInSync:
         m_ui->statusPushButton->setText(tr("Pause"));
         m_ui->statusPushButton->setToolTip(tr("Syncthing is running, click to pause all devices"));
-        m_ui->statusPushButton->setIcon(QIcon::fromTheme(
-            QStringLiteral("media-playback-pause"), QIcon(QStringLiteral(":/icons/hicolor/scalable/actions/media-playback-pause.svg"))));
+        m_ui->statusPushButton->setIcon(QIcon(QStringLiteral("pause.fa")));
         m_ui->statusPushButton->setHidden(false);
         break;
     case SyncthingStatus::Paused:
         m_ui->statusPushButton->setText(tr("Continue"));
         m_ui->statusPushButton->setToolTip(tr("At least one device is paused, click to resume"));
-        m_ui->statusPushButton->setIcon(QIcon::fromTheme(
-            QStringLiteral("media-playback-start"), QIcon(QStringLiteral(":/icons/hicolor/scalable/actions/media-playback-start.svg"))));
+        m_ui->statusPushButton->setIcon(QIcon(QStringLiteral("play.fa")));
         m_ui->statusPushButton->setHidden(false);
         break;
     default:;
     }
 }
 
-#ifdef SYNCTHINGTRAY_UNIFY_TRAY_MENUS
-void TrayWidget::handleErrorsCleared()
-{
-    m_internalErrorsButton->setVisible(false);
-}
-#endif
-
 void TrayWidget::applySettings(const QString &connectionConfig)
 {
     // update connections menu
@@ -428,6 +457,7 @@ void TrayWidget::applySettings(const QString &connectionConfig)
         m_connectionsMenu->actions().at(0)->setChecked(true);
     }
     m_ui->connectionsPushButton->setText(m_selectedConnection->label);
+    m_ui->connectionsPushButton->setHidden(secondaryConnectionSettings.empty());
     const bool reconnectRequired = m_connection.applySettings(*m_selectedConnection);
 
     // apply notification settings
@@ -474,9 +504,6 @@ void TrayWidget::applySettings(const QString &connectionConfig)
     if (settings.appearance.tabPosition >= QTabWidget::North && settings.appearance.tabPosition <= QTabWidget::East) {
         m_ui->tabWidget->setTabPosition(static_cast<QTabWidget::TabPosition>(settings.appearance.tabPosition));
     }
-    m_dirModel.setBrightColors(settings.appearance.brightTextColors);
-    m_devModel.setBrightColors(settings.appearance.brightTextColors);
-    m_dlModel.setBrightColors(settings.appearance.brightTextColors);
     IconManager::instance().applySettings(&settings.icons.status, settings.icons.distinguishTrayIcons ? &settings.icons.tray : nullptr);
 
     // update status icon and text of tray icon because reconnect interval might have changed
@@ -484,7 +511,7 @@ void TrayWidget::applySettings(const QString &connectionConfig)
         m_menu->icon()->updateStatusIconAndText();
     }
 
-    // show warning when explicitely specified connection configuration was not found
+    // show warning when explicitly specified connection configuration was not found
     if (!specifiedConnectionConfigFound && !connectionConfig.isEmpty()) {
         auto *const msgBox = new QMessageBox(QMessageBox::Warning, QCoreApplication::applicationName(),
             tr("The specified connection configuration <em>%1</em> is not defined and hence ignored.").arg(connectionConfig));
@@ -493,6 +520,17 @@ void TrayWidget::applySettings(const QString &connectionConfig)
     }
 }
 
+bool TrayWidget::event(QEvent *event)
+{
+    switch (event->type()) {
+    case QEvent::PaletteChange:
+        setBrightColorsOfModelsAccordingToPalette();
+        break;
+    default:;
+    }
+    return QWidget::event(event);
+}
+
 void TrayWidget::applySettingsOnAllInstances()
 {
     for (TrayWidget *instance : s_instances) {
@@ -502,11 +540,11 @@ void TrayWidget::applySettingsOnAllInstances()
 
 void TrayWidget::openDir(const SyncthingDir &dir)
 {
-    if (QDir(dir.path).exists()) {
-        openLocalFileOrDir(dir.path);
+    const auto path = substituteTilde(dir.path, m_connection.tilde(), m_connection.pathSeparator());
+    if (QDir(path).exists()) {
+        openLocalFileOrDir(path);
     } else {
-        QMessageBox::warning(
-            this, QCoreApplication::applicationName(), tr("The directory <i>%1</i> does not exist on the local machine.").arg(dir.path));
+        QMessageBox::warning(this, QCoreApplication::applicationName(), tr("The directory <i>%1</i> does not exist on the local machine.").arg(path));
     }
 }
 
@@ -544,6 +582,34 @@ void TrayWidget::pauseResumeDir(const SyncthingDir &dir)
     }
 }
 
+void TrayWidget::showRecentChangesContextMenu(const QPoint &position)
+{
+    const auto *const selectionModel = m_ui->recentChangesTreeView->selectionModel();
+    if (!selectionModel || selectionModel->selectedRows().size() != 1) {
+        return;
+    }
+    const auto copyRole = [this](SyncthingRecentChangesModel::SyncthingRecentChangesModelRole role) {
+        return [this, role] {
+            const auto *const selectionModelToCopy = m_ui->recentChangesTreeView->selectionModel();
+            if (selectionModelToCopy && selectionModelToCopy->selectedRows().size() == 1) {
+                QGuiApplication::clipboard()->setText(m_recentChangesModel.data(selectionModelToCopy->selectedRows().at(0), role).toString());
+            }
+        };
+    };
+    QMenu menu(this);
+    connect(menu.addAction(QIcon::fromTheme(QStringLiteral("edit-copy"), QIcon(QStringLiteral(":/icons/hicolor/scalable/actions/edit-copy.svg"))),
+                tr("Copy path")),
+        &QAction::triggered, this, copyRole(SyncthingRecentChangesModel::Path));
+    connect(menu.addAction(QIcon::fromTheme(QStringLiteral("network-server-symbolic"),
+                               QIcon(QStringLiteral(":/icons/hicolor/scalable/places/network-workgroup.svg"))),
+                tr("Copy device ID")),
+        &QAction::triggered, this, copyRole(SyncthingRecentChangesModel::ModifiedBy));
+    connect(menu.addAction(QIcon::fromTheme(QStringLiteral("folder"), QIcon(QStringLiteral(":/icons/hicolor/scalable/places/folder.svg"))),
+                tr("Copy directory ID")),
+        &QAction::triggered, this, copyRole(SyncthingRecentChangesModel::DirectoryId));
+    showViewMenu(position, *m_ui->recentChangesTreeView, menu);
+}
+
 void TrayWidget::changeStatus()
 {
     switch (m_connection.status()) {
@@ -555,6 +621,7 @@ void TrayWidget::changeStatus()
     case SyncthingStatus::Idle:
     case SyncthingStatus::Scanning:
     case SyncthingStatus::Synchronizing:
+    case SyncthingStatus::RemoteNotInSync:
         m_connection.pauseAllDevs();
         break;
     case SyncthingStatus::Paused:
@@ -578,18 +645,19 @@ void TrayWidget::updateTraffic()
         const auto colorActive = palette.color(QPalette::WindowText);
         const auto colorInactive = QColor((colorActive.red() + colorBackground.red()) / 2, (colorActive.green() + colorBackground.green()) / 2,
             (colorActive.blue() + colorBackground.blue()) / 2);
-        const auto renderIcon
-            = [&size](const QString &name, const QColor &color) { return Data::renderSvgImage(Data::loadFontAwesomeIcon(name, color), size); };
+        const auto renderIcon = [&size](QtForkAwesome::Icon icon, const QColor &color) {
+            return IconManager::instance().forkAwesomeRenderer().pixmap(icon, size, color);
+        };
         struct {
             QPixmap uploadIconActive;
             QPixmap uploadIconInactive;
             QPixmap downloadIconActive;
             QPixmap downloadIconInactive;
         } icons;
-        icons.uploadIconActive = renderIcon(QStringLiteral("cloud-upload-alt"), colorActive);
-        icons.uploadIconInactive = renderIcon(QStringLiteral("cloud-upload-alt"), colorInactive);
-        icons.downloadIconActive = renderIcon(QStringLiteral("cloud-download-alt"), colorActive);
-        icons.downloadIconInactive = renderIcon(QStringLiteral("cloud-download-alt"), colorInactive);
+        icons.uploadIconActive = renderIcon(QtForkAwesome::Icon::CloudUpload, colorActive);
+        icons.uploadIconInactive = renderIcon(QtForkAwesome::Icon::CloudUpload, colorInactive);
+        icons.downloadIconActive = renderIcon(QtForkAwesome::Icon::CloudDownload, colorActive);
+        icons.downloadIconInactive = renderIcon(QtForkAwesome::Icon::CloudDownload, colorInactive);
         return icons;
     }();
 
@@ -607,6 +675,16 @@ void TrayWidget::updateOverallStatistics()
     m_ui->localStatisticsLabel->setText(directoryStatusString(overallStats.local));
 }
 
+void TrayWidget::updateIconAndTooltip()
+{
+    if (!m_menu) {
+        return;
+    }
+    if (auto *const trayIcon = m_menu->icon()) {
+        trayIcon->updateStatusIconAndText();
+    }
+}
+
 void TrayWidget::toggleRunning()
 {
     switch (m_startStopButtonTarget) {
@@ -620,7 +698,7 @@ void TrayWidget::toggleRunning()
     case StartStopButtonTarget::Launcher:
         if (auto *const launcher = SyncthingLauncher::mainInstance()) {
             if (launcher->isRunning()) {
-                launcher->terminate();
+                launcher->terminate(&m_connection);
             } else {
                 launcher->launch(Settings::values().launcher);
             }
@@ -660,13 +738,11 @@ Settings::Launcher::LauncherStatus TrayWidget::applyLauncherSettings(bool reconn
     if (launcherStatus.running) {
         m_ui->startStopPushButton->setText(tr("Stop"));
         m_ui->startStopPushButton->setToolTip(tr("Stop Syncthing instance launched via tray icon"));
-        m_ui->startStopPushButton->setIcon(
-            QIcon::fromTheme(QStringLiteral("process-stop"), QIcon(QStringLiteral(":/icons/hicolor/scalable/actions/process-stop.svg"))));
+        m_ui->startStopPushButton->setIcon(QIcon(QStringLiteral("stop.fa")));
     } else {
         m_ui->startStopPushButton->setText(tr("Start"));
         m_ui->startStopPushButton->setToolTip(tr("Start Syncthing with the built-in launcher configured in the settings"));
-        m_ui->startStopPushButton->setIcon(
-            QIcon::fromTheme(QStringLiteral("system-run"), QIcon(QStringLiteral(":/icons/hicolor/scalable/apps/system-run.svg"))));
+        m_ui->startStopPushButton->setIcon(QIcon(QStringLiteral("play.fa")));
     }
     return launcherStatus;
 }
@@ -701,14 +777,16 @@ Settings::Systemd::ServiceStatus TrayWidget::applySystemdSettings(bool reconnect
     m_startStopButtonTarget = StartStopButtonTarget::Service;
     if (serviceStatus.running) {
         m_ui->startStopPushButton->setText(tr("Stop"));
-        m_ui->startStopPushButton->setToolTip(QStringLiteral("systemctl --user stop ") + systemdSettings.syncthingUnit);
-        m_ui->startStopPushButton->setIcon(
-            QIcon::fromTheme(QStringLiteral("process-stop"), QIcon(QStringLiteral(":/icons/hicolor/scalable/actions/process-stop.svg"))));
+        m_ui->startStopPushButton->setToolTip(
+            (serviceStatus.userService ? QStringLiteral("systemctl --user stop ") : QStringLiteral("systemctl stop "))
+            + systemdSettings.syncthingUnit);
+        m_ui->startStopPushButton->setIcon(QIcon(QStringLiteral("stop.fa")));
     } else {
         m_ui->startStopPushButton->setText(tr("Start"));
-        m_ui->startStopPushButton->setToolTip(QStringLiteral("systemctl --user start ") + systemdSettings.syncthingUnit);
-        m_ui->startStopPushButton->setIcon(
-            QIcon::fromTheme(QStringLiteral("system-run"), QIcon(QStringLiteral(":/icons/hicolor/scalable/apps/system-run.svg"))));
+        m_ui->startStopPushButton->setToolTip(
+            (serviceStatus.userService ? QStringLiteral("systemctl --user start ") : QStringLiteral("systemctl start "))
+            + systemdSettings.syncthingUnit);
+        m_ui->startStopPushButton->setIcon(QIcon(QStringLiteral("play.fa")));
     }
     return serviceStatus;
 }
@@ -729,7 +807,7 @@ void TrayWidget::handleNewNotification(DateTime when, const QString &msg)
 
 void TrayWidget::handleConnectionSelected(QAction *connectionAction)
 {
-    int index = m_connectionsMenu->actions().indexOf(connectionAction);
+    auto index = m_connectionsMenu->actions().indexOf(connectionAction);
     if (index >= 0) {
         m_selectedConnection
             = (index == 0) ? &Settings::values().connection.primary : &Settings::values().connection.secondary[static_cast<size_t>(index - 1)];
@@ -746,12 +824,26 @@ void TrayWidget::handleConnectionSelected(QAction *connectionAction)
     }
 }
 
-void TrayWidget::showDialog(QWidget *dlg)
+void TrayWidget::showDialog(QWidget *dlg, bool maximized)
 {
     if (m_menu) {
         m_menu->close();
     }
-    dlg->show();
+    if (maximized) {
+        dlg->showMaximized();
+    } else {
+        dlg->show();
+    }
     dlg->activateWindow();
 }
+
+void TrayWidget::setBrightColorsOfModelsAccordingToPalette()
+{
+    const auto brightColors = isPaletteDark(palette());
+    m_dirModel.setBrightColors(brightColors);
+    m_devModel.setBrightColors(brightColors);
+    m_dlModel.setBrightColors(brightColors);
+    m_recentChangesModel.setBrightColors(brightColors);
+}
+
 } // namespace QtGui
