@@ -4,116 +4,151 @@
 <context>
     <name>QtGui::DevView</name>
     <message>
-        <location filename="../gui/devview.cpp" line="56"/>
+        <location filename="../gui/devview.cpp" line="59"/>
         <source>Copy value</source>
         <translation>Zkopírovat hodnotu</translation>
     </message>
     <message>
-        <location filename="../gui/devview.cpp" line="60"/>
+        <location filename="../gui/devview.cpp" line="65"/>
         <source>Copy name</source>
         <translation>Zkopírovat název</translation>
     </message>
     <message>
-        <location filename="../gui/devview.cpp" line="63"/>
+        <location filename="../gui/devview.cpp" line="68"/>
         <source>Copy ID</source>
         <translation>Zkopírovat identifikátor</translation>
     </message>
+    <message>
+        <location filename="../gui/devview.cpp" line="74"/>
+        <source>Resume</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../gui/devview.cpp" line="79"/>
+        <source>Pause</source>
+        <translation type="unfinished">Pozastavit</translation>
+    </message>
 </context>
 <context>
     <name>QtGui::DirView</name>
     <message>
-        <location filename="../gui/dirview.cpp" line="80"/>
+        <location filename="../gui/dirview.cpp" line="75"/>
         <source>Copy value</source>
         <translation>Zkopírovat hodnotu</translation>
     </message>
     <message>
-        <location filename="../gui/dirview.cpp" line="84"/>
+        <location filename="../gui/dirview.cpp" line="81"/>
         <source>Copy label/ID</source>
         <translation>Zkopírovat jmenovku/identifikátor</translation>
     </message>
     <message>
-        <location filename="../gui/dirview.cpp" line="87"/>
+        <location filename="../gui/dirview.cpp" line="84"/>
         <source>Copy path</source>
         <translation>Zkopírovat popis umístění</translation>
     </message>
+    <message>
+        <location filename="../gui/dirview.cpp" line="89"/>
+        <source>Rescan</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../gui/dirview.cpp" line="94"/>
+        <source>Resume</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../gui/dirview.cpp" line="99"/>
+        <source>Pause</source>
+        <translation type="unfinished">Pozastavit</translation>
+    </message>
+    <message>
+        <location filename="../gui/dirview.cpp" line="103"/>
+        <source>Open in file browser</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>QtGui::DownloadView</name>
     <message>
-        <location filename="../gui/downloadview.cpp" line="61"/>
+        <location filename="../gui/downloadview.cpp" line="65"/>
         <source>Copy value</source>
         <translation>Zkopírovat hodnotu</translation>
     </message>
     <message>
-        <location filename="../gui/downloadview.cpp" line="65"/>
+        <location filename="../gui/downloadview.cpp" line="70"/>
         <source>Copy label/ID</source>
         <translation>Zkopírovat jmenovku/identifikátor</translation>
     </message>
+    <message>
+        <location filename="../gui/downloadview.cpp" line="74"/>
+        <source>Open in file browser</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>QtGui::TrayIcon</name>
     <message>
-        <location filename="../gui/trayicon.cpp" line="56"/>
+        <location filename="../gui/trayicon.cpp" line="58"/>
         <source>Settings</source>
         <translation>Nastavení</translation>
     </message>
     <message>
-        <location filename="../gui/trayicon.cpp" line="60"/>
+        <location filename="../gui/trayicon.cpp" line="62"/>
         <source>Rescan all</source>
         <translation>Znovu vše proskenovat</translation>
     </message>
     <message>
-        <location filename="../gui/trayicon.cpp" line="68"/>
+        <location filename="../gui/trayicon.cpp" line="70"/>
         <source>Show internal errors</source>
         <translation>Zobrazit vnitřní chyby</translation>
     </message>
     <message>
-        <location filename="../gui/trayicon.cpp" line="73"/>
+        <location filename="../gui/trayicon.cpp" line="75"/>
         <source>About</source>
         <translation>O Syncthing Tray</translation>
     </message>
     <message>
-        <location filename="../gui/trayicon.cpp" line="78"/>
+        <location filename="../gui/trayicon.cpp" line="80"/>
         <source>Close</source>
         <translation>Zavřít</translation>
     </message>
     <message>
-        <location filename="../gui/trayicon.cpp" line="211"/>
+        <location filename="../gui/trayicon.cpp" line="214"/>
         <source>Error</source>
         <translation>Chyba</translation>
     </message>
     <message>
-        <location filename="../gui/trayicon.cpp" line="230"/>
+        <location filename="../gui/trayicon.cpp" line="234"/>
         <source>Launcher error</source>
         <translation>Chyba spouštěče</translation>
     </message>
     <message>
-        <location filename="../gui/trayicon.cpp" line="246"/>
+        <location filename="../gui/trayicon.cpp" line="250"/>
         <source>Syncthing notification - click to dismiss</source>
         <translation>Oznámení ze Syncthing – kliknutím zahodíte</translation>
     </message>
     <message>
-        <location filename="../gui/trayicon.cpp" line="274"/>
+        <location filename="../gui/trayicon.cpp" line="280"/>
         <source>Syncthing device wants to connect - click for web UI</source>
         <translation>Syncthing zařízení se chce připojit – klikněte pro webové rozhraní</translation>
     </message>
     <message>
-        <location filename="../gui/trayicon.cpp" line="290"/>
+        <location filename="../gui/trayicon.cpp" line="296"/>
         <source>New Syncthing directory - click for web UI</source>
         <translation>Nový Syncthing adresář – klikněte pro webové rozhraní</translation>
     </message>
     <message>
-        <location filename="../gui/trayicon.cpp" line="173"/>
+        <location filename="../gui/trayicon.cpp" line="175"/>
         <source>Disconnected from Syncthing</source>
         <translation>Odpojeno od Syncthing</translation>
     </message>
     <message>
-        <location filename="../gui/trayicon.cpp" line="52"/>
+        <location filename="../gui/trayicon.cpp" line="54"/>
         <source>Open Syncthing</source>
         <translation>Otevřít Syncthing</translation>
     </message>
     <message>
-        <location filename="../gui/trayicon.cpp" line="64"/>
+        <location filename="../gui/trayicon.cpp" line="66"/>
         <source>Log</source>
         <translation>Záznam událostí</translation>
     </message>
@@ -126,214 +161,234 @@
         <translation>Syncthing Tray</translation>
     </message>
     <message>
-        <location filename="../gui/traywidget.ui" line="99"/>
-        <location filename="../gui/traywidget.cpp" line="239"/>
+        <location filename="../gui/traywidget.ui" line="97"/>
+        <location filename="../gui/traywidget.cpp" line="269"/>
         <source>About</source>
         <translation>O Syncthing Tray</translation>
     </message>
     <message>
         <location filename="../gui/traywidget.ui" line="58"/>
-        <location filename="../gui/traywidget.cpp" line="354"/>
+        <location filename="../gui/traywidget.cpp" line="392"/>
         <source>Connect</source>
         <translation>Připojit</translation>
     </message>
     <message>
-        <location filename="../gui/traywidget.ui" line="72"/>
-        <location filename="../gui/traywidget.cpp" line="666"/>
-        <location filename="../gui/traywidget.cpp" line="708"/>
+        <location filename="../gui/traywidget.ui" line="71"/>
+        <location filename="../gui/traywidget.cpp" line="743"/>
+        <location filename="../gui/traywidget.cpp" line="785"/>
         <source>Start</source>
         <translation>Spustit</translation>
     </message>
     <message>
-        <location filename="../gui/traywidget.ui" line="113"/>
+        <location filename="../gui/traywidget.ui" line="110"/>
         <source>Settings</source>
         <translation>Nastavení</translation>
     </message>
     <message>
-        <location filename="../gui/traywidget.ui" line="127"/>
+        <location filename="../gui/traywidget.ui" line="123"/>
         <source>Open Syncthing</source>
         <translation>Otevřít Syncthing</translation>
     </message>
     <message>
-        <location filename="../gui/traywidget.ui" line="289"/>
+        <location filename="../gui/traywidget.ui" line="283"/>
         <source>In</source>
         <translation>Přích.</translation>
     </message>
     <message>
-        <location filename="../gui/traywidget.ui" line="296"/>
+        <location filename="../gui/traywidget.ui" line="290"/>
         <source>Incoming traffic</source>
         <translation>Příchozí provoz</translation>
     </message>
     <message>
-        <location filename="../gui/traywidget.ui" line="228"/>
-        <location filename="../gui/traywidget.ui" line="248"/>
-        <location filename="../gui/traywidget.ui" line="299"/>
-        <location filename="../gui/traywidget.ui" line="319"/>
+        <location filename="../gui/traywidget.ui" line="222"/>
+        <location filename="../gui/traywidget.ui" line="242"/>
+        <location filename="../gui/traywidget.ui" line="293"/>
+        <location filename="../gui/traywidget.ui" line="313"/>
         <source>unknown</source>
         <translation>neznámé</translation>
     </message>
     <message>
-        <location filename="../gui/traywidget.ui" line="218"/>
+        <location filename="../gui/traywidget.ui" line="212"/>
         <source>Global</source>
         <translation>Globální</translation>
     </message>
     <message>
-        <location filename="../gui/traywidget.ui" line="225"/>
+        <location filename="../gui/traywidget.ui" line="219"/>
         <source>Global overall statistics</source>
         <translation>Globální celkové statistiky</translation>
     </message>
     <message>
-        <location filename="../gui/traywidget.ui" line="235"/>
+        <location filename="../gui/traywidget.ui" line="229"/>
         <source>Local</source>
         <translation>Místní</translation>
     </message>
     <message>
-        <location filename="../gui/traywidget.ui" line="245"/>
+        <location filename="../gui/traywidget.ui" line="239"/>
         <source>Local overall statistics</source>
         <translation>Místní celkové statistiky</translation>
     </message>
     <message>
-        <location filename="../gui/traywidget.ui" line="306"/>
+        <location filename="../gui/traywidget.ui" line="300"/>
         <source>Out</source>
         <translation>odchoz.</translation>
     </message>
     <message>
-        <location filename="../gui/traywidget.ui" line="316"/>
+        <location filename="../gui/traywidget.ui" line="310"/>
         <source>Outgoing traffic</source>
         <translation>Odchozí provoz</translation>
     </message>
     <message>
-        <location filename="../gui/traywidget.ui" line="356"/>
+        <location filename="../gui/traywidget.ui" line="350"/>
         <source>Click to show &lt;i&gt;new&lt;/i&gt; notifications&lt;br&gt;
 For &lt;i&gt;all&lt;/i&gt; notifications, checkout the log</source>
         <translation>Kliknutím na &lt;i&gt;nové &lt;/i&gt; oznámení&lt;br&gt;
 (pro &lt;i&gt;alle&lt;/i&gt; oznámení, nahlédněte do záznamu událostí)</translation>
     </message>
     <message>
-        <location filename="../gui/traywidget.ui" line="360"/>
-        <location filename="../gui/traywidget.cpp" line="130"/>
-        <location filename="../gui/traywidget.cpp" line="284"/>
+        <location filename="../gui/traywidget.ui" line="354"/>
+        <location filename="../gui/traywidget.cpp" line="148"/>
+        <location filename="../gui/traywidget.cpp" line="312"/>
         <source>New notifications</source>
         <translation>Nová oznámení</translation>
     </message>
     <message>
-        <location filename="../gui/traywidget.ui" line="391"/>
+        <location filename="../gui/traywidget.ui" line="384"/>
         <source>Directories</source>
         <translation>Adresáře</translation>
     </message>
     <message>
-        <location filename="../gui/traywidget.ui" line="420"/>
+        <location filename="../gui/traywidget.ui" line="416"/>
         <source>Devices</source>
         <translation>Zařízení</translation>
     </message>
     <message>
-        <location filename="../gui/traywidget.ui" line="449"/>
+        <location filename="../gui/traywidget.ui" line="448"/>
         <source>Downloads</source>
         <translation>Stahování</translation>
     </message>
     <message>
-        <location filename="../gui/traywidget.ui" line="481"/>
+        <location filename="../gui/traywidget.ui" line="476"/>
+        <source>Recent changes</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../gui/traywidget.ui" line="512"/>
         <source>Show</source>
         <translation>Zobrazit</translation>
     </message>
     <message>
-        <location filename="../gui/traywidget.ui" line="491"/>
+        <location filename="../gui/traywidget.ui" line="522"/>
         <source>Dismiss</source>
         <translation>Zahodit</translation>
     </message>
     <message>
-        <location filename="../gui/traywidget.cpp" line="98"/>
+        <location filename="../gui/traywidget.cpp" line="120"/>
         <source>View own device ID</source>
         <translation>Zobrazit identifikátor místního zařízení</translation>
     </message>
     <message>
-        <location filename="../gui/traywidget.cpp" line="104"/>
+        <location filename="../gui/traywidget.cpp" line="125"/>
         <source>Restart Syncthing</source>
         <translation>Restartovat Syncthing</translation>
     </message>
     <message>
-        <location filename="../gui/traywidget.cpp" line="110"/>
+        <location filename="../gui/traywidget.cpp" line="130"/>
         <source>Show Syncthing log</source>
         <translation>Zobrazit záznam událostí v Syncthing</translation>
     </message>
     <message>
-        <location filename="../gui/traywidget.cpp" line="116"/>
+        <location filename="../gui/traywidget.cpp" line="135"/>
         <source>Rescan all directories</source>
         <translation>Znovu proskenovat všechny složky</translation>
     </message>
     <message>
-        <location filename="../gui/traywidget.cpp" line="124"/>
+        <location filename="../gui/traywidget.cpp" line="142"/>
         <source>Connection</source>
         <translation>Spojení</translation>
     </message>
     <message>
-        <location filename="../gui/traywidget.cpp" line="146"/>
+        <location filename="../gui/traywidget.cpp" line="164"/>
         <source>Show internal errors</source>
         <translation>Zobrazit vnitřní chyby</translation>
     </message>
     <message>
-        <location filename="../gui/traywidget.cpp" line="154"/>
+        <location filename="../gui/traywidget.cpp" line="179"/>
         <source>Quit Syncthing Tray</source>
         <translation>Ukončit Syncthing Tray</translation>
     </message>
     <message>
-        <location filename="../gui/traywidget.cpp" line="329"/>
+        <location filename="../gui/traywidget.cpp" line="367"/>
         <source>Do you really want to restart Syncthing?</source>
         <translation>Opravdu chcete Syncthing restartovat?</translation>
     </message>
     <message>
-        <location filename="../gui/traywidget.cpp" line="355"/>
+        <location filename="../gui/traywidget.cpp" line="393"/>
         <source>Not connected to Syncthing, click to connect</source>
         <translation>Nepřipojeno k Syncthing, klikněte pro připojení se</translation>
     </message>
     <message>
-        <location filename="../gui/traywidget.cpp" line="367"/>
+        <location filename="../gui/traywidget.cpp" line="405"/>
         <source>Pause</source>
         <translation>Pozastavit</translation>
     </message>
     <message>
-        <location filename="../gui/traywidget.cpp" line="368"/>
+        <location filename="../gui/traywidget.cpp" line="406"/>
         <source>Syncthing is running, click to pause all devices</source>
         <translation>Syncthing je spuštěné, kliknutím pozastavíte veškerá zařízení</translation>
     </message>
     <message>
-        <location filename="../gui/traywidget.cpp" line="374"/>
+        <location filename="../gui/traywidget.cpp" line="411"/>
         <source>Continue</source>
         <translation>Pokračovat</translation>
     </message>
     <message>
-        <location filename="../gui/traywidget.cpp" line="375"/>
+        <location filename="../gui/traywidget.cpp" line="412"/>
         <source>At least one device is paused, click to resume</source>
         <translation>Přinejmenším jedno zařízení je pozastaveno, kliknutím pokračujte</translation>
     </message>
     <message>
-        <location filename="../gui/traywidget.cpp" line="490"/>
+        <location filename="../gui/traywidget.cpp" line="517"/>
         <source>The specified connection configuration &lt;em&gt;%1&lt;/em&gt; is not defined and hence ignored.</source>
         <translation>Zadané nastavení spojení &lt;em&gt;%1&lt;/em&gt; není definováno a proto je ignorováno.</translation>
     </message>
     <message>
-        <location filename="../gui/traywidget.cpp" line="509"/>
+        <location filename="../gui/traywidget.cpp" line="547"/>
         <source>The directory &lt;i&gt;%1&lt;/i&gt; does not exist on the local machine.</source>
         <translation>Adresář &lt;i&gt;%1&lt;/i&gt; neexistuje místně.</translation>
     </message>
     <message>
-        <location filename="../gui/traywidget.cpp" line="520"/>
+        <location filename="../gui/traywidget.cpp" line="558"/>
         <source>The containing directory &lt;i&gt;%1&lt;/i&gt; does not exist on the local machine.</source>
         <translation>Obsažený adresář &lt;i&gt;%1&lt;/i&gt; neexistuje místně.</translation>
     </message>
     <message>
-        <location filename="../gui/traywidget.cpp" line="661"/>
-        <location filename="../gui/traywidget.cpp" line="703"/>
+        <location filename="../gui/traywidget.cpp" line="601"/>
+        <source>Copy path</source>
+        <translation type="unfinished">Zkopírovat popis umístění</translation>
+    </message>
+    <message>
+        <location filename="../gui/traywidget.cpp" line="605"/>
+        <source>Copy device ID</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../gui/traywidget.cpp" line="608"/>
+        <source>Copy directory ID</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../gui/traywidget.cpp" line="739"/>
+        <location filename="../gui/traywidget.cpp" line="779"/>
         <source>Stop</source>
         <translation>Zastavit</translation>
     </message>
     <message>
-        <location filename="../gui/traywidget.cpp" line="662"/>
+        <location filename="../gui/traywidget.cpp" line="740"/>
         <source>Stop Syncthing instance launched via tray icon</source>
         <translation>Zastavit instanci Syncthing spuštěnou prostřednictvím ikony v oznamovací oblasti</translation>
     </message>
     <message>
-        <location filename="../gui/traywidget.cpp" line="667"/>
+        <location filename="../gui/traywidget.cpp" line="744"/>
         <source>Start Syncthing with the built-in launcher configured in the settings</source>
         <translation>Spustit Syncthing s vestavěným spouštěčem nastaveným v nastaveních</translation>
     </message>
@@ -341,27 +396,27 @@ For &lt;i&gt;all&lt;/i&gt; notifications, checkout the log</source>
 <context>
     <name>main</name>
     <message>
-        <location filename="../application/main.cpp" line="45"/>
+        <location filename="../application/main.cpp" line="57"/>
         <source>Unable to </source>
         <translation>Nedaří se </translation>
     </message>
     <message>
-        <location filename="../application/main.cpp" line="71"/>
+        <location filename="../application/main.cpp" line="90"/>
         <source>The system tray is (currently) not available. You could open the tray menu as a regular window using the --windowed flag, though.It is also possible to start Syncthing Tray with --wait to wait until the system tray becomes available instead of showing this message.</source>
         <translation>Oznamovací oblast systémového panelu je (pro tuto chvíli) nedostupná. Je možné otevřít nabídku oznamovací oblasti jako běžné okno pomocí příznaku „--windowed“. Dále je možné spustit s volbou „--wait“ a čekat na to, až bude oznamovací oblast k dispozici (namísto zobrazení této zprávy).</translation>
     </message>
     <message>
-        <location filename="../application/main.cpp" line="89"/>
+        <location filename="../application/main.cpp" line="114"/>
         <source>You must configure how to connect to Syncthing when using Syncthing Tray the first time.</source>
         <translation>Je třeba nastavit jako se připojit k Syncthing ze Syncthing Tray.</translation>
     </message>
     <message>
-        <location filename="../application/main.cpp" line="90"/>
+        <location filename="../application/main.cpp" line="115"/>
         <source>Note that the settings dialog allows importing URL, credentials and API-key from the local Syncthing configuration.</source>
         <translation>Poznamenejme, že dialog nastavení umožňuje importovat URL adresu, přihlašovací údaje a klíč k API z místního nastavení Syncthing.</translation>
     </message>
     <message>
-        <location filename="../application/main.cpp" line="99"/>
+        <location filename="../application/main.cpp" line="124"/>
         <source>The Qt libraries have not been built with tray icon support. You could open the tray menu as a regular window using the -w flag, though.</source>
         <translation>Knihovny Qt byly sestaveny bez podpory pro ikonu v oznamovací oblasti. Měli byste otevřít nabídku pro oznamovací oblast jako běžné okno pomocí příznaku -w.</translation>
     </message>
