@@ -3,11 +3,14 @@
 #include "../misc/syncthingkiller.h"
 #include "../misc/syncthinglauncher.h"
 
-#include "../../connector/syncthingconnection.h"
-#include "../../connector/syncthingnotifier.h"
-#include "../../connector/syncthingprocess.h"
+#include <syncthingconnector/qstringhash.h>
+#include <syncthingconnector/syncthingconnection.h>
+#include <syncthingconnector/syncthingconnectionsettings.h>
+#include <syncthingconnector/syncthingnotifier.h>
+#include <syncthingconnector/syncthingprocess.h>
+#include <syncthingconnector/utils.h>
 #ifdef LIB_SYNCTHING_CONNECTOR_SUPPORT_SYSTEMD
-#include "../../connector/syncthingservice.h"
+#include <syncthingconnector/syncthingservice.h>
 #endif
 
 // use meta-data of syncthingtray application here
@@ -18,6 +21,8 @@
 #include <qtutilities/misc/dbusnotification.h>
 #endif
 
+#include <c++utilities/io/ansiescapecodes.h>
+
 #include <QApplication>
 #include <QCursor>
 #include <QFile>
@@ -26,25 +31,17 @@
 #include <QSslCertificate>
 #include <QSslError>
 #include <QStringBuilder>
+#include <QVersionNumber>
 
+#include <iostream>
+#include <type_traits>
 #include <unordered_map>
 
 using namespace std;
 using namespace Data;
+using namespace CppUtilities::EscapeCodes;
 using namespace QtUtilities;
 
-#if (QT_VERSION < QT_VERSION_CHECK(5, 14, 0))
-namespace std {
-
-template <> struct hash<QString> {
-    std::size_t operator()(const QString &str) const
-    {
-        return qHash(str);
-    }
-};
-} // namespace std
-#endif
-
 namespace Settings {
 
 /*!
@@ -66,22 +63,65 @@ QPoint Appearance::Positioning::positionToUse() const
  * \brief Contains the processes for launching extra tools.
  * \remarks Using std::unordered_map instead of QHash because SyncthingProcess can not be copied.
  */
-static unordered_map<QString, SyncthingProcess> toolProcesses;
+static std::unordered_map<QString, SyncthingProcess> &toolProcesses()
+{
+    static auto toolProcesses = std::unordered_map<QString, SyncthingProcess>();
+    return toolProcesses;
+}
 
 SyncthingProcess &Launcher::toolProcess(const QString &tool)
 {
-    return toolProcesses[tool];
+    return toolProcesses()[tool];
 }
 
-std::vector<SyncthingProcess *> Launcher::allProcesses()
+static bool isLocalAndMatchesPort(const Data::SyncthingConnectionSettings &settings, int port)
 {
-    vector<SyncthingProcess *> processes;
-    processes.reserve(1 + toolProcesses.size());
-    if (auto *const syncthingProcess = SyncthingProcess::mainInstance()) {
-        processes.push_back(syncthingProcess);
+    if (settings.syncthingUrl.isEmpty() || settings.apiKey.isEmpty()) {
+        return false;
     }
-    for (auto &process : toolProcesses) {
-        processes.push_back(&process.second);
+    const auto url = QUrl(settings.syncthingUrl);
+    return ::Data::isLocal(url) && port == url.port(url.scheme() == QLatin1String("https") ? 443 : 80);
+}
+
+Data::SyncthingConnection *Launcher::connectionForLauncher(Data::SyncthingLauncher *launcher)
+{
+    const auto port = launcher->guiUrl().port(-1);
+    if (port < 0) {
+        return nullptr;
+    }
+    auto &connectionSettings = values().connection;
+    auto *relevantSetting = isLocalAndMatchesPort(connectionSettings.primary, port) ? &connectionSettings.primary : nullptr;
+    if (!relevantSetting) {
+        for (auto &secondarySetting : connectionSettings.secondary) {
+            if (isLocalAndMatchesPort(secondarySetting, port)) {
+                relevantSetting = &secondarySetting;
+                continue;
+            }
+        }
+    }
+    if (!relevantSetting) {
+        return nullptr;
+    }
+    auto *const connection = new SyncthingConnection();
+    connection->setParent(launcher);
+    connection->applySettings(*relevantSetting);
+    std::cerr << Phrases::Info << "Considering configured connection \"" << relevantSetting->label.toStdString()
+              << "\" (URL: " << relevantSetting->syncthingUrl.toStdString() << ") to terminate Syncthing" << Phrases::End;
+    return connection;
+}
+
+std::vector<QtGui::ProcessWithConnection> Launcher::allProcesses()
+{
+    auto &tools = toolProcesses();
+    auto processes = std::vector<QtGui::ProcessWithConnection>();
+    processes.reserve(1 + tools.size());
+    if (auto *const launcher = SyncthingLauncher::mainInstance()) {
+        processes.emplace_back(launcher->process(), connectionForLauncher(launcher));
+    } else if (auto *const process = SyncthingProcess::mainInstance()) {
+        processes.emplace_back(process);
+    }
+    for (auto &[tool, process] : tools) {
+        processes.emplace_back(&process);
     }
     return processes;
 }
@@ -95,10 +135,11 @@ void Launcher::autostart() const
     if (autostartEnabled && launcher) {
         launcher->launch(*this);
     }
+    auto &toolProcs = toolProcesses();
     for (auto i = tools.cbegin(), end = tools.cend(); i != end; ++i) {
         const ToolParameter &toolParams = i.value();
         if (toolParams.autostart && !toolParams.path.isEmpty()) {
-            toolProcesses[i.key()].startSyncthing(toolParams.path, SyncthingProcess::splitArguments(toolParams.args));
+            toolProcs[i.key()].startSyncthing(toolParams.path, SyncthingProcess::splitArguments(toolParams.args));
         }
     }
 }
@@ -116,6 +157,61 @@ void Launcher::terminate()
     QtGui::SyncthingKiller(allProcesses()).waitForFinished();
 }
 
+static bool isActiveFor(const SyncthingLauncher &launcher, unsigned int atLeastSeconds)
+{
+    return launcher.isActiveFor(atLeastSeconds);
+}
+
+#ifdef LIB_SYNCTHING_CONNECTOR_SUPPORT_SYSTEMD
+static bool isActiveFor(const SyncthingService &launcher, unsigned int atLeastSeconds)
+{
+    return launcher.isActiveWithoutSleepFor(atLeastSeconds);
+}
+#endif
+
+/*!
+ * \brief Configures the reconnect interval and establishes a connection according to the specified settings/status.
+ */
+template <typename SyncthingMonitor>
+static inline void connectAccordingToSettings(Data::SyncthingConnection &connection, const SyncthingConnectionSettings *currentConnectionSettings,
+    const SyncthingMonitor &monitor, bool reconnectRequired, bool considerForReconnect, bool isRelevant, bool isRunning, bool consideredForReconnect)
+{
+    // set reconnect interval and connect if auto-reconnect is configured
+    if (currentConnectionSettings && (!considerForReconnect || !isRelevant || isRunning)) {
+        // ensure reconnect interval is configured according to settings and connect if auto-connect is configured
+        connection.setAutoReconnectInterval(currentConnectionSettings->reconnectInterval);
+        if (!consideredForReconnect && currentConnectionSettings->autoConnect) {
+            if (reconnectRequired) {
+                connection.reconnect();
+            } else {
+                connection.connect();
+            }
+        }
+    } else {
+        // disable auto-reconnect regardless of the overall settings
+        connection.setAutoReconnectInterval(0);
+    }
+
+    // connect instantly if service is running
+    if (consideredForReconnect) {
+        if (reconnectRequired) {
+            if (isActiveFor(monitor, minActiveTimeInSeconds)) {
+                connection.reconnect();
+            } else if (isRunning) {
+                // give the service (which has just started) a few seconds to initialize
+                connection.reconnectLater(minActiveTimeInSeconds * 1000);
+            }
+        } else if (isRunning && !connection.isConnected()) {
+            if (isActiveFor(monitor, minActiveTimeInSeconds)) {
+                connection.connect();
+            } else {
+                // give the service (which has just started) a few seconds to initialize
+                connection.connectLater(minActiveTimeInSeconds * 1000);
+            }
+        }
+    }
+}
+
 /*!
  * \brief Applies the launcher settings to the specified \a connection considering the status of the main SyncthingLauncher instance.
  * \remarks
@@ -134,34 +230,8 @@ Launcher::LauncherStatus Launcher::apply(
     const auto isRelevant = connection.isLocal();
     const auto isRunning = launcher->isRunning();
     const auto consideredForReconnect = considerForReconnect && isRelevant;
-
-    if (currentConnectionSettings && (!considerForReconnect || !isRelevant || isRunning)) {
-        // ensure auto-reconnect is configured according to settings
-        connection.setAutoReconnectInterval(currentConnectionSettings->reconnectInterval);
-    } else {
-        // disable auto-reconnect regardless of the overall settings
-        connection.setAutoReconnectInterval(0);
-    }
-
-    // connect instantly if service is running
-    if (consideredForReconnect) {
-        if (reconnectRequired) {
-            if (launcher->isActiveFor(minActiveTimeInSeconds)) {
-                connection.reconnect();
-            } else if (isRunning) {
-                // give the service (which has just started) a few seconds to initialize
-                connection.reconnectLater(minActiveTimeInSeconds * 1000);
-            }
-        } else if (isRunning && !connection.isConnected()) {
-            if (launcher->isActiveFor(minActiveTimeInSeconds)) {
-                connection.connect();
-            } else {
-                // give the service (which has just started) a few seconds to initialize
-                connection.connectLater(minActiveTimeInSeconds * 1000);
-            }
-        }
-    }
-
+    connectAccordingToSettings(
+        connection, currentConnectionSettings, *launcher, reconnectRequired, considerForReconnect, isRelevant, isRunning, consideredForReconnect);
     return LauncherStatus{ isRelevant, isRunning, consideredForReconnect, showButton && isRelevant };
 }
 
@@ -194,9 +264,11 @@ void restore()
     settings.sync();
     Settings &v = values();
 
+    const auto version = QVersionNumber::fromString(settings.value(QStringLiteral("v")).toString());
     settings.beginGroup(QStringLiteral("tray"));
     const int connectionCount = settings.beginReadArray(QStringLiteral("connections"));
     auto &primaryConnectionSettings = v.connection.primary;
+    using UnderlyingFlagType = std::underlying_type_t<Data::SyncthingStatusComputionFlags>;
     if (connectionCount > 0) {
         auto &secondaryConnectionSettings = v.connection.secondary;
         secondaryConnectionSettings.clear();
@@ -227,6 +299,17 @@ void restore()
                 = settings.value(QStringLiteral("errorsPollInterval"), connectionSettings->errorsPollInterval).toInt();
             connectionSettings->reconnectInterval
                 = settings.value(QStringLiteral("reconnectInterval"), connectionSettings->reconnectInterval).toInt();
+            connectionSettings->autoConnect = settings.value(QStringLiteral("autoConnect"), connectionSettings->autoConnect).toBool();
+            const auto statusComputionFlags = settings.value(QStringLiteral("statusComputionFlags"),
+                QVariant::fromValue(static_cast<UnderlyingFlagType>(connectionSettings->statusComputionFlags)));
+            if (statusComputionFlags.canConvert<UnderlyingFlagType>()) {
+                connectionSettings->statusComputionFlags
+                    = static_cast<Data::SyncthingStatusComputionFlags>(statusComputionFlags.value<UnderlyingFlagType>());
+                if (version < QVersionNumber(1, 2)) {
+                    connectionSettings->statusComputionFlags
+                        += Data::SyncthingStatusComputionFlags::OutOfSync | Data::SyncthingStatusComputionFlags::UnreadNotifications;
+                }
+            }
             connectionSettings->httpsCertPath = settings.value(QStringLiteral("httpsCertPath")).toString();
             if (!connectionSettings->loadHttpsCert()) {
                 QMessageBox::critical(nullptr, QCoreApplication::applicationName(),
@@ -258,9 +341,10 @@ void restore()
     appearance.trayMenuSize = settings.value(QStringLiteral("trayMenuSize"), appearance.trayMenuSize).toSize();
     appearance.frameStyle = settings.value(QStringLiteral("frameStyle"), appearance.frameStyle).toInt();
     appearance.tabPosition = settings.value(QStringLiteral("tabPos"), appearance.tabPosition).toInt();
-    appearance.brightTextColors = settings.value(QStringLiteral("brightTextColors"), appearance.brightTextColors).toBool();
     v.icons.status = StatusIconSettings(settings.value(QStringLiteral("statusIcons")).toString());
     v.icons.tray = StatusIconSettings(settings.value(QStringLiteral("trayIcons")).toString());
+    v.icons.status.renderSize = settings.value(QStringLiteral("statusIconsRenderSize"), v.icons.status.renderSize).toSize();
+    v.icons.tray.renderSize = settings.value(QStringLiteral("trayIconsRenderSize"), v.icons.tray.renderSize).toSize();
     v.icons.distinguishTrayIcons = settings.value(QStringLiteral("distinguishTrayIcons")).toBool();
     settings.beginGroup(QStringLiteral("positioning"));
     auto &positioning = appearance.positioning;
@@ -273,13 +357,19 @@ void restore()
     auto &launcher = v.launcher;
     launcher.autostartEnabled = settings.value(QStringLiteral("syncthingAutostart"), launcher.autostartEnabled).toBool();
     launcher.useLibSyncthing = settings.value(QStringLiteral("useLibSyncthing"), launcher.useLibSyncthing).toBool();
+#ifdef SYNCTHINGWIDGETS_USE_LIBSYNCTHING
     launcher.libSyncthing.configDir = settings.value(QStringLiteral("libSyncthingConfigDir"), launcher.libSyncthing.configDir).toString();
+    launcher.libSyncthing.dataDir = settings.value(QStringLiteral("libSyncthingDataDir"), launcher.libSyncthing.dataDir).toString();
+    launcher.libSyncthing.logLevel = static_cast<LibSyncthing::LogLevel>(
+        settings.value(QStringLiteral("libSyncthingLogLevel"), static_cast<int>(launcher.libSyncthing.logLevel)).toInt());
+#endif
     launcher.syncthingPath = settings.value(QStringLiteral("syncthingPath"), launcher.syncthingPath).toString();
     launcher.syncthingArgs = settings.value(QStringLiteral("syncthingArgs"), launcher.syncthingArgs).toString();
     launcher.considerForReconnect = settings.value(QStringLiteral("considerLauncherForReconnect"), launcher.considerForReconnect).toBool();
     launcher.showButton = settings.value(QStringLiteral("showLauncherButton"), launcher.showButton).toBool();
     settings.beginGroup(QStringLiteral("tools"));
-    for (const QString &tool : settings.childGroups()) {
+    const auto childGroups = settings.childGroups();
+    for (const QString &tool : childGroups) {
         settings.beginGroup(tool);
         ToolParameter &toolParams = launcher.tools[tool];
         toolParams.autostart = settings.value(QStringLiteral("autostart"), toolParams.autostart).toBool();
@@ -291,6 +381,7 @@ void restore()
 #ifdef LIB_SYNCTHING_CONNECTOR_SUPPORT_SYSTEMD
     auto &systemd = v.systemd;
     systemd.syncthingUnit = settings.value(QStringLiteral("syncthingUnit"), systemd.syncthingUnit).toString();
+    systemd.systemUnit = settings.value(QStringLiteral("systemUnit"), systemd.systemUnit).toBool();
     systemd.showButton = settings.value(QStringLiteral("showButton"), systemd.showButton).toBool();
     systemd.considerForReconnect = settings.value(QStringLiteral("considerForReconnect"), systemd.considerForReconnect).toBool();
 #endif
@@ -315,6 +406,7 @@ void save()
 
     const Settings &v = values();
 
+    settings.setValue(QStringLiteral("v"), QStringLiteral(APP_VERSION));
     settings.beginGroup(QStringLiteral("tray"));
     const auto &primaryConnectionSettings = v.connection.primary;
     const auto &secondaryConnectionSettings = v.connection.secondary;
@@ -334,6 +426,9 @@ void save()
         settings.setValue(QStringLiteral("devStatsPollInterval"), connectionSettings->devStatsPollInterval);
         settings.setValue(QStringLiteral("errorsPollInterval"), connectionSettings->errorsPollInterval);
         settings.setValue(QStringLiteral("reconnectInterval"), connectionSettings->reconnectInterval);
+        settings.setValue(QStringLiteral("autoConnect"), connectionSettings->autoConnect);
+        settings.setValue(QStringLiteral("statusComputionFlags"),
+            QVariant::fromValue(static_cast<std::underlying_type_t<Data::SyncthingStatusComputionFlags>>(connectionSettings->statusComputionFlags)));
         settings.setValue(QStringLiteral("httpsCertPath"), connectionSettings->httpsCertPath);
     }
     settings.endArray();
@@ -356,9 +451,10 @@ void save()
     settings.setValue(QStringLiteral("trayMenuSize"), appearance.trayMenuSize);
     settings.setValue(QStringLiteral("frameStyle"), appearance.frameStyle);
     settings.setValue(QStringLiteral("tabPos"), appearance.tabPosition);
-    settings.setValue(QStringLiteral("brightTextColors"), appearance.brightTextColors);
     settings.setValue(QStringLiteral("statusIcons"), v.icons.status.toString());
     settings.setValue(QStringLiteral("trayIcons"), v.icons.tray.toString());
+    settings.setValue(QStringLiteral("statusIconsRenderSize"), v.icons.status.renderSize);
+    settings.setValue(QStringLiteral("trayIconsRenderSize"), v.icons.tray.renderSize);
     settings.setValue(QStringLiteral("distinguishTrayIcons"), v.icons.distinguishTrayIcons);
     settings.beginGroup(QStringLiteral("positioning"));
     settings.setValue(QStringLiteral("useCursorPos"), appearance.positioning.useCursorPosition);
@@ -370,7 +466,11 @@ void save()
     const auto &launcher = v.launcher;
     settings.setValue(QStringLiteral("syncthingAutostart"), launcher.autostartEnabled);
     settings.setValue(QStringLiteral("useLibSyncthing"), launcher.useLibSyncthing);
+#ifdef SYNCTHINGWIDGETS_USE_LIBSYNCTHING
     settings.setValue(QStringLiteral("libSyncthingConfigDir"), launcher.libSyncthing.configDir);
+    settings.setValue(QStringLiteral("libSyncthingDataDir"), launcher.libSyncthing.dataDir);
+    settings.setValue(QStringLiteral("libSyncthingLogLevel"), static_cast<int>(launcher.libSyncthing.logLevel));
+#endif
     settings.setValue(QStringLiteral("syncthingPath"), launcher.syncthingPath);
     settings.setValue(QStringLiteral("syncthingArgs"), launcher.syncthingArgs);
     settings.setValue(QStringLiteral("considerLauncherForReconnect"), launcher.considerForReconnect);
@@ -388,6 +488,7 @@ void save()
 #ifdef LIB_SYNCTHING_CONNECTOR_SUPPORT_SYSTEMD
     const auto &systemd = v.systemd;
     settings.setValue(QStringLiteral("syncthingUnit"), systemd.syncthingUnit);
+    settings.setValue(QStringLiteral("systemUnit"), systemd.systemUnit);
     settings.setValue(QStringLiteral("showButton"), systemd.showButton);
     settings.setValue(QStringLiteral("considerForReconnect"), systemd.considerForReconnect);
 #endif
@@ -435,6 +536,14 @@ void Settings::apply(SyncthingNotifier &notifier) const
 }
 
 #ifdef LIB_SYNCTHING_CONNECTOR_SUPPORT_SYSTEMD
+/*!
+ * \brief Sets the scope and unit name of the specified \a service according to the settings.
+ */
+void Systemd::setupService(SyncthingService &service) const
+{
+    service.setScopeAndUnitName(systemUnit ? SystemdScope::System : SystemdScope::User, syncthingUnit);
+}
+
 /*!
  * \brief Applies the systemd settings to the specified \a connection considering the status of the global SyncthingService instance.
  * \remarks
@@ -454,35 +563,9 @@ Systemd::ServiceStatus Systemd::apply(
     const auto unitAvailable = service->isUnitAvailable();
     const auto isRunning = unitAvailable && service->isRunning();
     const auto consideredForReconnect = considerForReconnect && isRelevant && unitAvailable;
-
-    if (currentConnectionSettings && (!considerForReconnect || !isRelevant || isRunning)) {
-        // ensure auto-reconnect is configured according to settings
-        connection.setAutoReconnectInterval(currentConnectionSettings->reconnectInterval);
-    } else {
-        // disable auto-reconnect regardless of the overall settings
-        connection.setAutoReconnectInterval(0);
-    }
-
-    // connect instantly if service is running
-    if (consideredForReconnect) {
-        if (reconnectRequired) {
-            if (service->isActiveWithoutSleepFor(minActiveTimeInSeconds)) {
-                connection.reconnect();
-            } else if (isRunning) {
-                // give the service (which has just started) a few seconds to initialize
-                connection.reconnectLater(minActiveTimeInSeconds * 1000);
-            }
-        } else if (isRunning && !connection.isConnected()) {
-            if (service->isActiveWithoutSleepFor(minActiveTimeInSeconds)) {
-                connection.connect();
-            } else {
-                // give the service (which has just started) a few seconds to initialize
-                connection.connectLater(minActiveTimeInSeconds * 1000);
-            }
-        }
-    }
-
-    return ServiceStatus{ isRelevant, isRunning, consideredForReconnect, showButton && isRelevant };
+    connectAccordingToSettings(
+        connection, currentConnectionSettings, *service, reconnectRequired, considerForReconnect, isRelevant, isRunning, consideredForReconnect);
+    return ServiceStatus{ isRelevant, isRunning, consideredForReconnect, showButton && isRelevant, service->isUserScope() };
 }
 
 /*!
@@ -495,9 +578,8 @@ Systemd::ServiceStatus Systemd::status(SyncthingConnection &connection) const
         return ServiceStatus{};
     }
     const auto isRelevant = service->isSystemdAvailable() && connection.isLocal();
-    return ServiceStatus{ isRelevant, service->isRunning(), considerForReconnect && isRelevant, showButton && isRelevant };
+    return ServiceStatus{ isRelevant, service->isRunning(), considerForReconnect && isRelevant, showButton && isRelevant, service->isUserScope() };
 }
-
 #endif
 
 } // namespace Settings
