@@ -2,14 +2,15 @@
 
 #include "../misc/syncthinglauncher.h"
 
-#include "../../connector/syncthingconfig.h"
-#include "../../connector/syncthingconnection.h"
-#include "../../connector/syncthingprocess.h"
-#include "../../connector/utils.h"
+#include <syncthingconnector/syncthingconfig.h>
+#include <syncthingconnector/syncthingconnection.h>
+#include <syncthingconnector/syncthingprocess.h>
+#include <syncthingconnector/utils.h>
+#include <syncthingmodel/syncthingstatuscomputionmodel.h>
 #ifdef LIB_SYNCTHING_CONNECTOR_SUPPORT_SYSTEMD
-#include "../../connector/syncthingservice.h"
-#include "../../model/colors.h"
-#include "../../model/syncthingicons.h"
+#include <syncthingconnector/syncthingservice.h>
+#include <syncthingmodel/colors.h>
+#include <syncthingmodel/syncthingicons.h>
 #endif
 
 #include "ui_appearanceoptionpage.h"
@@ -26,6 +27,8 @@
 // use meta-data of syncthingtray application here
 #include "resources/../../tray/resources/config.h"
 
+#include <qtutilities/misc/compat.h>
+#include <qtutilities/misc/desktoputils.h>
 #include <qtutilities/paletteeditor/colorbutton.h>
 #include <qtutilities/settingsdialog/optioncategory.h>
 #include <qtutilities/settingsdialog/optioncategorymodel.h>
@@ -39,6 +42,7 @@
 #include <qtutilities/misc/dialogutils.h>
 #endif
 
+#include <QDesktopServices>
 #include <QFileDialog>
 #include <QHostAddress>
 #include <QMessageBox>
@@ -51,6 +55,7 @@
 #endif
 #include <QApplication>
 #include <QFontDatabase>
+#include <QMenu>
 #include <QStringBuilder>
 #include <QStyle>
 #include <QTextBlock>
@@ -79,16 +84,36 @@ ConnectionOptionPage::~ConnectionOptionPage()
 {
 }
 
+void ConnectionOptionPage::hideConnectionStatus()
+{
+    ui()->statusTextLabel->setHidden(true);
+    ui()->statusLabel->setHidden(true);
+    ui()->connectPushButton->setHidden(true);
+    m_connection = nullptr;
+}
+
 QWidget *ConnectionOptionPage::setupWidget()
 {
     auto *const widget = ConnectionOptionPageBase::setupWidget();
+    m_statusComputionModel = new SyncthingStatusComputionModel(widget);
     ui()->certPathSelection->provideCustomFileMode(QFileDialog::ExistingFile);
     ui()->certPathSelection->lineEdit()->setPlaceholderText(
         QCoreApplication::translate("QtGui::ConnectionOptionPage", "Auto-detected for local instance"));
     ui()->instanceNoteIcon->setPixmap(QApplication::style()->standardIcon(QStyle::SP_MessageBoxInformation).pixmap(32, 32));
-    QObject::connect(m_connection, &SyncthingConnection::statusChanged, bind(&ConnectionOptionPage::updateConnectionStatus, this));
+    ui()->pollTrafficLabel->setToolTip(ui()->pollTrafficSpinBox->toolTip());
+    ui()->pollDevStatsLabel->setToolTip(ui()->pollDevStatsSpinBox->toolTip());
+    ui()->pollErrorsLabel->setToolTip(ui()->pollErrorsSpinBox->toolTip());
+    ui()->reconnectLabel->setToolTip(ui()->reconnectSpinBox->toolTip());
+    if (m_connection) {
+        QObject::connect(m_connection, &SyncthingConnection::statusChanged, bind(&ConnectionOptionPage::updateConnectionStatus, this));
+    } else {
+        hideConnectionStatus();
+    }
+    ui()->statusComputionFlagsListView->setModel(m_statusComputionModel);
     QObject::connect(ui()->connectPushButton, &QPushButton::clicked, bind(&ConnectionOptionPage::applyAndReconnect, this));
-    QObject::connect(ui()->insertFromConfigFilePushButton, &QPushButton::clicked, bind(&ConnectionOptionPage::insertFromConfigFile, this));
+    QObject::connect(ui()->insertFromConfigFilePushButton, &QPushButton::clicked, bind(&ConnectionOptionPage::insertFromConfigFile, this, false));
+    QObject::connect(
+        ui()->insertFromCustomConfigFilePushButton, &QPushButton::clicked, bind(&ConnectionOptionPage::insertFromConfigFile, this, true));
     QObject::connect(ui()->selectionComboBox, static_cast<void (QComboBox::*)(int)>(&QComboBox::currentIndexChanged),
         bind(&ConnectionOptionPage::showConnectionSettings, this, _1));
     QObject::connect(ui()->selectionComboBox, static_cast<void (QComboBox::*)(const QString &)>(&QComboBox::editTextChanged),
@@ -100,9 +125,9 @@ QWidget *ConnectionOptionPage::setupWidget()
     return widget;
 }
 
-void ConnectionOptionPage::insertFromConfigFile()
+void ConnectionOptionPage::insertFromConfigFile(bool forceFileSelection)
 {
-    auto configFile(SyncthingConfig::locateConfigFile());
+    auto configFile(forceFileSelection ? QString() : SyncthingConfig::locateConfigFile());
     if (configFile.isEmpty()) {
         // allow user to select config file manually if it could not be located
         configFile = QFileDialog::getOpenFileName(
@@ -120,8 +145,8 @@ void ConnectionOptionPage::insertFromConfigFile()
 
     if (!config.guiAddress.isEmpty()) {
         const auto portStart(config.guiAddress.indexOf(QChar(':')));
-        QString guiHost(config.guiAddress.mid(0, portStart));
-        const QStringRef guiPort(portStart > 0 ? config.guiAddress.midRef(portStart) : QStringRef());
+        auto guiHost(config.guiAddress.mid(0, portStart));
+        const auto guiPort = portStart > 0 ? QtUtilities::midRef(config.guiAddress, portStart) : QtUtilities::StringView();
         const QHostAddress guiAddress(guiHost);
         // assume local connection if address is eg. 0.0.0.0
         auto localConnection = true;
@@ -152,7 +177,9 @@ void ConnectionOptionPage::insertFromConfigFile()
 
 void ConnectionOptionPage::updateConnectionStatus()
 {
-    ui()->statusLabel->setText(m_connection->statusText());
+    if (m_connection) {
+        ui()->statusLabel->setText(m_connection->statusText());
+    }
 }
 
 bool ConnectionOptionPage::showConnectionSettings(int index)
@@ -175,6 +202,8 @@ bool ConnectionOptionPage::showConnectionSettings(int index)
     ui()->pollDevStatsSpinBox->setValue(connectionSettings.devStatsPollInterval);
     ui()->pollErrorsSpinBox->setValue(connectionSettings.errorsPollInterval);
     ui()->reconnectSpinBox->setValue(connectionSettings.reconnectInterval);
+    ui()->autoConnectCheckBox->setChecked(connectionSettings.autoConnect);
+    m_statusComputionModel->setStatusComputionFlags(connectionSettings.statusComputionFlags);
     setCurrentIndex(index);
     return true;
 }
@@ -198,6 +227,8 @@ bool ConnectionOptionPage::cacheCurrentSettings(bool applying)
     connectionSettings.devStatsPollInterval = ui()->pollDevStatsSpinBox->value();
     connectionSettings.errorsPollInterval = ui()->pollErrorsSpinBox->value();
     connectionSettings.reconnectInterval = ui()->reconnectSpinBox->value();
+    connectionSettings.autoConnect = ui()->autoConnectCheckBox->isChecked();
+    connectionSettings.statusComputionFlags = m_statusComputionModel->statusComputionFlags();
     if (!connectionSettings.loadHttpsCert()) {
         const QString errorMessage = QCoreApplication::translate("QtGui::ConnectionOptionPage", "Unable to load specified certificate \"%1\".")
                                          .arg(connectionSettings.httpsCertPath);
@@ -342,7 +373,9 @@ void ConnectionOptionPage::reset()
 void ConnectionOptionPage::applyAndReconnect()
 {
     apply();
-    m_connection->reconnect((m_currentIndex == 0 ? m_primarySettings : m_secondarySettings[static_cast<size_t>(m_currentIndex - 1)]));
+    if (m_connection) {
+        m_connection->reconnect((m_currentIndex == 0 ? m_primarySettings : m_secondarySettings[static_cast<size_t>(m_currentIndex - 1)]));
+    }
 }
 
 // NotificationsOptionPage
@@ -456,8 +489,6 @@ bool AppearanceOptionPage::apply()
     settings.frameStyle = style;
     settings.tabPosition = ui()->tabPosComboBox->currentIndex();
 
-    settings.brightTextColors = ui()->brightTextColorsCheckBox->isChecked();
-
     settings.positioning.useCursorPosition = ui()->useCursorPosCheckBox->isChecked();
     settings.positioning.assumedIconPosition = QPoint(ui()->xPosSpinBox->value(), ui()->yPosSpinBox->value());
     return true;
@@ -497,8 +528,6 @@ void AppearanceOptionPage::reset()
     ui()->frameShadowComboBox->setCurrentIndex(index);
     ui()->tabPosComboBox->setCurrentIndex(settings.tabPosition);
 
-    ui()->brightTextColorsCheckBox->setChecked(settings.brightTextColors);
-
     ui()->useCursorPosCheckBox->setChecked(settings.positioning.useCursorPosition);
     ui()->xPosSpinBox->setValue(settings.positioning.assumedIconPosition.x());
     ui()->yPosSpinBox->setValue(settings.positioning.assumedIconPosition.y());
@@ -528,14 +557,14 @@ QWidget *IconsOptionPage::setupWidget()
     case Context::UI:
         widget->setWindowTitle(QCoreApplication::translate("QtGui::IconsOptionPageBase", "UI icons"));
         ui()->contextLabel->setText(
-            QCoreApplication::translate("QtGui::IconsOptionPageBase", "These icon colors are used within Syncthing Tray's UI."));
+            QCoreApplication::translate("QtGui::IconsOptionPageBase", "These icon settings are used within Syncthing Tray's UI."));
         ui()->contextCheckBox->hide();
         break;
     case Context::System:
         widget->setWindowTitle(QCoreApplication::translate("QtGui::IconsOptionPageBase", "System icons"));
-        ui()->contextLabel->setText(
-            QCoreApplication::translate("QtGui::IconsOptionPageBase", "These icon colors are used for the system tray icon and the notifications."));
-        ui()->contextCheckBox->setText(QCoreApplication::translate("QtGui::IconsOptionPageBase", "Use same colors as for UI icons"));
+        ui()->contextLabel->setText(QCoreApplication::translate(
+            "QtGui::IconsOptionPageBase", "These icon settings are used for the system tray icon and the notifications."));
+        ui()->contextCheckBox->setText(QCoreApplication::translate("QtGui::IconsOptionPageBase", "Use same settings as for UI icons"));
         break;
     }
 
@@ -555,6 +584,7 @@ QWidget *IconsOptionPage::setupWidget()
             &colorMapping.setting,
             colorMapping.defaultEmblem,
         };
+        widgetsForColor.previewLabel->setMaximumSize(QSize(32, 32));
 
         // add label for color name
         gridLayout->addWidget(new QLabel(colorMapping.colorName, statusIconsGroupBox), index, 0, Qt::AlignRight | Qt::AlignVCenter);
@@ -569,7 +599,7 @@ QWidget *IconsOptionPage::setupWidget()
                                                                            widgetsForColor.colorButtons[2]->color(),
                                                                        },
                                                                        widgetsForColor.statusEmblem),
-                QSize(32, 32)));
+                widgetsForColor.previewLabel->maximumSize()));
         };
         for (const auto &colorButton : widgetsForColor.colorButtons) {
             QObject::connect(colorButton, &ColorButton::colorChanged, updatePreview);
@@ -588,13 +618,39 @@ QWidget *IconsOptionPage::setupWidget()
         }
     }
 
-    // setup additional buttons
-    QObject::connect(ui()->restoreDefaultsPushButton, &QPushButton::clicked, [this] {
+    // setup presets menu
+    auto *const presetsMenu = new QMenu(widget);
+    presetsMenu->addAction(QCoreApplication::translate("QtGui::IconsOptionPageBase", "Colorful background with gradient (default)"), [this] {
         m_settings = Data::StatusIconSettings();
         update();
     });
+    presetsMenu->addAction(
+        QCoreApplication::translate("QtGui::IconsOptionPageBase", "Transparent background and dark foreground (for bright themes)"), [this] {
+            m_settings = Data::StatusIconSettings(Data::StatusIconSettings::BrightTheme{});
+            update();
+        });
+    presetsMenu->addAction(
+        QCoreApplication::translate("QtGui::IconsOptionPageBase", "Transparent background and bright foreground (for dark themes)"), [this] {
+            m_settings = Data::StatusIconSettings(Data::StatusIconSettings::DarkTheme{});
+            update();
+        });
+
+    // setup additional buttons
+    ui()->restoreDefaultsPushButton->setMenu(presetsMenu);
     QObject::connect(ui()->restorePreviousPushButton, &QPushButton::clicked, [this] { reset(); });
 
+    // setup slider
+    QObject::connect(ui()->renderingSizeSlider, &QSlider::valueChanged, [this](int value) {
+        m_settings.renderSize = QSize(value, value);
+        auto *const label = ui()->renderingSizeLabel;
+        if (const auto scaleFactor = label->devicePixelRatioF(); scaleFactor == 1.0) {
+            label->setText(QString::number(value) + QStringLiteral(" px"));
+        } else {
+            label->setText(QCoreApplication::translate("QtGui::IconsOptionPageBase", "%1 px (scaled to %2 px)")
+                               .arg(QString::number(value), QString::number(static_cast<qreal>(value) * scaleFactor, 'f', 0)));
+        }
+    });
+
     return widget;
 }
 
@@ -623,6 +679,7 @@ bool IconsOptionPage::apply()
 
 void IconsOptionPage::update()
 {
+    ui()->renderingSizeSlider->setValue(std::max(m_settings.renderSize.width(), m_settings.renderSize.height()));
     for (auto &widgetsForColor : m_widgets) {
         widgetsForColor.colorButtons[0]->setColor(widgetsForColor.setting->backgroundStart);
         widgetsForColor.colorButtons[1]->setColor(widgetsForColor.setting->backgroundEnd);
@@ -746,7 +803,7 @@ bool setAutostartEnabled(bool enabled)
                           "Name=" APP_NAME "\n"
                           "Exec=\"");
         desktopFile.write(qEnvironmentVariable("APPIMAGE", QCoreApplication::applicationFilePath()).toUtf8().data());
-        desktopFile.write("\"\nComment=" APP_DESCRIPTION "\n"
+        desktopFile.write("\" qt-widgets-gui --single-instance\nComment=" APP_DESCRIPTION "\n"
                           "Icon=" PROJECT_NAME "\n"
                           "Type=Application\n"
                           "Terminal=false\n"
@@ -828,14 +885,16 @@ LauncherOptionPage::LauncherOptionPage(QWidget *parentWidget)
 {
 }
 
-LauncherOptionPage::LauncherOptionPage(const QString &tool, QWidget *parentWidget)
+LauncherOptionPage::LauncherOptionPage(const QString &tool, const QString &toolName, const QString &windowTitle, QWidget *parentWidget)
     : QObject(parentWidget)
     , LauncherOptionPageBase(parentWidget)
     , m_process(&Launcher::toolProcess(tool))
     , m_launcher(nullptr)
-    , m_restoreArgsButton(nullptr)
+    , m_restoreArgsAction(nullptr)
     , m_kill(false)
     , m_tool(tool)
+    , m_toolName(toolName)
+    , m_windowTitle(windowTitle)
 {
 }
 
@@ -850,25 +909,41 @@ QWidget *LauncherOptionPage::setupWidget()
     // adjust labels to use name of additional tool instead of "Syncthing"
     const auto isSyncthing = m_tool.isEmpty();
     if (!isSyncthing) {
-        widget->setWindowTitle(tr("%1-launcher").arg(m_tool));
-        ui()->enabledCheckBox->setText(tr("Launch %1 when starting the tray icon").arg(m_tool));
-        ui()->syncthingPathLabel->setText(tr("%1 executable").arg(m_tool));
-        ui()->logLabel->setText(tr("%1 log (interleaved stdout/stderr)").arg(m_tool));
+        widget->setWindowTitle(m_windowTitle.isEmpty() ? tr("%1-launcher").arg(m_tool) : m_windowTitle);
+        ui()->enabledCheckBox->setText(tr("Launch %1 when starting the tray icon").arg(m_toolName.isEmpty() ? m_tool : m_toolName));
+        auto toolNameStartingSentence = m_toolName.isEmpty() ? m_tool : m_toolName;
+        toolNameStartingSentence[0] = toolNameStartingSentence[0].toUpper();
+        ui()->syncthingPathLabel->setText(tr("%1 executable").arg(toolNameStartingSentence));
+        ui()->logLabel->setText(tr("%1 log (interleaved stdout/stderr)").arg(toolNameStartingSentence));
 
         // hide "consider for reconnect" and "show start/stop button on tray" checkboxes for tools
         ui()->considerForReconnectCheckBox->setVisible(false);
         ui()->showButtonCheckBox->setVisible(false);
     }
 
+    // hide libsyncthing-controls by default (as the checkbox is unchecked by default)
+    for (auto *const lstWidget : std::initializer_list<QWidget *>{ ui()->configDirLabel, ui()->configDirPathSelection, ui()->dataDirLabel,
+             ui()->dataDirPathSelection, ui()->logLevelLabel, ui()->logLevelComboBox }) {
+        lstWidget->setVisible(false);
+    }
+
     // add "restore to defaults" action for Syncthing arguments
     if (isSyncthing) {
-        m_restoreArgsButton = new IconButton(ui()->argumentsLineEdit);
-        m_restoreArgsButton->setPixmap(
-            QIcon::fromTheme(QStringLiteral("edit-undo"), QIcon(QStringLiteral(":/icons/hicolor/scalable/actions/edit-paste.svg"))).pixmap(16));
-        m_restoreArgsButton->setToolTip(tr("Restore default"));
-        connect(m_restoreArgsButton, &IconButton::clicked, this, &LauncherOptionPage::restoreDefaultArguments);
-        ui()->argumentsLineEdit->insertCustomButton(0, m_restoreArgsButton);
+        m_restoreArgsAction = new QAction(ui()->argumentsLineEdit);
+        m_restoreArgsAction->setText(tr("Restore default"));
+        m_restoreArgsAction->setIcon(
+            QIcon::fromTheme(QStringLiteral("edit-undo"), QIcon(QStringLiteral(":/icons/hicolor/scalable/actions/edit-paste.svg"))));
+        connect(m_restoreArgsAction, &QAction::triggered, this, &LauncherOptionPage::restoreDefaultArguments);
+        ui()->argumentsLineEdit->addCustomAction(m_restoreArgsAction);
+        m_syncthingDownloadAction = new QAction(ui()->syncthingPathSelection);
+        m_syncthingDownloadAction->setText(tr("Show Syncthing releases/downloads"));
+        m_syncthingDownloadAction->setIcon(
+            QIcon::fromTheme(QStringLiteral("download"), QIcon(QStringLiteral(":/icons/hicolor/scalable/actions/download.svg"))));
+        connect(m_syncthingDownloadAction, &QAction::triggered,
+            [] { QDesktopServices::openUrl(QUrl(QStringLiteral("https://github.com/syncthing/syncthing/releases"))); });
+        ui()->syncthingPathSelection->lineEdit()->addCustomAction(m_syncthingDownloadAction);
         ui()->configDirPathSelection->provideCustomFileMode(QFileDialog::Directory);
+        ui()->dataDirPathSelection->provideCustomFileMode(QFileDialog::Directory);
     }
 
     // setup other widgets
@@ -893,6 +968,10 @@ QWidget *LauncherOptionPage::setupWidget()
         connect(m_launcher, &SyncthingLauncher::outputAvailable, this, &LauncherOptionPage::handleSyncthingOutputAvailable, Qt::QueuedConnection);
         connect(m_launcher, &SyncthingLauncher::exited, this, &LauncherOptionPage::handleSyncthingExited, Qt::QueuedConnection);
         connect(m_launcher, &SyncthingLauncher::errorOccurred, this, &LauncherOptionPage::handleSyncthingError, Qt::QueuedConnection);
+#ifdef SYNCTHINGWIDGETS_USE_LIBSYNCTHING
+        connect(ui()->logLevelComboBox, static_cast<void (QComboBox::*)(int)>(&QComboBox::currentIndexChanged), this,
+            &LauncherOptionPage::updateLibSyncthingLogLevel);
+#endif
         m_launcher->setEmittingOutput(true);
     }
     connect(ui()->launchNowPushButton, &QPushButton::clicked, this, &LauncherOptionPage::launch);
@@ -907,7 +986,11 @@ bool LauncherOptionPage::apply()
     if (m_tool.isEmpty()) {
         settings.autostartEnabled = ui()->enabledCheckBox->isChecked();
         settings.useLibSyncthing = ui()->useBuiltInVersionCheckBox->isChecked();
+#ifdef SYNCTHINGWIDGETS_USE_LIBSYNCTHING
         settings.libSyncthing.configDir = ui()->configDirPathSelection->lineEdit()->text();
+        settings.libSyncthing.dataDir = ui()->dataDirPathSelection->lineEdit()->text();
+        settings.libSyncthing.logLevel = static_cast<LibSyncthing::LogLevel>(ui()->logLevelComboBox->currentIndex());
+#endif
         settings.syncthingPath = ui()->syncthingPathSelection->lineEdit()->text();
         settings.syncthingArgs = ui()->argumentsLineEdit->text();
         settings.considerForReconnect = ui()->considerForReconnectCheckBox->isChecked();
@@ -928,7 +1011,11 @@ void LauncherOptionPage::reset()
         ui()->enabledCheckBox->setChecked(settings.autostartEnabled);
         ui()->useBuiltInVersionCheckBox->setChecked(settings.useLibSyncthing);
         ui()->useBuiltInVersionCheckBox->setVisible(settings.useLibSyncthing || SyncthingLauncher::isLibSyncthingAvailable());
+#ifdef SYNCTHINGWIDGETS_USE_LIBSYNCTHING
         ui()->configDirPathSelection->lineEdit()->setText(settings.libSyncthing.configDir);
+        ui()->dataDirPathSelection->lineEdit()->setText(settings.libSyncthing.dataDir);
+        ui()->logLevelComboBox->setCurrentIndex(static_cast<int>(settings.libSyncthing.logLevel));
+#endif
         ui()->syncthingPathSelection->lineEdit()->setText(settings.syncthingPath);
         ui()->argumentsLineEdit->setText(settings.syncthingArgs);
         ui()->considerForReconnectCheckBox->setChecked(settings.considerForReconnect);
@@ -1012,25 +1099,32 @@ void LauncherOptionPage::handleSyncthingError(QProcess::ProcessError error)
     cursor.movePosition(QTextCursor::End);
     cursor.insertBlock();
 
-    QString errorString;
-    switch (error) {
-    case QProcess::FailedToStart:
-        errorString = tr("failed to start (e.g. executable does not exist or not permission error)");
-        break;
-    case QProcess::Crashed:
-        errorString = tr("process crashed");
-        break;
-    case QProcess::Timedout:
-        errorString = tr("timeout error");
-        break;
-    case QProcess::ReadError:
-        errorString = tr("read error");
-        break;
-    case QProcess::WriteError:
-        errorString = tr("write error");
-        break;
-    default:
-        errorString = tr("unknown process error");
+    auto errorString = QString();
+    if (m_launcher) {
+        errorString = m_launcher->errorString();
+    } else if (m_process) {
+        errorString = m_process->errorString();
+    }
+    if (errorString.isEmpty()) {
+        switch (error) {
+        case QProcess::FailedToStart:
+            errorString = tr("failed to start (e.g. executable does not exist or not permission error)");
+            break;
+        case QProcess::Crashed:
+            errorString = tr("process crashed");
+            break;
+        case QProcess::Timedout:
+            errorString = tr("timeout error");
+            break;
+        case QProcess::ReadError:
+            errorString = tr("read error");
+            break;
+        case QProcess::WriteError:
+            errorString = tr("write error");
+            break;
+        default:
+            errorString = tr("unknown process error");
+        }
     }
     cursor.insertText(tr("An error occurred when running %1: %2").arg(m_tool.isEmpty() ? QStringLiteral("Syncthing") : m_tool, errorString));
     cursor.insertBlock();
@@ -1055,16 +1149,23 @@ void LauncherOptionPage::launch()
     if (isRunning()) {
         return;
     }
-    const auto launcherSettings(values().launcher);
+    const auto &launcherSettings(values().launcher);
     if (m_tool.isEmpty()) {
         m_launcher->launch(launcherSettings);
-    } else {
-        const auto toolParams(launcherSettings.tools.value(m_tool));
-        m_process->startSyncthing(toolParams.path, SyncthingProcess::splitArguments(toolParams.args));
-        handleSyncthingLaunched(true);
+        return;
     }
+    const auto toolParams(launcherSettings.tools.value(m_tool));
+    m_process->startSyncthing(toolParams.path, SyncthingProcess::splitArguments(toolParams.args));
+    handleSyncthingLaunched(true);
 }
 
+#ifdef SYNCTHINGWIDGETS_USE_LIBSYNCTHING
+void LauncherOptionPage::updateLibSyncthingLogLevel()
+{
+    m_launcher->setLibSyncthingLogLevel(static_cast<LibSyncthing::LogLevel>(ui()->logLevelComboBox->currentIndex()));
+}
+#endif
+
 void LauncherOptionPage::stop()
 {
     if (!hasBeenShown()) {
@@ -1084,7 +1185,7 @@ void LauncherOptionPage::stop()
             m_process->stopSyncthing();
         }
         if (m_launcher) {
-            m_launcher->terminate();
+            m_launcher->terminate(Launcher::connectionForLauncher(m_launcher));
         }
     }
 }
@@ -1105,22 +1206,39 @@ SystemdOptionPage::SystemdOptionPage(QWidget *parentWidget)
 
 SystemdOptionPage::~SystemdOptionPage()
 {
+    QObject::disconnect(m_unitChangedConn);
+    QObject::disconnect(m_descChangedConn);
+    QObject::disconnect(m_statusChangedConn);
+    QObject::disconnect(m_enabledChangedConn);
 }
 
 QWidget *SystemdOptionPage::setupWidget()
 {
     auto *const widget = SystemdOptionPageBase::setupWidget();
+    auto *const refreshAction = new QAction(QCoreApplication::translate("QtGui::SystemdOptionPage", "Reload all unit files"), widget);
+    refreshAction->setIcon(
+        QIcon::fromTheme(QStringLiteral("view-refresh"), QIcon(QStringLiteral(":/icons/hicolor/scalable/actions/view-refresh.svg"))));
+    ui()->syncthingUnitLineEdit->addCustomAction(refreshAction);
     if (!m_service) {
         return widget;
     }
+    QObject::connect(refreshAction, &QAction::triggered, m_service, &SyncthingService::reloadAllUnitFiles);
     QObject::connect(ui()->syncthingUnitLineEdit, &QLineEdit::textChanged, m_service, &SyncthingService::setUnitName);
     QObject::connect(ui()->startPushButton, &QPushButton::clicked, m_service, &SyncthingService::start);
     QObject::connect(ui()->stopPushButton, &QPushButton::clicked, m_service, &SyncthingService::stop);
     QObject::connect(ui()->enablePushButton, &QPushButton::clicked, m_service, &SyncthingService::enable);
     QObject::connect(ui()->disablePushButton, &QPushButton::clicked, m_service, &SyncthingService::disable);
-    QObject::connect(m_service, &SyncthingService::descriptionChanged, bind(&SystemdOptionPage::handleDescriptionChanged, this, _1));
-    QObject::connect(m_service, &SyncthingService::stateChanged, bind(&SystemdOptionPage::handleStatusChanged, this, _1, _2, _3));
-    QObject::connect(m_service, &SyncthingService::unitFileStateChanged, bind(&SystemdOptionPage::handleEnabledChanged, this, _1));
+    m_unitChangedConn
+        = QObject::connect(ui()->systemUnitCheckBox, &QCheckBox::clicked, m_service, bind(&SystemdOptionPage::handleSystemUnitChanged, this));
+    m_descChangedConn
+        = QObject::connect(m_service, &SyncthingService::descriptionChanged, bind(&SystemdOptionPage::handleDescriptionChanged, this, _1));
+    m_statusChangedConn
+        = QObject::connect(m_service, &SyncthingService::stateChanged, bind(&SystemdOptionPage::handleStatusChanged, this, _1, _2, _3));
+    m_enabledChangedConn
+        = QObject::connect(m_service, &SyncthingService::unitFileStateChanged, bind(&SystemdOptionPage::handleEnabledChanged, this, _1));
+    if (const auto *optionPageWidget = qobject_cast<OptionPageWidget *>(widget)) {
+        QObject::connect(optionPageWidget, &OptionPageWidget::paletteChanged, std::bind(&SystemdOptionPage::updateColors, this));
+    }
     return widget;
 }
 
@@ -1130,6 +1248,7 @@ bool SystemdOptionPage::apply()
     auto &systemdSettings = settings.systemd;
     auto &launcherSettings = settings.launcher;
     systemdSettings.syncthingUnit = ui()->syncthingUnitLineEdit->text();
+    systemdSettings.systemUnit = ui()->systemUnitCheckBox->isChecked();
     systemdSettings.showButton = ui()->showButtonCheckBox->isChecked();
     systemdSettings.considerForReconnect = ui()->considerForReconnectCheckBox->isChecked();
     auto result = true;
@@ -1152,6 +1271,7 @@ void SystemdOptionPage::reset()
 {
     const auto &settings = values().systemd;
     ui()->syncthingUnitLineEdit->setText(settings.syncthingUnit);
+    ui()->systemUnitCheckBox->setChecked(settings.systemUnit);
     ui()->showButtonCheckBox->setChecked(settings.showButton);
     ui()->considerForReconnectCheckBox->setChecked(settings.considerForReconnect);
     if (!m_service) {
@@ -1162,6 +1282,11 @@ void SystemdOptionPage::reset()
     handleEnabledChanged(m_service->unitFileState());
 }
 
+void SystemdOptionPage::handleSystemUnitChanged()
+{
+    m_service->setScope(ui()->systemUnitCheckBox->isChecked() ? SystemdScope::System : SystemdScope::User);
+}
+
 void SystemdOptionPage::handleDescriptionChanged(const QString &description)
 {
     ui()->descriptionValueLabel->setText(description.isEmpty()
@@ -1169,22 +1294,22 @@ void SystemdOptionPage::handleDescriptionChanged(const QString &description)
             : description);
 }
 
-void setIndicatorColor(QWidget *indicator, const QColor &color)
+static void setIndicatorColor(QWidget *indicator, const QColor &color)
 {
     indicator->setStyleSheet(QStringLiteral("border-radius:8px;background-color:") + color.name());
 }
 
 void SystemdOptionPage::handleStatusChanged(const QString &activeState, const QString &subState, DateTime activeSince)
 {
-    QStringList status;
+    m_status.clear();
     if (!activeState.isEmpty()) {
-        status << activeState;
+        m_status << activeState;
     }
     if (!subState.isEmpty()) {
-        status << subState;
+        m_status << subState;
     }
 
-    const bool isRunning = m_service && m_service->isRunning();
+    const bool isRunning = updateRunningColor();
     QString timeStamp;
     if (isRunning && !activeSince.isNull()) {
         timeStamp = QLatin1Char('\n') % QCoreApplication::translate("QtGui::SystemdOptionPage", "since ")
@@ -1192,24 +1317,42 @@ void SystemdOptionPage::handleStatusChanged(const QString &activeState, const QS
     }
 
     ui()->statusValueLabel->setText(
-        status.isEmpty() ? QCoreApplication::translate("QtGui::SystemdOptionPage", "unknown") : status.join(QStringLiteral(" - ")) + timeStamp);
-    setIndicatorColor(ui()->statusIndicator,
-        status.isEmpty() ? Colors::gray(values().appearance.brightTextColors)
-                         : (isRunning ? Colors::green(values().appearance.brightTextColors) : Colors::red(values().appearance.brightTextColors)));
+        m_status.isEmpty() ? QCoreApplication::translate("QtGui::SystemdOptionPage", "unknown") : m_status.join(QStringLiteral(" - ")) + timeStamp);
     ui()->startPushButton->setVisible(!isRunning);
-    ui()->stopPushButton->setVisible(!status.isEmpty() && isRunning);
+    ui()->stopPushButton->setVisible(!m_status.isEmpty() && isRunning);
 }
 
 void SystemdOptionPage::handleEnabledChanged(const QString &unitFileState)
 {
-    const bool isEnabled = m_service && m_service->isEnabled();
+    const auto isEnabled = updateEnabledColor();
     ui()->unitFileStateValueLabel->setText(
         unitFileState.isEmpty() ? QCoreApplication::translate("QtGui::SystemdOptionPage", "unknown") : unitFileState);
-    setIndicatorColor(
-        ui()->enabledIndicator, isEnabled ? Colors::green(values().appearance.brightTextColors) : Colors::gray(values().appearance.brightTextColors));
     ui()->enablePushButton->setVisible(!isEnabled);
     ui()->disablePushButton->setVisible(!unitFileState.isEmpty() && isEnabled);
 }
+
+bool SystemdOptionPage::updateRunningColor()
+{
+    const bool isRunning = m_service && m_service->isRunning();
+    const auto brightColors = isPaletteDark(widget()->palette());
+    setIndicatorColor(ui()->statusIndicator,
+        m_status.isEmpty() ? Colors::gray(brightColors) : (isRunning ? Colors::green(brightColors) : Colors::red(brightColors)));
+    return isRunning;
+}
+
+bool SystemdOptionPage::updateEnabledColor()
+{
+    const auto isEnabled = m_service && m_service->isEnabled();
+    const auto brightColors = isPaletteDark(widget()->palette());
+    setIndicatorColor(ui()->enabledIndicator, isEnabled ? Colors::green(brightColors) : Colors::gray(brightColors));
+    return isEnabled;
+}
+
+void SystemdOptionPage::updateColors()
+{
+    updateRunningColor();
+    updateEnabledColor();
+}
 #endif
 
 // WebViewOptionPage
@@ -1272,13 +1415,15 @@ SettingsDialog::SettingsDialog(QWidget *parent)
 SettingsDialog::SettingsDialog(Data::SyncthingConnection *connection, QWidget *parent)
     : QtUtilities::SettingsDialog(parent)
 {
+    setWindowFlags(windowFlags() | Qt::WindowMaximizeButtonHint);
+
     // setup categories
     QList<OptionCategory *> categories;
     OptionCategory *category;
 
     category = new OptionCategory(this);
     category->setDisplayName(tr("Tray"));
-    category->assignPages({ new ConnectionOptionPage(connection), new NotificationsOptionPage, new AppearanceOptionPage,
+    category->assignPages({ m_connectionsOptionPage = new ConnectionOptionPage(connection), new NotificationsOptionPage, new AppearanceOptionPage,
         new IconsOptionPage(IconsOptionPage::Context::UI), new IconsOptionPage(IconsOptionPage::Context::System) });
     category->setIcon(QIcon(QStringLiteral(":/icons/hicolor/scalable/app/syncthingtray.svg")));
     categories << category;
@@ -1292,9 +1437,10 @@ SettingsDialog::SettingsDialog(Data::SyncthingConnection *connection, QWidget *p
 
     category = new OptionCategory(this);
     category->setDisplayName(tr("Startup"));
-    category->assignPages({ new AutostartOptionPage, new LauncherOptionPage, new LauncherOptionPage(QStringLiteral("Inotify"))
+    category->assignPages({ new AutostartOptionPage, new LauncherOptionPage,
+        new LauncherOptionPage(QStringLiteral("Inotify"), tr("additional tool"), tr("Extra launcher"))
 #ifdef LIB_SYNCTHING_CONNECTOR_SUPPORT_SYSTEMD
-                                                                                 ,
+            ,
         new SystemdOptionPage
 #endif
     });
@@ -1312,7 +1458,7 @@ SettingsDialog::~SettingsDialog()
 
 void SettingsDialog::init()
 {
-    resize(860, 620);
+    resize(1100, 750);
     setWindowTitle(tr("Settings") + QStringLiteral(" - " APP_NAME));
     setWindowIcon(
         QIcon::fromTheme(QStringLiteral("preferences-other"), QIcon(QStringLiteral(":/icons/hicolor/scalable/apps/preferences-other.svg"))));
@@ -1320,6 +1466,12 @@ void SettingsDialog::init()
     // some settings could be applied without restarting the application, good idea?
     //connect(this, &Dialogs::SettingsDialog::applied, bind(&Dialogs::QtSettings::apply, &Settings::qtSettings()));
 }
+
+void SettingsDialog::hideConnectionStatus()
+{
+    m_connectionsOptionPage->hideConnectionStatus();
+}
+
 } // namespace QtGui
 
 INSTANTIATE_UI_FILE_BASED_OPTION_PAGE_NS(QtGui, ConnectionOptionPage)
